@@ -2,30 +2,29 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** No Commercial Usage
-**
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
 **
 ** GNU Lesser General Public License Usage
 **
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this file.
+** Please review the following information to ensure the GNU Lesser General
+** Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
+** Other Usage
+**
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at qt-info@nokia.com.
 **
@@ -36,6 +35,7 @@
 #include "Overview.h"
 #include "DeprecatedGenTemplateInstance.h"
 #include "CppRewriter.h"
+#include "TypeOfExpression.h"
 
 #include <Control.h>
 #include <AST.h>
@@ -46,9 +46,11 @@
 #include <CoreTypes.h>
 #include <TypeVisitor.h>
 #include <NameVisitor.h>
+#include <Templates.h>
 
-#include <QtCore/QList>
-#include <QtCore/QtDebug>
+#include <QList>
+#include <QtDebug>
+#include <QSet>
 
 using namespace CPlusPlus;
 
@@ -79,7 +81,8 @@ ResolveExpression::ResolveExpression(const LookupContext &context)
     : ASTVisitor(context.expressionDocument()->translationUnit()),
       _scope(0),
       _context(context),
-      bind(context.expressionDocument()->translationUnit())
+      bind(context.expressionDocument()->translationUnit()),
+      _reference(false)
 { }
 
 ResolveExpression::~ResolveExpression()
@@ -88,19 +91,26 @@ ResolveExpression::~ResolveExpression()
 QList<LookupItem> ResolveExpression::operator()(ExpressionAST *ast, Scope *scope)
 { return resolve(ast, scope); }
 
-QList<LookupItem> ResolveExpression::resolve(ExpressionAST *ast, Scope *scope)
+QList<LookupItem> ResolveExpression::reference(ExpressionAST *ast, Scope *scope)
+{ return resolve(ast, scope, true); }
+
+QList<LookupItem> ResolveExpression::resolve(ExpressionAST *ast, Scope *scope, bool ref)
 {
     if (! scope)
         return QList<LookupItem>();
 
-    Scope *previousVisibleSymbol = _scope;
-    _scope = scope;
-    const QList<LookupItem> result = resolve(ast);
-    _scope = previousVisibleSymbol;
+    std::swap(_scope, scope);
+    std::swap(_reference, ref);
+
+    const QList<LookupItem> result = expression(ast);
+
+    std::swap(_reference, ref);
+    std::swap(_scope, scope);
+
     return result;
 }
 
-QList<LookupItem> ResolveExpression::resolve(ExpressionAST *ast)
+QList<LookupItem> ResolveExpression::expression(ExpressionAST *ast)
 {
     const QList<LookupItem> previousResults = switchResults(QList<LookupItem>());
     accept(ast);
@@ -265,6 +275,13 @@ bool ResolveExpression::visit(SizeofExpressionAST *)
     return false;
 }
 
+bool ResolveExpression::visit(PointerLiteralAST *)
+{
+    FullySpecifiedType ty(control()->integerType(IntegerType::Int)); // Handling as Int.
+    addResult(ty, _scope);
+    return false;
+}
+
 bool ResolveExpression::visit(NumericLiteralAST *ast)
 {
     const Token &tk = tokenAt(ast->literal_token);
@@ -387,11 +404,39 @@ bool ResolveExpression::visit(UnaryExpressionAST *ast)
         QMutableListIterator<LookupItem > it(_results);
         while (it.hasNext()) {
             LookupItem p = it.next();
-            if (PointerType *ptrTy = p.type()->asPointerType()) {
+            FullySpecifiedType ty = p.type();
+            NamedType *namedTy = ty->asNamedType();
+            if (namedTy != 0) {
+                const QList<LookupItem> types = _context.lookup(namedTy->name(), p.scope());
+                if (!types.empty())
+                    ty = types.front().type();
+            }
+            bool added = false;
+            if (PointerType *ptrTy = ty->asPointerType()) {
                 p.setType(ptrTy->elementType());
                 it.setValue(p);
-            } else {
-                it.remove();
+                added = true;
+            } else if (namedTy != 0) {
+                const Name *starOp = control()->operatorNameId(OperatorNameId::StarOp);
+                if (ClassOrNamespace *b = _context.lookupType(namedTy->name(), p.scope())) {
+                    foreach (const LookupItem &r, b->find(starOp)) {
+                        Symbol *overload = r.declaration();
+                        if (Function *funTy = overload->type()->asFunctionType()) {
+                            if (maybeValidPrototype(funTy, 0)) {
+                                if (Function *proto = instantiate(b->templateId(), funTy)->asFunctionType()) {
+                                    FullySpecifiedType retTy = proto->returnType().simplified();
+                                    p.setType(retTy);
+                                    p.setScope(proto->enclosingScope());
+                                    it.setValue(p);
+                                    added = true;
+                                    break;
+                                }
+                            }
+                        }
+                    }
+                }
+                if (!added)
+                    it.remove();
             }
         }
     }
@@ -416,8 +461,65 @@ bool ResolveExpression::visit(QualifiedNameAST *ast)
 
 bool ResolveExpression::visit(SimpleNameAST *ast)
 {
-    const QList<LookupItem> candidates = _context.lookup(ast->name, _scope);
+    QList<LookupItem> candidates = _context.lookup(ast->name, _scope);
+    QList<LookupItem> newCandidates;
+
+    for (QList<LookupItem>::iterator it = candidates.begin(); it != candidates.end(); ++ it) {
+        LookupItem& item = *it;
+        if (!item.type()->isUndefinedType())
+            continue;
+
+        if (item.declaration() == 0)
+            continue;
+
+        if (item.type().isAuto()) {
+            const Declaration *decl = item.declaration()->asDeclaration();
+            if (!decl)
+                continue;
+
+            Document::Ptr doc = _context.snapshot().document(decl->fileName());
+
+            const StringLiteral *initializationString = decl->getInitializer();
+            if (initializationString == 0)
+                continue;
+
+            QByteArray initializer = QByteArray::fromRawData(initializationString->chars(), initializationString->size()).trimmed();
+
+            // Skip lambda-function initializers
+            if (initializer.length() > 0 && initializer[0] == '[')
+                continue;
+
+            TypeOfExpression exprTyper;
+            exprTyper.init(doc, _context.snapshot(), _context.bindings());
+
+            QList<LookupItem> typeItems = exprTyper(initializer, decl->enclosingScope(), TypeOfExpression::Preprocess);
+            if (typeItems.empty())
+                continue;
+
+            CPlusPlus::Clone cloner(_context.control().data());
+
+            for (int n = 0; n < typeItems.size(); ++ n) {
+                FullySpecifiedType newType = cloner.type(typeItems[n].type(), 0);
+                if (n == 0) {
+                    item.setType(newType);
+                    item.setScope(typeItems[n].scope());
+                }
+                else {
+                    LookupItem newItem(item);
+                    newItem.setType(newType);
+                    newItem.setScope(typeItems[n].scope());
+                    newCandidates.push_back(newItem);
+                }
+            }
+        }
+        else {
+            item.setType(item.declaration()->type());
+            item.setScope(item.declaration()->enclosingScope());
+        }
+    }
+
     addResults(candidates);
+    addResults(newCandidates);
     return false;
 }
 
@@ -445,27 +547,18 @@ bool ResolveExpression::visit(ConversionFunctionIdAST *)
     return false;
 }
 
-bool ResolveExpression::maybeValidPrototype(Function *funTy, unsigned actualArgumentCount) const
+bool ResolveExpression::maybeValidPrototype(Function *funTy, unsigned actualArgumentCount)
 {
-    unsigned minNumberArguments = 0;
+    return funTy->maybeValidPrototype(actualArgumentCount);
+}
 
-    for (; minNumberArguments < funTy->argumentCount(); ++minNumberArguments) {
-        Argument *arg = funTy->argumentAt(minNumberArguments)->asArgument();
-
-        if (arg->hasInitializer())
-            break;
-    }
-
-    if (actualArgumentCount < minNumberArguments) {
-        // not enough arguments.
-        return false;
-
-    } else if (! funTy->isVariadic() && actualArgumentCount > funTy->argumentCount()) {
-        // too many arguments.
-        return false;
-    }
-
-    return true;
+bool ResolveExpression::implicitConversion(const FullySpecifiedType &sourceTy, const FullySpecifiedType &targetTy) const
+{
+    if (sourceTy.isEqualTo(targetTy))
+        return true;
+    else if (sourceTy.simplified().isEqualTo(targetTy.simplified()))
+        return true;
+    return false;
 }
 
 bool ResolveExpression::visit(CallAST *ast)
@@ -473,14 +566,55 @@ bool ResolveExpression::visit(CallAST *ast)
     const QList<LookupItem> baseResults = resolve(ast->base_expression, _scope);
 
     // Compute the types of the actual arguments.
-    int actualArgumentCount = 0;
+    unsigned actualArgumentCount = 0;
 
-    //QList< QList<Result> > arguments;
+    QList< QList<LookupItem> > arguments;
     for (ExpressionListAST *exprIt = ast->expression_list; exprIt; exprIt = exprIt->next) {
-        //arguments.append(resolve(exprIt->expression));
+        if (_reference)
+            arguments.append(resolve(exprIt->value, _scope));
+
         ++actualArgumentCount;
     }
 
+    if (_reference) {
+        _results.clear();
+        foreach (const LookupItem &base, baseResults) {
+            if (Function *funTy = base.type()->asFunctionType()) {
+                if (! maybeValidPrototype(funTy, actualArgumentCount))
+                    continue;
+
+                int score = 0;
+
+                for (unsigned i = 0; i < funTy->argumentCount(); ++i) {
+                    const FullySpecifiedType formalTy = funTy->argumentAt(i)->type();
+
+                    FullySpecifiedType actualTy;
+                    if (i < unsigned(arguments.size())) {
+                        const QList<LookupItem> actual = arguments.at(i);
+                        if (actual.isEmpty())
+                            continue;
+
+                        actualTy = actual.first().type();
+                    } else
+                        actualTy = formalTy;
+
+                    if (implicitConversion(actualTy, formalTy))
+                        ++score;
+                }
+
+                if (score)
+                    _results.prepend(base);
+                else
+                    _results.append(base);
+            }
+        }
+
+        if (_results.isEmpty())
+            _results = baseResults;
+
+        return false;
+    }
+
     const Name *functionCallOp = control()->operatorNameId(OperatorNameId::FunctionCallOp);
 
     foreach (const LookupItem &result, baseResults) {
@@ -517,7 +651,7 @@ bool ResolveExpression::visit(CallAST *ast)
 bool ResolveExpression::visit(ArrayAccessAST *ast)
 {
     const QList<LookupItem> baseResults = resolve(ast->base_expression, _scope);
-    const QList<LookupItem> indexResults = resolve(ast->expression);
+    const QList<LookupItem> indexResults = resolve(ast->expression, _scope);
 
     const Name *arrayAccessOp = control()->operatorNameId(OperatorNameId::ArrayAccessOp);
 
@@ -640,6 +774,38 @@ ClassOrNamespace *ResolveExpression::findClass(const FullySpecifiedType &origina
     return binding;
 }
 
+static void resolveTypedefs(const LookupContext &context,
+                            FullySpecifiedType *type,
+                            Scope **scope)
+{
+    QSet<Symbol *> visited;
+    while (NamedType *namedTy = (*type)->asNamedType()) {
+        ClassOrNamespace *scopeCoN = context.lookupType(*scope);
+        if (!scopeCoN)
+            break;
+
+        // check if namedTy->name() resolves to a typedef
+        QList<LookupItem> namedTypeItems = scopeCoN->lookup(namedTy->name());
+        bool foundTypedef = false;
+        foreach (const LookupItem &it, namedTypeItems) {
+            if (it.declaration() && it.declaration()->isTypedef()) {
+                if (visited.contains(it.declaration()))
+                    break;
+                visited.insert(it.declaration());
+
+                // continue working with the typedefed type and scope
+                *type = it.declaration()->type();
+                *scope = it.scope();
+                foundTypedef = true;
+                break;
+            }
+        }
+
+        if (!foundTypedef)
+            break;
+    }
+}
+
 ClassOrNamespace *ResolveExpression::baseExpression(const QList<LookupItem> &baseResults,
                                                     int accessOp,
                                                     bool *replacedDotOperator) const
@@ -648,6 +814,8 @@ ClassOrNamespace *ResolveExpression::baseExpression(const QList<LookupItem> &bas
         FullySpecifiedType ty = r.type().simplified();
         Scope *scope = r.scope();
 
+        resolveTypedefs(_context, &ty, &scope);
+
         if (accessOp == T_ARROW) {
             if (PointerType *ptrTy = ty->asPointerType()) {
                 if (ClassOrNamespace *binding = findClass(ptrTy->elementType(), scope))
@@ -661,6 +829,7 @@ ClassOrNamespace *ResolveExpression::baseExpression(const QList<LookupItem> &bas
                     Symbol *overload = r.declaration();
                     if (! overload)
                         continue;
+                    Scope *functionScope = overload->enclosingScope();
 
                     if (overload->type()->isFunctionType()) {
                         FullySpecifiedType overloadTy = instantiate(binding->templateId(), overload);
@@ -669,14 +838,26 @@ ClassOrNamespace *ResolveExpression::baseExpression(const QList<LookupItem> &bas
 
                         FullySpecifiedType retTy = instantiatedFunction->returnType().simplified();
 
+                        resolveTypedefs(_context, &retTy, &functionScope);
+
                         if (PointerType *ptrTy = retTy->asPointerType()) {
-                            if (ClassOrNamespace *retBinding = findClass(ptrTy->elementType(), overload->enclosingScope()))
+                            if (ClassOrNamespace *retBinding = findClass(ptrTy->elementType(), functionScope))
                                 return retBinding;
 
-                            else if (scope != overload->enclosingScope()) {
+                            if (scope != functionScope) {
                                 if (ClassOrNamespace *retBinding = findClass(ptrTy->elementType(), scope))
                                     return retBinding;
                             }
+
+                            if (ClassOrNamespace *origin = binding->instantiationOrigin()) {
+                                foreach (Symbol *originSymbol, origin->symbols()) {
+                                    Scope *originScope = originSymbol->asScope();
+                                    if (originScope && originScope != scope && originScope != functionScope) {
+                                        if (ClassOrNamespace *retBinding = findClass(ptrTy->elementType(), originScope))
+                                            return retBinding;
+                                    }
+                                }
+                            }
                         }
                     }
                 }
@@ -713,7 +894,7 @@ bool ResolveExpression::visit(PostIncrDecrAST *ast)
 
 bool ResolveExpression::visit(ObjCMessageExpressionAST *ast)
 {
-    const QList<LookupItem> receiverResults = resolve(ast->receiver_expression);
+    const QList<LookupItem> receiverResults = resolve(ast->receiver_expression, _scope);
 
     foreach (const LookupItem &result, receiverResults) {
         FullySpecifiedType ty = result.type().simplified();
