@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -34,9 +34,9 @@
 #include "qmlerror.h"
 bool Qml_isFileCaseCorrect(const QString &) { return true; }
 
-#include <QtCore/QTextStream>
-#include <QtCore/QFile>
-#include <QtCore/QtDebug>
+#include <QTextStream>
+#include <QFile>
+#include <QtDebug>
 
 QT_BEGIN_NAMESPACE
 
@@ -177,7 +177,7 @@ bool QmlDirParser::parse()
                             QString::fromUtf8("internal types require 2 arguments, but %1 were provided").arg(sectionCount - 1));
                 continue;
             }
-            Component entry(sections[1].toUtf8(), sections[2], -1, -1);
+            Component entry(sections[1], sections[2], -1, -1);
             entry.internal = true;
             _components.append(entry);
         } else if (sections[0] == QLatin1String("typeinfo")) {
@@ -193,7 +193,7 @@ bool QmlDirParser::parse()
 
         } else if (sectionCount == 2) {
             // No version specified (should only be used for relative qmldir files)
-            const Component entry(sections[0].toUtf8(), sections[1], -1, -1);
+            const Component entry(sections[0], sections[1], -1, -1);
             _components.append(entry);
         } else if (sectionCount == 3) {
             const QString &version = sections[1];
@@ -211,7 +211,7 @@ bool QmlDirParser::parse()
                     const int minorVersion = version.mid(dotIndex + 1).toInt(&validVersionNumber);
 
                     if (validVersionNumber) {
-                        const Component entry(sections[0].toUtf8(), sections[2], majorVersion, minorVersion);
+                        const Component entry(sections[0], sections[2], majorVersion, minorVersion);
 
                         _components.append(entry);
                     }
