@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -32,11 +32,12 @@
 
 #include "qtcolorbutton.h"
 
-#include <QtCore/QMimeData>
-#include <QtGui/QApplication>
-#include <QtGui/QColorDialog>
-#include <QtGui/QDragEnterEvent>
-#include <QtGui/QPainter>
+#include <QMimeData>
+#include <QApplication>
+#include <QColorDialog>
+#include <QDragEnterEvent>
+#include <QPainter>
+#include <QDrag>
 
 namespace Utils {
 
