@@ -2,30 +2,29 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** No Commercial Usage
-**
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
 **
 ** GNU Lesser General Public License Usage
 **
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this file.
+** Please review the following information to ensure the GNU Lesser General
+** Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
+** Other Usage
+**
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at qt-info@nokia.com.
 **
@@ -38,164 +37,39 @@
 #include "ifilewizardextension.h"
 #include "mimedatabase.h"
 #include "editormanager/editormanager.h"
-
+#include "dialogs/promptoverwritedialog.h"
 #include <extensionsystem/pluginmanager.h>
 #include <utils/filewizarddialog.h>
 #include <utils/qtcassert.h>
 #include <utils/stringutils.h>
+#include <utils/fileutils.h>
 
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QVector>
-#include <QtCore/QDebug>
-#include <QtCore/QSharedData>
-#include <QtCore/QEventLoop>
-#include <QtCore/QSharedPointer>
-#include <QtCore/QScopedPointer>
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
+#include <QVector>
+#include <QDebug>
+#include <QSharedData>
+#include <QEventLoop>
+#include <QSharedPointer>
+#include <QScopedPointer>
 
-#include <QtGui/QMessageBox>
-#include <QtGui/QWizard>
-#include <QtGui/QMainWindow>
-#include <QtGui/QIcon>
+#include <QMessageBox>
+#include <QWizard>
+#include <QMainWindow>
+#include <QIcon>
 
 enum { debugWizard = 0 };
 
 namespace Core {
 
-class GeneratedFilePrivate : public QSharedData
+static int indexOfFile(const GeneratedFiles &f, const QString &path)
 {
-public:
-    GeneratedFilePrivate() : binary(false) {}
-    explicit GeneratedFilePrivate(const QString &p);
-    QString path;
-    QByteArray contents;
-    QString editorId;
-    bool binary;
-    GeneratedFile::Attributes attributes;
-};
-
-GeneratedFilePrivate::GeneratedFilePrivate(const QString &p) :
-    path(QDir::cleanPath(p)),
-    binary(false),
-    attributes(0)
-{
-}
-
-GeneratedFile::GeneratedFile() :
-    m_d(new GeneratedFilePrivate)
-{
-}
-
-GeneratedFile::GeneratedFile(const QString &p) :
-    m_d(new GeneratedFilePrivate(p))
-{
-}
-
-GeneratedFile::GeneratedFile(const GeneratedFile &rhs) :
-    m_d(rhs.m_d)
-{
-}
-
-GeneratedFile &GeneratedFile::operator=(const GeneratedFile &rhs)
-{
-    if (this != &rhs)
-        m_d.operator=(rhs.m_d);
-    return *this;
-}
-
-GeneratedFile::~GeneratedFile()
-{
-}
-
-QString GeneratedFile::path() const
-{
-    return m_d->path;
-}
-
-void GeneratedFile::setPath(const QString &p)
-{
-    m_d->path = QDir::cleanPath(p);
-}
-
-QString GeneratedFile::contents() const
-{
-    return QString::fromUtf8(m_d->contents);
-}
-
-void GeneratedFile::setContents(const QString &c)
-{
-    m_d->contents = c.toUtf8();
-}
-
-QByteArray GeneratedFile::binaryContents() const
-{
-    return m_d->contents;
-}
-
-void GeneratedFile::setBinaryContents(const QByteArray &c)
-{
-    m_d->contents = c;
-}
-
-bool GeneratedFile::isBinary() const
-{
-    return m_d->binary;
-}
-
-void GeneratedFile::setBinary(bool b)
-{
-    m_d->binary = b;
-}
-
-QString GeneratedFile::editorId() const
-{
-    return m_d->editorId;
-}
-
-void GeneratedFile::setEditorId(const QString &k)
-{
-    m_d->editorId = k;
-}
-
-bool GeneratedFile::write(QString *errorMessage) const
-{
-    // Ensure the directory
-    const QFileInfo info(m_d->path);
-    const QDir dir = info.absoluteDir();
-    if (!dir.exists()) {
-        if (!dir.mkpath(dir.absolutePath())) {
-            *errorMessage = BaseFileWizard::tr("Unable to create the directory %1.").arg(dir.absolutePath());
-            return false;
-        }
-    }
-    // Write out
-    QFile file(m_d->path);
-
-    QIODevice::OpenMode flags = QIODevice::WriteOnly|QIODevice::Truncate;
-    if (!isBinary())
-        flags |= QIODevice::Text;
-
-    if (!file.open(flags)) {
-        *errorMessage = BaseFileWizard::tr("Unable to open %1 for writing: %2").arg(m_d->path, file.errorString());
-        return false;
-    }
-    if (file.write(m_d->contents) == -1) {
-        *errorMessage =  BaseFileWizard::tr("Error while writing to %1: %2").arg(m_d->path, file.errorString());
-        return false;
-    }
-    file.close();
-    return true;
-}
-
-GeneratedFile::Attributes GeneratedFile::attributes() const
-{
-    return m_d->attributes;
-}
-
-void GeneratedFile::setAttributes(Attributes a)
-{
-    m_d->attributes = a;
+    const int size = f.size();
+    for (int i = 0; i < size; ++i)
+        if (f.at(i).path() == path)
+            return i;
+    return -1;
 }
 
 // ------------ BaseFileWizardParameterData
@@ -212,6 +86,9 @@ public:
     QString id;
     QString category;
     QString displayCategory;
+    Core::FeatureSet requiredFeatures;
+    Core::IWizard::WizardFlags flags;
+    QString descriptionImage;
 };
 
 BaseFileWizardParameterData::BaseFileWizardParameterData(IWizard::WizardKind k) :
@@ -230,6 +107,15 @@ void BaseFileWizardParameterData::clear()
     displayCategory.clear();
 }
 
+/*!
+    \class Core::BaseFileWizardParameters
+    \brief Parameter class for passing parameters to instances of class Wizard
+     containing name, icon and such.
+
+    \sa Core::GeneratedFile, Core::BaseFileWizard, Core::StandardFileWizard
+    \sa Core::Internal::WizardEventLoop
+*/
+
 BaseFileWizardParameters::BaseFileWizardParameters(IWizard::WizardKind kind) :
    m_d(new BaseFileWizardParameterData(kind))
 {
@@ -262,7 +148,8 @@ CORE_EXPORT QDebug operator<<(QDebug d, const BaseFileWizardParameters &p)
                 << " Category: " << p.category()
                 << " DisplayName: " << p.displayName()
                 << " Description: " << p.description()
-                << " DisplayCategory: " << p.displayCategory();
+                << " DisplayCategory: " << p.displayCategory()
+                << " Required Features: " << p.requiredFeatures().toStringList();
     return d;
 }
 
@@ -331,25 +218,64 @@ QString BaseFileWizardParameters::displayCategory() const
     return m_d->displayCategory;
 }
 
+Core::FeatureSet BaseFileWizardParameters::requiredFeatures() const
+{
+    return m_d->requiredFeatures;
+}
+
+void BaseFileWizardParameters::setRequiredFeatures(Core::FeatureSet features)
+{
+
+    m_d->requiredFeatures = features;
+}
+
 void BaseFileWizardParameters::setDisplayCategory(const QString &v)
 {
     m_d->displayCategory = v;
 }
 
-/* WizardEventLoop: Special event loop that runs a QWizard and terminates if the page changes.
- * Synopsis:
- * \code
+Core::IWizard::WizardFlags BaseFileWizardParameters::flags() const
+{
+    return m_d->flags;
+}
+
+void BaseFileWizardParameters::setFlags(Core::IWizard::WizardFlags flags)
+{
+    m_d->flags = flags;
+}
+
+QString BaseFileWizardParameters::descriptionImage() const
+{
+  return m_d->descriptionImage;
+}
+
+void BaseFileWizardParameters::setDescriptionImage(const QString &path)
+{
+    m_d->descriptionImage = path;
+}
+
+/*!
+    \class Core::Internal::WizardEventLoop
+    \brief Special event loop that runs a QWizard and terminates if the page changes.
+
+    Use by Core::BaseFileWizard to intercept the change from the standard wizard pages
+    to the extension pages (as the latter require the list of Core::GeneratedFile generated).
+
+    Synopsis:
+    \code
     Wizard wizard(parent);
     WizardEventLoop::WizardResult wr;
     do {
         wr = WizardEventLoop::execWizardPage(wizard);
     } while (wr == WizardEventLoop::PageChanged);
- * \endcode */
+    \endcode
+
+    \sa Core::GeneratedFile, Core::BaseFileWizardParameters, Core::BaseFileWizard, Core::StandardFileWizard
+*/
 
 class WizardEventLoop : public QEventLoop
 {
     Q_OBJECT
-    Q_DISABLE_COPY(WizardEventLoop)
     WizardEventLoop(QObject *parent);
 
 public:
@@ -422,7 +348,24 @@ void WizardEventLoop::rejected()
     quit();
 }
 
-// ---------------- BaseFileWizardPrivate
+/*!
+    \class Core::BaseFileWizard
+    \brief A generic wizard for creating files.
+
+    The abstract methods:
+    \list
+    \o createWizardDialog(): Called to create the QWizard dialog to be shown
+    \o generateFiles(): Generate file content
+    \endlist
+
+    must be implemented.
+    The behaviour can be further customized by overwriting the virtual method \c postGenerateFiles(),
+    which is called after generating the files.
+
+    \sa Core::GeneratedFile, Core::BaseFileWizardParameters, Core::StandardFileWizard
+    \sa Core::Internal::WizardEventLoop
+*/
+
 struct BaseFileWizardPrivate
 {
     explicit BaseFileWizardPrivate(const Core::BaseFileWizardParameters &parameters)
@@ -437,51 +380,61 @@ struct BaseFileWizardPrivate
 BaseFileWizard::BaseFileWizard(const BaseFileWizardParameters &parameters,
                        QObject *parent) :
     IWizard(parent),
-    m_d(new BaseFileWizardPrivate(parameters))
+    d(new BaseFileWizardPrivate(parameters))
 {
 }
 
+BaseFileWizardParameters BaseFileWizard::baseFileWizardParameters() const
+{
+    return d->m_parameters;
+}
+
 BaseFileWizard::~BaseFileWizard()
 {
-    delete m_d;
+    delete d;
 }
 
 IWizard::WizardKind  BaseFileWizard::kind() const
 {
-    return m_d->m_parameters.kind();
+    return d->m_parameters.kind();
 }
 
 QIcon BaseFileWizard::icon() const
 {
-    return m_d->m_parameters.icon();
+    return d->m_parameters.icon();
 }
 
 QString BaseFileWizard::description() const
 {
-    return m_d->m_parameters.description();
+    return d->m_parameters.description();
 }
 
 QString BaseFileWizard::displayName() const
 {
-    return m_d->m_parameters.displayName();
+    return d->m_parameters.displayName();
 }
 
 QString BaseFileWizard::id() const
 {
-    return m_d->m_parameters.id();
+    return d->m_parameters.id();
 }
 
 QString BaseFileWizard::category() const
 {
-    return m_d->m_parameters.category();
+    return d->m_parameters.category();
 }
 
 QString BaseFileWizard::displayCategory() const
 {
-    return m_d->m_parameters.displayCategory();
+    return d->m_parameters.displayCategory();
 }
 
-void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
+QString BaseFileWizard::descriptionImage() const
+{
+       return d->m_parameters.descriptionImage();
+}
+
+void BaseFileWizard::runWizard(const QString &path, QWidget *parent, const QString &platform, const QVariantMap &extraValues)
 {
     QTC_ASSERT(!path.isEmpty(), return);
 
@@ -511,7 +464,10 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
     // Create dialog and run it. Ensure that the dialog is deleted when
     // leaving the func, but not before the IFileWizardExtension::process
     // has been called
-    const QScopedPointer<QWizard> wizard(createWizardDialog(parent, path, allExtensionPages));
+    const QScopedPointer<QWizard> wizard(createWizardDialog(parent, WizardDialogParameters(path,
+                                                                                           allExtensionPages,
+                                                                                           platform,
+                                                                                           requiredFeatures())));
     QTC_ASSERT(!wizard.isNull(), return);
 
     GeneratedFiles files;
@@ -537,18 +493,14 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
         }
         if (firstExtensionPageHit)
             foreach (IFileWizardExtension *ex, extensions)
-                ex->firstExtensionPageShown(files);
+                ex->firstExtensionPageShown(files, extraValues);
         if (accepted)
             break;
     }
     if (files.empty())
         return;
     // Compile result list and prompt for overwrite
-    QStringList result;
-    foreach (const GeneratedFile &generatedFile, files)
-        result.push_back(generatedFile.path());
-
-    switch (promptOverwrite(result, &errorMessage)) {
+    switch (promptOverwrite(&files, &errorMessage)) {
     case OverwriteCanceled:
         return;
     case OverwriteError:
@@ -558,6 +510,12 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
         break;
     }
 
+    foreach (IFileWizardExtension *ex, extensions) {
+        for (int i = 0; i < files.count(); i++) {
+            ex->applyCodeStyle(&files[i]);
+        }
+    }
+
     // Write
     if (!writeFiles(files, &errorMessage)) {
         QMessageBox::critical(parent, tr("File Generation Failure"), errorMessage);
@@ -568,7 +526,7 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
     // Run the extensions
     foreach (IFileWizardExtension *ex, extensions) {
         bool remove;
-        if (!ex->process(files, &remove, &errorMessage)) {
+        if (!ex->processFiles(files, &remove, &errorMessage)) {
             QMessageBox::critical(parent, tr("File Generation Failure"), errorMessage);
             return;
         }
@@ -587,24 +545,76 @@ void BaseFileWizard::runWizard(const QString &path, QWidget *parent)
         QMessageBox::critical(0, tr("File Generation Failure"), errorMessage);
 }
 
-// Write
+
+Core::FeatureSet BaseFileWizard::requiredFeatures() const
+{
+    return d->m_parameters.requiredFeatures();
+}
+
+Core::IWizard::WizardFlags BaseFileWizard::flags() const
+{
+    return d->m_parameters.flags();
+}
+
+/*!
+    \fn virtual QWizard *Core::BaseFileWizard::createWizardDialog(QWidget *parent,
+                                                                  const QString &defaultPath,
+                                                                  const WizardPageList &extensionPages) const = 0
+    \brief Implement to create the wizard dialog on the parent, adding the extension pages.
+*/
+
+/*!
+    \fn virtual Core::GeneratedFiles Core::BaseFileWizard::generateFiles(const QWizard *w,
+                                                                         QString *errorMessage) const = 0
+     \brief Overwrite to query the parameters from the dialog and generate the files.
+
+     Note: This does not generate physical files, but merely the list of Core::GeneratedFile.
+*/
+
+/*!
+    \brief Physically write files.
+
+    Re-implement (calling the base implementation) to create files with CustomGeneratorAttribute set.
+*/
+
 bool BaseFileWizard::writeFiles(const GeneratedFiles &files, QString *errorMessage)
 {
+    const GeneratedFile::Attributes noWriteAttributes
+        = GeneratedFile::CustomGeneratorAttribute|GeneratedFile::KeepExistingFileAttribute;
     foreach (const GeneratedFile &generatedFile, files)
-        if (!(generatedFile.attributes() & GeneratedFile::CustomGeneratorAttribute))
+        if (!(generatedFile.attributes() & noWriteAttributes ))
             if (!generatedFile.write(errorMessage))
                 return false;
     return true;
 }
 
+/*!
+    \brief Sets some standard options on a QWizard
+*/
 
 void BaseFileWizard::setupWizard(QWizard *w)
 {
     w->setOption(QWizard::NoCancelButton, false);
     w->setOption(QWizard::NoDefaultButton, false);
     w->setOption(QWizard::NoBackButtonOnStartPage, true);
+    w->setWindowFlags(w->windowFlags() & ~Qt::WindowContextHelpButtonHint);
+
+#ifdef Q_OS_MAC
+    w->setButtonLayout(QList<QWizard::WizardButton>()
+                    << QWizard::CancelButton
+                    << QWizard::Stretch
+                    << QWizard::BackButton
+                    << QWizard::NextButton
+                    << QWizard::CommitButton
+                    << QWizard::FinishButton);
+#endif
 }
 
+/*!
+    \brief Read "shortTitle" dynamic property of the pageId and apply it as the title
+    of corresponding progress item
+*/
+
 void BaseFileWizard::applyExtensionPageShortTitle(Utils::Wizard *wizard, int pageId)
 {
     if (pageId < 0)
@@ -620,11 +630,21 @@ void BaseFileWizard::applyExtensionPageShortTitle(Utils::Wizard *wizard, int pag
       item->setTitle(shortTitle);
 }
 
+/*!
+    \brief Overwrite to perform steps to be done after files are actually created.
+
+    The default implementation opens editors with the newly generated files.
+*/
+
 bool BaseFileWizard::postGenerateFiles(const QWizard *, const GeneratedFiles &l, QString *errorMessage)
 {
     return BaseFileWizard::postGenerateOpenEditors(l, errorMessage);
 }
 
+/*!
+    \brief Utility to open the editors for the files whose attribute is set accordingly.
+*/
+
 bool BaseFileWizard::postGenerateOpenEditors(const GeneratedFiles &l, QString *errorMessage)
 {
     Core::EditorManager *em = Core::EditorManager::instance();
@@ -640,7 +660,12 @@ bool BaseFileWizard::postGenerateOpenEditors(const GeneratedFiles &l, QString *e
     return true;
 }
 
-BaseFileWizard::OverwriteResult BaseFileWizard::promptOverwrite(const QStringList &files,
+/*!
+    \brief Utility that performs an overwrite check on a set of files. It checks if
+    the file exists, can be overwritten at all and prompts the user with a summary.
+*/
+
+BaseFileWizard::OverwriteResult BaseFileWizard::promptOverwrite(GeneratedFiles *files,
                                                                 QString *errorMessage) const
 {
     if (debugWizard)
@@ -650,17 +675,20 @@ BaseFileWizard::OverwriteResult BaseFileWizard::promptOverwrite(const QStringLis
     bool oddStuffFound = false;
 
     static const QString readOnlyMsg = tr(" [read only]");
-    static const QString directoryMsg = tr(" [directory]");
+    static const QString directoryMsg = tr(" [folder]");
     static const QString symLinkMsg = tr(" [symbolic link]");
 
-    foreach (const QString &fileName, files) {
-        const QFileInfo fi(fileName);
+    foreach (const GeneratedFile &file, *files) {
+        const QFileInfo fi(file.path());
         if (fi.exists())
-            existingFiles.append(fileName);
+            existingFiles.append(file.path());
     }
-    // Note: Generated files are using native separators, no need to convert.
+    if (existingFiles.isEmpty())
+        return OverwriteOk;
+    // Before prompting to overwrite existing files, loop over files and check
+    // if there is anything blocking overwriting them (like them being links or folders).
+    // Format a file list message as ( "<file1> [readonly], <file2> [folder]").
     const QString commonExistingPath = Utils::commonPath(existingFiles);
-    // Format a file list message as ( "<file1> [readonly], <file2> [directory]").
     QString fileNamesMsgPart;
     foreach (const QString &fileName, existingFiles) {
         const QFileInfo fi(fileName);
@@ -687,26 +715,37 @@ BaseFileWizard::OverwriteResult BaseFileWizard::promptOverwrite(const QStringLis
         }
     }
 
-    if (existingFiles.isEmpty())
-        return OverwriteOk;
-
     if (oddStuffFound) {
         *errorMessage = tr("The project directory %1 contains files which cannot be overwritten:\n%2.")
                 .arg(QDir::toNativeSeparators(commonExistingPath)).arg(fileNamesMsgPart);
         return OverwriteError;
     }
-
-    const QString messageFormat = tr("The following files already exist in the directory %1:\n"
-                                     "%2.\nWould you like to overwrite them?");
-    const QString message = messageFormat.arg(QDir::toNativeSeparators(commonExistingPath)).arg(fileNamesMsgPart);
-    const bool yes = (QMessageBox::question(Core::ICore::instance()->mainWindow(),
-                                            tr("Existing files"), message,
-                                            QMessageBox::Yes | QMessageBox::No,
-                                            QMessageBox::No)
-                      == QMessageBox::Yes);
-    return yes ? OverwriteOk :  OverwriteCanceled;
+    // Prompt to overwrite existing files.
+    Internal::PromptOverwriteDialog overwriteDialog;
+    // Scripts cannot handle overwrite
+    overwriteDialog.setFiles(existingFiles);
+    foreach (const GeneratedFile &file, *files)
+        if (file.attributes() & GeneratedFile::CustomGeneratorAttribute)
+            overwriteDialog.setFileEnabled(file.path(), false);
+    if (overwriteDialog.exec() != QDialog::Accepted)
+        return OverwriteCanceled;
+    const QStringList existingFilesToKeep = overwriteDialog.uncheckedFiles();
+    if (existingFilesToKeep.size() == files->size()) // All exist & all unchecked->Cancel.
+        return OverwriteCanceled;
+    // Set 'keep' attribute in files
+    foreach (const QString &keepFile, existingFilesToKeep) {
+        const int i = indexOfFile(*files, keepFile);
+        QTC_ASSERT(i != -1, return OverwriteCanceled; )
+        GeneratedFile &file = (*files)[i];
+        file.setAttributes(file.attributes() | GeneratedFile::KeepExistingFileAttribute);
+    }
+    return OverwriteOk;
 }
 
+/*!
+    \brief Build a file name, adding the extension unless baseName already has one.
+*/
+
 QString BaseFileWizard::buildFileName(const QString &path,
                                       const QString &baseName,
                                       const QString &extension)
@@ -727,16 +766,36 @@ QString BaseFileWizard::buildFileName(const QString &path,
     return rc;
 }
 
+/*!
+    \brief Utility that returns the preferred suffix for a mime type
+*/
+
 QString BaseFileWizard::preferredSuffix(const QString &mimeType)
 {
-    const QString rc = Core::ICore::instance()->mimeDatabase()->preferredSuffixByType(mimeType);
+    const QString rc = Core::ICore::mimeDatabase()->preferredSuffixByType(mimeType);
     if (rc.isEmpty())
         qWarning("%s: WARNING: Unable to find a preferred suffix for %s.",
                  Q_FUNC_INFO, mimeType.toUtf8().constData());
     return rc;
 }
 
-// ------------- StandardFileWizard
+/*!
+    \class Core::StandardFileWizard
+    \brief Convenience class for creating one file.
+
+    It uses Utils::FileWizardDialog and introduces a new virtual to generate the
+    files from path and name.
+
+    \sa Core::GeneratedFile, Core::BaseFileWizardParameters, Core::BaseFileWizard
+    \sa Core::Internal::WizardEventLoop
+*/
+
+/*!
+    \fn Core::GeneratedFiles Core::StandardFileWizard::generateFilesFromPath(const QString &path,
+                                                                             const QString &name,
+                                                                             QString *errorMessage) const = 0
+    \brief Newly introduced virtual that creates the files under the path.
+*/
 
 StandardFileWizard::StandardFileWizard(const BaseFileWizardParameters &parameters,
                                        QObject *parent) :
@@ -744,19 +803,26 @@ StandardFileWizard::StandardFileWizard(const BaseFileWizardParameters &parameter
 {
 }
 
+/*!
+    \brief Implemented to create a Utils::FileWizardDialog.
+*/
+
 QWizard *StandardFileWizard::createWizardDialog(QWidget *parent,
-                                                const QString &defaultPath,
-                                                const WizardPageList &extensionPages) const
+                                                const WizardDialogParameters &wizardDialogParameters) const
 {
     Utils::FileWizardDialog *standardWizardDialog = new Utils::FileWizardDialog(parent);
     standardWizardDialog->setWindowTitle(tr("New %1").arg(displayName()));
     setupWizard(standardWizardDialog);
-    standardWizardDialog->setPath(defaultPath);
-    foreach (QWizardPage *p, extensionPages)
+    standardWizardDialog->setPath(wizardDialogParameters.defaultPath());
+    foreach (QWizardPage *p, wizardDialogParameters.extensionPages())
         BaseFileWizard::applyExtensionPageShortTitle(standardWizardDialog, standardWizardDialog->addPage(p));
     return standardWizardDialog;
 }
 
+/*!
+    \brief Implemented to retrieve path and name and call generateFilesFromPath()
+*/
+
 GeneratedFiles StandardFileWizard::generateFiles(const QWizard *w,
                                                  QString *errorMessage) const
 {
