@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -34,18 +34,18 @@
 #include "actioncontainer.h"
 #include "command.h"
 #include "actionmanager_p.h"
-#include "coreimpl.h"
+#include "icore.h"
 #include "coreconstants.h"
 #include "editormanager.h"
 #include "externaltool.h"
 #include "toolsettings.h"
 #include "mimetypesettings.h"
 #include "fancytabwidget.h"
-#include "filemanager.h"
+#include "documentmanager.h"
 #include "generalsettings.h"
 #include "helpmanager.h"
 #include "ieditor.h"
-#include "ifilefactory.h"
+#include "idocumentfactory.h"
 #include "messagemanager.h"
 #include "modemanager.h"
 #include "mimedatabase.h"
@@ -85,27 +85,28 @@
 #include <utils/stringutils.h>
 #include <extensionsystem/pluginmanager.h>
 
-#include <QtCore/QDebug>
-#include <QtCore/QFileInfo>
-#include <QtCore/QSettings>
-#include <QtCore/QTimer>
-#include <QtCore/QtPlugin>
-#include <QtCore/QUrl>
-#include <QtCore/QDir>
-#include <QtCore/QFile>
+#include <QDebug>
+#include <QFileInfo>
+#include <QSettings>
+#include <QTimer>
+#include <QtPlugin>
+#include <QUrl>
+#include <QDir>
+#include <QFile>
+#include <QMimeData>
 
-#include <QtGui/QApplication>
-#include <QtGui/QCloseEvent>
-#include <QtGui/QMenu>
-#include <QtGui/QPixmap>
-#include <QtGui/QPrinter>
-#include <QtGui/QShortcut>
-#include <QtGui/QStatusBar>
-#include <QtGui/QWizard>
-#include <QtGui/QToolButton>
-#include <QtGui/QMessageBox>
-#include <QtGui/QMenuBar>
-#include <QtGui/QPushButton>
+#include <QApplication>
+#include <QCloseEvent>
+#include <QMenu>
+#include <QPixmap>
+#include <QPrinter>
+#include <QShortcut>
+#include <QStatusBar>
+#include <QWizard>
+#include <QToolButton>
+#include <QMessageBox>
+#include <QMenuBar>
+#include <QPushButton>
 
 /*
 #ifdef Q_OS_UNIX
@@ -113,7 +114,7 @@
 extern "C" void handleSigInt(int sig)
 {
     Q_UNUSED(sig)
-    Core::ICore::instance()->exit();
+    Core::ICore::exit();
     qDebug() << "SIGINT caught. Shutting down.";
 }
 #endif
@@ -126,11 +127,10 @@ enum { debugMainWindow = 0 };
 
 MainWindow::MainWindow() :
     EventFilteringMainWindow(),
-    m_coreImpl(new CoreImpl(this)),
+    m_coreImpl(new ICore(this)),
     m_additionalContexts(Constants::C_GLOBAL),
     m_settings(ExtensionSystem::PluginManager::instance()->settings()),
-    m_globalSettings(new QSettings(QSettings::IniFormat, QSettings::SystemScope,
-                             QLatin1String("Nokia"), QLatin1String("QtCreator"), this)),
+    m_globalSettings(ExtensionSystem::PluginManager::instance()->globalSettings()),
     m_settingsDatabase(new SettingsDatabase(QFileInfo(m_settings->fileName()).path(),
                                             QLatin1String("QtCreator"),
                                             this)),
@@ -138,7 +138,6 @@ MainWindow::MainWindow() :
     m_actionManager(new ActionManagerPrivate(this)),
     m_editorManager(0),
     m_externalToolManager(0),
-    m_fileManager(new FileManager(this)),
     m_progressManager(new ProgressManagerPrivate()),
     m_scriptManager(new ScriptManagerPrivate(this)),
     m_variableManager(new VariableManager),
@@ -165,22 +164,22 @@ MainWindow::MainWindow() :
     m_optionsAction(0),
     m_toggleSideBarAction(0),
     m_toggleFullScreenAction(0),
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     m_minimizeAction(0),
     m_zoomAction(0),
 #endif
     m_toggleSideBarButton(new QToolButton)
 {
+    (void) new DocumentManager(this);
     OutputPaneManager::create();
 
     setWindowTitle(tr("Qt Creator"));
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
     QApplication::setWindowIcon(QIcon(QLatin1String(Constants::ICON_QTLOGO_128)));
 #endif
     QCoreApplication::setApplicationName(QLatin1String("QtCreator"));
     QCoreApplication::setApplicationVersion(QLatin1String(Core::Constants::IDE_VERSION_LONG));
-    QCoreApplication::setOrganizationName(QLatin1String("Nokia"));
-    QSettings::setDefaultFormat(QSettings::IniFormat);
+    QCoreApplication::setOrganizationName(QLatin1String(Constants::IDE_SETTINGSVARIANT_STR));
     QString baseName = QApplication::style()->objectName();
 #ifdef Q_WS_X11
     if (baseName == QLatin1String("windows")) {
@@ -211,9 +210,9 @@ MainWindow::MainWindow() :
     m_modeManager->addWidget(m_progressManager->progressView());
     m_statusBarManager = new StatusBarManager(this);
     m_messageManager = new MessageManager;
-    m_editorManager = new EditorManager(m_coreImpl, this);
+    m_editorManager = new EditorManager(this);
     m_editorManager->hide();
-    m_externalToolManager = new ExternalToolManager(m_coreImpl);
+    m_externalToolManager = new ExternalToolManager();
     setCentralWidget(m_modeStack);
 
     connect(QApplication::instance(), SIGNAL(focusChanged(QWidget*,QWidget*)),
@@ -228,6 +227,13 @@ MainWindow::MainWindow() :
 
     statusBar()->setProperty("p_styled", true);
     setAcceptDrops(true);
+
+    m_autoSaveSessionTimer = new QTimer(this);
+    m_autoSaveSessionTimer->setSingleShot(true);
+    m_autoSaveSessionTimer->setInterval(10000);
+    m_autoSaveSessionTimer->start();
+    connect(m_autoSaveSessionTimer, SIGNAL(timeout()),
+            m_coreImpl, SIGNAL(saveSettingsRequested()));
 }
 
 void MainWindow::setSidebarVisible(bool visible)
@@ -253,6 +259,16 @@ void MainWindow::setOverrideColor(const QColor &color)
     m_overrideColor = color;
 }
 
+bool MainWindow::isPresentationModeEnabled()
+{
+    return m_actionManager->isPresentationModeEnabled();
+}
+
+void MainWindow::setPresentationModeEnabled(bool enabled)
+{
+    m_actionManager->setPresentationModeEnabled(enabled);
+}
+
 MainWindow::~MainWindow()
 {
     ExtensionSystem::PluginManager *pm = ExtensionSystem::PluginManager::instance();
@@ -363,11 +379,12 @@ void MainWindow::extensionsInitialized()
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
+    m_autoSaveSessionTimer->stop();
     emit m_coreImpl->saveSettingsRequested();
 
     // Save opened files
     bool cancelled;
-    QList<IFile*> notSaved = fileManager()->saveModifiedFiles(fileManager()->modifiedFiles(), &cancelled);
+    QList<IDocument*> notSaved = DocumentManager::saveModifiedDocuments(DocumentManager::modifiedDocuments(), &cancelled);
     if (cancelled || !notSaved.isEmpty()) {
         event->ignore();
         return;
@@ -467,7 +484,7 @@ void MainWindow::registerDefaultContainers()
 
     ActionContainer *menubar = am->createMenuBar(Constants::MENU_BAR);
 
-#ifndef Q_WS_MAC // System menu bar on Mac
+#ifndef Q_OS_MAC // System menu bar on Mac
     setMenuBar(menubar->menuBar());
 #endif
     menubar->appendGroup(Constants::G_FILE);
@@ -527,12 +544,11 @@ void MainWindow::registerDefaultContainers()
 }
 
 static Command *createSeparator(ActionManager *am, QObject *parent,
-                                const QString &name,
-                                const Context &context)
+                                const Id &id, const Context &context)
 {
     QAction *tmpaction = new QAction(parent);
     tmpaction->setSeparator(true);
-    Command *cmd = am->registerAction(tmpaction, name, context);
+    Command *cmd = am->registerAction(tmpaction, id, context);
     return cmd;
 }
 
@@ -548,30 +564,30 @@ void MainWindow::registerDefaultActions()
     Context globalContext(Constants::C_GLOBAL);
 
     // File menu separators
-    Command *cmd = createSeparator(am, this, QLatin1String("QtCreator.File.Sep.Save"), globalContext);
+    Command *cmd = createSeparator(am, this, Id("QtCreator.File.Sep.Save"), globalContext);
     mfile->addAction(cmd, Constants::G_FILE_SAVE);
 
-    cmd =  createSeparator(am, this, QLatin1String("QtCreator.File.Sep.Print"), globalContext);
-    QIcon icon = QIcon::fromTheme(QLatin1String("edit-cut"), QIcon(Constants::ICON_CUT));
+    cmd =  createSeparator(am, this, Id("QtCreator.File.Sep.Print"), globalContext);
+    QIcon icon = QIcon::fromTheme(QLatin1String("edit-cut"), QIcon(QLatin1String(Constants::ICON_CUT)));
     mfile->addAction(cmd, Constants::G_FILE_PRINT);
 
-    cmd =  createSeparator(am, this, QLatin1String("QtCreator.File.Sep.Close"), globalContext);
+    cmd =  createSeparator(am, this, Id("QtCreator.File.Sep.Close"), globalContext);
     mfile->addAction(cmd, Constants::G_FILE_CLOSE);
 
-    cmd = createSeparator(am, this, QLatin1String("QtCreator.File.Sep.Other"), globalContext);
+    cmd = createSeparator(am, this, Id("QtCreator.File.Sep.Other"), globalContext);
     mfile->addAction(cmd, Constants::G_FILE_OTHER);
 
     // Edit menu separators
-    cmd = createSeparator(am, this, QLatin1String("QtCreator.Edit.Sep.CopyPaste"), globalContext);
+    cmd = createSeparator(am, this, Id("QtCreator.Edit.Sep.CopyPaste"), globalContext);
     medit->addAction(cmd, Constants::G_EDIT_COPYPASTE);
 
-    cmd = createSeparator(am, this, QLatin1String("QtCreator.Edit.Sep.SelectAll"), globalContext);
+    cmd = createSeparator(am, this, Id("QtCreator.Edit.Sep.SelectAll"), globalContext);
     medit->addAction(cmd, Constants::G_EDIT_SELECTALL);
 
-    cmd = createSeparator(am, this, QLatin1String("QtCreator.Edit.Sep.Find"), globalContext);
+    cmd = createSeparator(am, this, Id("QtCreator.Edit.Sep.Find"), globalContext);
     medit->addAction(cmd, Constants::G_EDIT_FIND);
 
-    cmd = createSeparator(am, this, QLatin1String("QtCreator.Edit.Sep.Advanced"), globalContext);
+    cmd = createSeparator(am, this, Id("QtCreator.Edit.Sep.Advanced"), globalContext);
     medit->addAction(cmd, Constants::G_EDIT_ADVANCED);
 
     // Return to editor shortcut: Note this requires Qt to fix up
@@ -582,7 +598,7 @@ void MainWindow::registerDefaultActions()
     connect(m_focusToEditor, SIGNAL(activated()), this, SLOT(setFocusToEditor()));
 
     // New File Action
-    icon = QIcon::fromTheme(QLatin1String("document-new"), QIcon(Constants::ICON_NEWFILE));
+    icon = QIcon::fromTheme(QLatin1String("document-new"), QIcon(QLatin1String(Constants::ICON_NEWFILE)));
     m_newAction = new QAction(icon, tr("&New File or Project..."), this);
     cmd = am->registerAction(m_newAction, Constants::NEW, globalContext);
     cmd->setDefaultKeySequence(QKeySequence::New);
@@ -590,7 +606,7 @@ void MainWindow::registerDefaultActions()
     connect(m_newAction, SIGNAL(triggered()), this, SLOT(newFile()));
 
     // Open Action
-    icon = QIcon::fromTheme(QLatin1String("document-open"), QIcon(Constants::ICON_OPENFILE));
+    icon = QIcon::fromTheme(QLatin1String("document-open"), QIcon(QLatin1String(Constants::ICON_OPENFILE)));
     m_openAction = new QAction(icon, tr("&Open File or Project..."), this);
     cmd = am->registerAction(m_openAction, Constants::OPEN, globalContext);
     cmd->setDefaultKeySequence(QKeySequence::Open);
@@ -610,13 +626,13 @@ void MainWindow::registerDefaultActions()
     ac->setOnAllDisabledBehavior(ActionContainer::Show);
 
     // Save Action
-    icon = QIcon::fromTheme(QLatin1String("document-save"), QIcon(Constants::ICON_SAVEFILE));
+    icon = QIcon::fromTheme(QLatin1String("document-save"), QIcon(QLatin1String(Constants::ICON_SAVEFILE)));
     QAction *tmpaction = new QAction(icon, tr("&Save"), this);
     tmpaction->setEnabled(false);
     cmd = am->registerAction(tmpaction, Constants::SAVE, globalContext);
     cmd->setDefaultKeySequence(QKeySequence::Save);
     cmd->setAttribute(Command::CA_UpdateText);
-    cmd->setDefaultText(tr("&Save"));
+    cmd->setDescription(tr("Save"));
     mfile->addAction(cmd, Constants::G_FILE_SAVE);
 
     // Save As Action
@@ -624,17 +640,17 @@ void MainWindow::registerDefaultActions()
     tmpaction = new QAction(icon, tr("Save &As..."), this);
     tmpaction->setEnabled(false);
     cmd = am->registerAction(tmpaction, Constants::SAVEAS, globalContext);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     cmd->setDefaultKeySequence(QKeySequence(tr("Ctrl+Shift+S")));
 #endif
     cmd->setAttribute(Command::CA_UpdateText);
-    cmd->setDefaultText(tr("Save &As..."));
+    cmd->setDescription(tr("Save As..."));
     mfile->addAction(cmd, Constants::G_FILE_SAVE);
 
     // SaveAll Action
     m_saveAllAction = new QAction(tr("Save A&ll"), this);
     cmd = am->registerAction(m_saveAllAction, Constants::SAVEALL, globalContext);
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
     cmd->setDefaultKeySequence(QKeySequence(tr("Ctrl+Shift+S")));
 #endif
     mfile->addAction(cmd, Constants::G_FILE_SAVE);
@@ -657,27 +673,27 @@ void MainWindow::registerDefaultActions()
     connect(m_exitAction, SIGNAL(triggered()), this, SLOT(exit()));
 
     // Undo Action
-    icon = QIcon::fromTheme(QLatin1String("edit-undo"), QIcon(Constants::ICON_UNDO));
+    icon = QIcon::fromTheme(QLatin1String("edit-undo"), QIcon(QLatin1String(Constants::ICON_UNDO)));
     tmpaction = new QAction(icon, tr("&Undo"), this);
     cmd = am->registerAction(tmpaction, Constants::UNDO, globalContext);
     cmd->setDefaultKeySequence(QKeySequence::Undo);
     cmd->setAttribute(Command::CA_UpdateText);
-    cmd->setDefaultText(tr("&Undo"));
+    cmd->setDescription(tr("Undo"));
     medit->addAction(cmd, Constants::G_EDIT_UNDOREDO);
     tmpaction->setEnabled(false);
 
     // Redo Action
-    icon = QIcon::fromTheme(QLatin1String("edit-redo"), QIcon(Constants::ICON_REDO));
+    icon = QIcon::fromTheme(QLatin1String("edit-redo"), QIcon(QLatin1String(Constants::ICON_REDO)));
     tmpaction = new QAction(icon, tr("&Redo"), this);
     cmd = am->registerAction(tmpaction, Constants::REDO, globalContext);
     cmd->setDefaultKeySequence(QKeySequence::Redo);
     cmd->setAttribute(Command::CA_UpdateText);
-    cmd->setDefaultText(tr("&Redo"));
+    cmd->setDescription(tr("Redo"));
     medit->addAction(cmd, Constants::G_EDIT_UNDOREDO);
     tmpaction->setEnabled(false);
 
     // Cut Action
-    icon = QIcon::fromTheme(QLatin1String("edit-cut"), QIcon(Constants::ICON_CUT));
+    icon = QIcon::fromTheme(QLatin1String("edit-cut"), QIcon(QLatin1String(Constants::ICON_CUT)));
     tmpaction = new QAction(icon, tr("Cu&t"), this);
     cmd = am->registerAction(tmpaction, Constants::CUT, globalContext);
     cmd->setDefaultKeySequence(QKeySequence::Cut);
@@ -685,7 +701,7 @@ void MainWindow::registerDefaultActions()
     tmpaction->setEnabled(false);
 
     // Copy Action
-    icon = QIcon::fromTheme(QLatin1String("edit-copy"), QIcon(Constants::ICON_COPY));
+    icon = QIcon::fromTheme(QLatin1String("edit-copy"), QIcon(QLatin1String(Constants::ICON_COPY)));
     tmpaction = new QAction(icon, tr("&Copy"), this);
     cmd = am->registerAction(tmpaction, Constants::COPY, globalContext);
     cmd->setDefaultKeySequence(QKeySequence::Copy);
@@ -693,7 +709,7 @@ void MainWindow::registerDefaultActions()
     tmpaction->setEnabled(false);
 
     // Paste Action
-    icon = QIcon::fromTheme(QLatin1String("edit-paste"), QIcon(Constants::ICON_PASTE));
+    icon = QIcon::fromTheme(QLatin1String("edit-paste"), QIcon(QLatin1String(Constants::ICON_PASTE)));
     tmpaction = new QAction(icon, tr("&Paste"), this);
     cmd = am->registerAction(tmpaction, Constants::PASTE, globalContext);
     cmd->setDefaultKeySequence(QKeySequence::Paste);
@@ -718,22 +734,22 @@ void MainWindow::registerDefaultActions()
 
     // Options Action
     mtools->appendGroup(Constants::G_TOOLS_OPTIONS);
-    cmd = createSeparator(am, this, QLatin1String("QtCreator.Tools.Sep.Options"), globalContext);
+    cmd = createSeparator(am, this, Id("QtCreator.Tools.Sep.Options"), globalContext);
     mtools->addAction(cmd, Constants::G_TOOLS_OPTIONS);
     m_optionsAction = new QAction(tr("&Options..."), this);
     cmd = am->registerAction(m_optionsAction, Constants::OPTIONS, globalContext);
-#ifdef Q_WS_MAC
-    cmd->setDefaultKeySequence(QKeySequence("Ctrl+,"));
+#ifdef Q_OS_MAC
+    cmd->setDefaultKeySequence(QKeySequence(tr("Ctrl+,")));
     cmd->action()->setMenuRole(QAction::PreferencesRole);
 #endif
     mtools->addAction(cmd, Constants::G_TOOLS_OPTIONS);
     connect(m_optionsAction, SIGNAL(triggered()), this, SLOT(showOptionsDialog()));
 
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     // Minimize Action
     m_minimizeAction = new QAction(tr("Minimize"), this);
     cmd = am->registerAction(m_minimizeAction, Constants::MINIMIZE_WINDOW, globalContext);
-    cmd->setDefaultKeySequence(QKeySequence("Ctrl+M"));
+    cmd->setDefaultKeySequence(QKeySequence(tr("Ctrl+M")));
     mwindow->addAction(cmd, Constants::G_WINDOW_SIZE);
     connect(m_minimizeAction, SIGNAL(triggered()), this, SLOT(showMinimized()));
 
@@ -744,32 +760,32 @@ void MainWindow::registerDefaultActions()
     connect(m_zoomAction, SIGNAL(triggered()), this, SLOT(showMaximized()));
 
     // Window separator
-    cmd = createSeparator(am, this, QLatin1String("QtCreator.Window.Sep.Size"), globalContext);
+    cmd = createSeparator(am, this, Id("QtCreator.Window.Sep.Size"), globalContext);
     mwindow->addAction(cmd, Constants::G_WINDOW_SIZE);
 #endif
 
     // Show Sidebar Action
-    m_toggleSideBarAction = new QAction(QIcon(Constants::ICON_TOGGLE_SIDEBAR),
+    m_toggleSideBarAction = new QAction(QIcon(QLatin1String(Constants::ICON_TOGGLE_SIDEBAR)),
                                         tr("Show Sidebar"), this);
     m_toggleSideBarAction->setCheckable(true);
     cmd = am->registerAction(m_toggleSideBarAction, Constants::TOGGLE_SIDEBAR, globalContext);
     cmd->setAttribute(Command::CA_UpdateText);
-#ifdef Q_WS_MAC
-    cmd->setDefaultKeySequence(QKeySequence("Ctrl+0"));
+#ifdef Q_OS_MAC
+    cmd->setDefaultKeySequence(QKeySequence(tr("Ctrl+0")));
 #else
-    cmd->setDefaultKeySequence(QKeySequence("Alt+0"));
+    cmd->setDefaultKeySequence(QKeySequence(tr("Alt+0")));
 #endif
     connect(m_toggleSideBarAction, SIGNAL(triggered(bool)), this, SLOT(setSidebarVisible(bool)));
     m_toggleSideBarButton->setDefaultAction(cmd->action());
     mwindow->addAction(cmd, Constants::G_WINDOW_VIEWS);
     m_toggleSideBarAction->setEnabled(false);
 
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
     // Full Screen Action
     m_toggleFullScreenAction = new QAction(tr("Full Screen"), this);
     m_toggleFullScreenAction->setCheckable(true);
     cmd = am->registerAction(m_toggleFullScreenAction, Constants::TOGGLE_FULLSCREEN, globalContext);
-    cmd->setDefaultKeySequence(QKeySequence("Ctrl+Shift+F11"));
+    cmd->setDefaultKeySequence(QKeySequence(tr("Ctrl+Shift+F11")));
     mwindow->addAction(cmd, Constants::G_WINDOW_SIZE);
     connect(m_toggleFullScreenAction, SIGNAL(triggered(bool)), this, SLOT(setFullScreen(bool)));
 #endif
@@ -781,7 +797,7 @@ void MainWindow::registerDefaultActions()
 
     // About IDE Action
     icon = QIcon::fromTheme(QLatin1String("help-about"));
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     tmpaction = new QAction(icon, tr("About &Qt Creator"), this); // it's convention not to add dots to the about menu
 #else
     tmpaction = new QAction(icon, tr("About &Qt Creator..."), this);
@@ -789,7 +805,7 @@ void MainWindow::registerDefaultActions()
     cmd = am->registerAction(tmpaction, Constants::ABOUT_QTCREATOR, globalContext);
     mhelp->addAction(cmd, Constants::G_HELP_ABOUT);
     tmpaction->setEnabled(true);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     cmd->action()->setMenuRole(QAction::ApplicationSpecificRole);
 #endif
     connect(tmpaction, SIGNAL(triggered()), this,  SLOT(aboutQtCreator()));
@@ -799,7 +815,7 @@ void MainWindow::registerDefaultActions()
     cmd = am->registerAction(tmpaction, Constants::ABOUT_PLUGINS, globalContext);
     mhelp->addAction(cmd, Constants::G_HELP_ABOUT);
     tmpaction->setEnabled(true);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     cmd->action()->setMenuRole(QAction::ApplicationSpecificRole);
 #endif
     connect(tmpaction, SIGNAL(triggered()), this,  SLOT(aboutPlugins()));
@@ -810,7 +826,7 @@ void MainWindow::registerDefaultActions()
 //    tmpaction->setEnabled(true);
 //    connect(tmpaction, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
     // About sep
-#ifndef Q_WS_MAC // doesn't have the "About" actions in the Help menu
+#ifndef Q_OS_MAC // doesn't have the "About" actions in the Help menu
     tmpaction = new QAction(this);
     tmpaction->setSeparator(true);
     cmd = am->registerAction(tmpaction, "QtCreator.Help.Sep.About", globalContext);
@@ -828,25 +844,25 @@ void MainWindow::openFile()
     openFiles(editorManager()->getOpenFileNames(), ICore::SwitchMode);
 }
 
-static QList<IFileFactory*> getNonEditorFileFactories()
+static QList<IDocumentFactory*> getNonEditorDocumentFactories()
 {
-    const QList<IFileFactory*> allFileFactories =
-        ExtensionSystem::PluginManager::instance()->getObjects<IFileFactory>();
-    QList<IFileFactory*> nonEditorFileFactories;
-    foreach (IFileFactory *factory, allFileFactories) {
+    const QList<IDocumentFactory*> allFileFactories =
+        ExtensionSystem::PluginManager::instance()->getObjects<IDocumentFactory>();
+    QList<IDocumentFactory*> nonEditorFileFactories;
+    foreach (IDocumentFactory *factory, allFileFactories) {
         if (!qobject_cast<IEditorFactory *>(factory))
             nonEditorFileFactories.append(factory);
     }
     return nonEditorFileFactories;
 }
 
-static IFileFactory *findFileFactory(const QList<IFileFactory*> &fileFactories,
+static IDocumentFactory *findDocumentFactory(const QList<IDocumentFactory*> &fileFactories,
                                      const MimeDatabase *db,
                                      const QFileInfo &fi)
 {
     if (const MimeType mt = db->findByFile(fi)) {
         const QString type = mt.type();
-        foreach (IFileFactory *factory, fileFactories) {
+        foreach (IDocumentFactory *factory, fileFactories) {
             if (factory->mimeTypes().contains(type))
                 return factory;
         }
@@ -857,24 +873,24 @@ static IFileFactory *findFileFactory(const QList<IFileFactory*> &fileFactories,
 // opens either an editor or loads a project
 void MainWindow::openFiles(const QStringList &fileNames, ICore::OpenFilesFlags flags)
 {
-    QList<IFileFactory*> nonEditorFileFactories = getNonEditorFileFactories();
+    QList<IDocumentFactory*> nonEditorFileFactories = getNonEditorDocumentFactories();
 
     foreach (const QString &fileName, fileNames) {
         const QFileInfo fi(fileName);
         const QString absoluteFilePath = fi.absoluteFilePath();
-        if (IFileFactory *fileFactory = findFileFactory(nonEditorFileFactories, mimeDatabase(), fi)) {
-            Core::IFile *file = fileFactory->open(absoluteFilePath);
-            if (!file && (flags & ICore::StopOnLoadFail))
+        if (IDocumentFactory *documentFactory = findDocumentFactory(nonEditorFileFactories, mimeDatabase(), fi)) {
+            Core::IDocument *document = documentFactory->open(absoluteFilePath);
+            if (!document && (flags & ICore::StopOnLoadFail))
                 return;
-            if (file && (flags & ICore::SwitchMode))
-                Core::ModeManager::instance()->activateMode(Core::Constants::MODE_EDIT);
+            if (document && (flags & ICore::SwitchMode))
+                ModeManager::activateMode(QLatin1String(Core::Constants::MODE_EDIT));
         } else {
             QFlags<EditorManager::OpenEditorFlag> emFlags;
             if (flags & ICore::SwitchMode)
                 emFlags = EditorManager::ModeSwitch;
             if (flags & ICore::CanContainLineNumbers)
                 emFlags |=  EditorManager::CanContainLineNumber;
-            Core::IEditor *editor = editorManager()->openEditor(absoluteFilePath, QString(), emFlags);
+            Core::IEditor *editor = editorManager()->openEditor(absoluteFilePath, Id(), emFlags);
             if (!editor && (flags & ICore::StopOnLoadFail))
                 return;
         }
@@ -887,9 +903,12 @@ void MainWindow::setFocusToEditor()
 
     // give focus to the editor if we have one
     if (IEditor *editor = m_editorManager->currentEditor()) {
-        if (qApp->focusWidget() != editor->widget()) {
-            editor->widget()->setFocus();
-            focusWasMovedToEditor = editor->widget()->hasFocus();
+        if (qApp->focusWidget() != editor->widget()->focusWidget()) {
+            QWidget *w = editor->widget()->focusWidget();
+            if (!w)
+                w = editor->widget();
+            w->setFocus();
+            focusWasMovedToEditor = w->hasFocus();
         }
     }
 
@@ -904,7 +923,6 @@ void MainWindow::setFocusToEditor()
     if (focusWasMovedToEditor)
         return;
 
-
     // check for some visible bar which we want to hide
     bool stuffVisible =
             (FindToolBarPlaceHolder::getCurrent() &&
@@ -922,17 +940,18 @@ void MainWindow::setFocusToEditor()
     }
 
     // switch to edit mode if necessary
-    m_coreImpl->modeManager()->activateMode(QLatin1String(Constants::MODE_EDIT));
-
+    ModeManager::activateMode(QLatin1String(Constants::MODE_EDIT));
 }
 
 void MainWindow::showNewItemDialog(const QString &title,
                                           const QList<IWizard *> &wizards,
-                                          const QString &defaultLocation)
+                                          const QString &defaultLocation,
+                                          const QVariantMap &extraVariables)
 {
     // Scan for wizards matching the filter and pick one. Don't show
     // dialog if there is only one.
     IWizard *wizard = 0;
+    QString selectedPlatform;
     switch (wizards.size()) {
     case 0:
         break;
@@ -944,6 +963,7 @@ void MainWindow::showNewItemDialog(const QString &title,
         dlg.setWizards(wizards);
         dlg.setWindowTitle(title);
         wizard = dlg.showDialog();
+        selectedPlatform = dlg.selectedPlatform();
     }
         break;
     }
@@ -953,22 +973,21 @@ void MainWindow::showNewItemDialog(const QString &title,
 
     QString path = defaultLocation;
     if (path.isEmpty()) {
-        const FileManager *fm = m_coreImpl->fileManager();
         switch (wizard->kind()) {
         case IWizard::ProjectWizard:
             // Project wizards: Check for projects directory or
             // use last visited directory of file dialog. Never start
             // at current.
-            path = fm->useProjectsDirectory() ?
-                       fm->projectsDirectory() :
-                       fm->fileDialogLastVisitedDirectory();
+            path = DocumentManager::useProjectsDirectory() ?
+                       DocumentManager::projectsDirectory() :
+                       DocumentManager::fileDialogLastVisitedDirectory();
             break;
         default:
-            path = fm->fileDialogInitialDirectory();
+            path = DocumentManager::fileDialogInitialDirectory();
             break;
         }
     }
-    wizard->runWizard(path, this);
+    wizard->runWizard(path, this, selectedPlatform, extraVariables);
 }
 
 bool MainWindow::showOptionsDialog(const QString &category,
@@ -984,7 +1003,7 @@ bool MainWindow::showOptionsDialog(const QString &category,
 
 void MainWindow::saveAll()
 {
-    m_fileManager->saveModifiedFilesSilently(m_fileManager->modifiedFiles());
+    DocumentManager::saveModifiedDocumentsSilently(DocumentManager::modifiedDocuments());
     emit m_coreImpl->saveSettingsRequested();
 }
 
@@ -1019,11 +1038,6 @@ ActionManager *MainWindow::actionManager() const
     return m_actionManager;
 }
 
-FileManager *MainWindow::fileManager() const
-{
-    return m_fileManager;
-}
-
 MessageManager *MainWindow::messageManager() const
 {
     return m_messageManager;
@@ -1117,7 +1131,7 @@ void MainWindow::changeEvent(QEvent *e)
             emit windowActivated();
         }
     } else if (e->type() == QEvent::WindowStateChange) {
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
         bool minimized = isMinimized();
         if (debugMainWindow)
             qDebug() << "main window state changed to minimized=" << minimized;
@@ -1227,7 +1241,7 @@ void MainWindow::writeSettings()
 
     m_settings->endGroup();
 
-    m_fileManager->saveSettings();
+    DocumentManager::saveSettings();
     m_actionManager->saveSettings(m_settings);
     m_editorManager->saveSettings();
     m_navigationWidget->saveSettings(m_settings);
@@ -1287,7 +1301,7 @@ void MainWindow::aboutToShowRecentFiles()
     aci->menu()->clear();
 
     bool hasRecentFiles = false;
-    foreach (const FileManager::RecentFile &file, m_fileManager->recentFiles()) {
+    foreach (const DocumentManager::RecentFile &file, DocumentManager::recentFiles()) {
         hasRecentFiles = true;
         QAction *action = aci->menu()->addAction(
                     QDir::toNativeSeparators(Utils::withTildeHomePath(file.first)));
@@ -1301,14 +1315,14 @@ void MainWindow::aboutToShowRecentFiles()
         aci->menu()->addSeparator();
         QAction *action = aci->menu()->addAction(QCoreApplication::translate(
                                                      "Core", Core::Constants::TR_CLEAR_MENU));
-        connect(action, SIGNAL(triggered()), m_fileManager, SLOT(clearRecentFiles()));
+        connect(action, SIGNAL(triggered()), DocumentManager::instance(), SLOT(clearRecentFiles()));
     }
 }
 
 void MainWindow::openRecentFile()
 {
     if (const QAction *action = qobject_cast<const QAction*>(sender())) {
-        const FileManager::RecentFile file = action->data().value<FileManager::RecentFile>();
+        const DocumentManager::RecentFile file = action->data().value<DocumentManager::RecentFile>();
         editorManager()->openEditor(file.first, file.second, Core::EditorManager::ModeSwitch);
     }
 }
