@@ -2,30 +2,29 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** No Commercial Usage
-**
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
 **
 ** GNU Lesser General Public License Usage
 **
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this file.
+** Please review the following information to ensure the GNU Lesser General
+** Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
+** Other Usage
+**
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at qt-info@nokia.com.
 **
@@ -35,6 +34,10 @@
 #include <cplusplus/Overview.h>
 
 #include "cppmodelmanager.h"
+#include "cppcompletionassist.h"
+#include "cpphighlightingsupport.h"
+#include "cpphighlightingsupportinternal.h"
+#include "abstracteditorsupport.h"
 #ifndef ICHECK_BUILD
 #  include "cpptoolsconstants.h"
 #  include "cpptoolseditorsupport.h"
@@ -45,7 +48,7 @@
 #include <QtConcurrentRun>
 #ifndef ICHECK_BUILD
 #  include <QFutureSynchronizer>
-#  include <qtconcurrent/runextensions.h>
+#  include <utils/runextensions.h>
 #  include <texteditor/itexteditor.h>
 #  include <texteditor/basetexteditor.h>
 #  include <projectexplorer/project.h>
@@ -76,19 +79,48 @@
 #include <Token.h>
 #include <Parser.h>
 #include <Control.h>
+#include <CoreTypes.h>
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QDebug>
-#include <QtCore/QMutexLocker>
-#include <QtCore/QTime>
-#include <QtCore/QTimer>
+#include <QCoreApplication>
+#include <QDebug>
+#include <QMutexLocker>
+#include <QTime>
+#include <QTimer>
 #include <QtConcurrentMap>
 
-#include <QtGui/QTextBlock>
+#include <QTextBlock>
 
 #include <iostream>
 #include <sstream>
 
+namespace CPlusPlus {
+uint qHash(const CppModelManagerInterface::ProjectPart &p)
+{
+    uint h = qHash(p.defines) ^ p.language ^ p.flags;
+
+    foreach (const QString &i, p.includePaths)
+        h ^= qHash(i);
+
+    foreach (const QString &f, p.frameworkPaths)
+        h ^= qHash(f);
+
+    return h;
+}
+bool operator==(const CppModelManagerInterface::ProjectPart &p1,
+                const CppModelManagerInterface::ProjectPart &p2)
+{
+    if (p1.defines != p2.defines)
+        return false;
+    if (p1.language != p2.language)
+        return false;
+    if (p1.flags != p2.flags)
+        return false;
+    if (p1.includePaths != p2.includePaths)
+        return false;
+    return p1.frameworkPaths == p2.frameworkPaths;
+}
+} // namespace CPlusPlus
+
 using namespace CppTools;
 using namespace CppTools::Internal;
 using namespace CPlusPlus;
@@ -157,14 +189,16 @@ static const char pp_configuration[] =
     "#define __cdecl\n"
     "#define __stdcall\n"
     "#define QT_WA(x) x\n"
-    "#define API\n"
-    "#define WINAPI\n"
     "#define CALLBACK\n"
     "#define STDMETHODCALLTYPE\n"
     "#define __RPC_FAR\n"
-    "#define APIENTRY\n"
     "#define __declspec(a)\n"
-    "#define STDMETHOD(method) virtual HRESULT STDMETHODCALLTYPE method\n";
+    "#define STDMETHOD(method) virtual HRESULT STDMETHODCALLTYPE method\n"
+    "#define __try try\n"
+    "#define __except catch\n"
+    "#define __finally\n"
+    "#define __inline inline\n"
+    "#define __forceinline inline\n";
 
 #ifndef ICHECK_BUILD
 CppPreprocessor::CppPreprocessor(QPointer<CppModelManager> modelManager)
@@ -172,7 +206,9 @@ CppPreprocessor::CppPreprocessor(QPointer<CppModelManager> modelManager)
       m_modelManager(modelManager),
       preprocess(this, &env),
       m_revision(0)
-{ }
+{
+    preprocess.setKeepComments(true);
+}
 
 #else
 
@@ -189,7 +225,7 @@ CppPreprocessor::~CppPreprocessor()
 void CppPreprocessor::setRevision(unsigned revision)
 { m_revision = revision; }
 
-void CppPreprocessor::setWorkingCopy(const CppTools::CppModelManagerInterface::WorkingCopy &workingCopy)
+void CppPreprocessor::setWorkingCopy(const CppModelManagerInterface::WorkingCopy &workingCopy)
 { m_workingCopy = workingCopy; }
 
 void CppPreprocessor::setIncludePaths(const QStringList &includePaths)
@@ -289,13 +325,11 @@ public:
     void operator()()
     {
         _doc->check(_mode);
-        _doc->releaseTranslationUnit();
-
-        if (_mode == Document::FastCheck)
-            _doc->control()->squeeze();
 
         if (_modelManager)
             _modelManager->emitDocumentUpdated(_doc); // ### TODO: compress
+
+        _doc->releaseSourceAndAST();
     }
 };
 } // end of anonymous namespace
@@ -331,7 +365,7 @@ bool CppPreprocessor::includeFile(const QString &absoluteFilePath, QString *resu
         return false;
 
     QFile file(absoluteFilePath);
-    if (file.open(QFile::ReadOnly)) {
+    if (file.open(QFile::ReadOnly | QFile::Text)) {
         m_included.insert(absoluteFilePath);
         QTextStream stream(&file);
         const QString contents = stream.readAll();
@@ -586,9 +620,9 @@ void CppPreprocessor::sourceNeeded(QString &fileName, IncludeType type, unsigned
 
     const QByteArray preprocessedCode = preprocess(fileName, contents);
 
-    doc->setSource(preprocessedCode);
+    doc->setUtf8Source(preprocessedCode);
+    doc->keepSourceAndAST();
     doc->tokenize();
-    doc->releaseSource();
 
     snapshot.insert(doc);
     m_todo.remove(fileName);
@@ -600,6 +634,7 @@ void CppPreprocessor::sourceNeeded(QString &fileName, IncludeType type, unsigned
 
     (void) switchDocument(previousDoc);
 #else
+    doc->releaseSource();
     Document::CheckMode mode = Document::FastCheck;
     mode = Document::FullCheck;
     doc->parse();
@@ -617,7 +652,7 @@ Document::Ptr CppPreprocessor::switchDocument(Document::Ptr doc)
 }
 
 #ifndef ICHECK_BUILD
-void CppTools::CppModelManagerInterface::updateModifiedSourceFiles()
+void CppModelManager::updateModifiedSourceFiles()
 {
     const Snapshot snapshot = this->snapshot();
     QStringList sourceFiles;
@@ -636,11 +671,10 @@ void CppTools::CppModelManagerInterface::updateModifiedSourceFiles()
     updateSourceFiles(sourceFiles);
 }
 
-CppTools::CppModelManagerInterface *CppTools::CppModelManagerInterface::instance()
+CppModelManager *CppModelManager::instance()
 {
     ExtensionSystem::PluginManager *pluginManager = ExtensionSystem::PluginManager::instance();
-    return pluginManager->getObject<CppTools::CppModelManagerInterface>();
-
+    return pluginManager->getObject<CppModelManager>();
 }
 
 
@@ -662,7 +696,6 @@ CppModelManager::CppModelManager(QObject *parent)
     m_revision = 0;
     m_synchronizer.setCancelOnWait(true);
 
-    m_core = Core::ICore::instance(); // FIXME
     m_dirty = true;
 
     ProjectExplorer::ProjectExplorerPlugin *pe =
@@ -671,8 +704,6 @@ CppModelManager::CppModelManager(QObject *parent)
     QTC_ASSERT(pe, return);
 
     ProjectExplorer::SessionManager *session = pe->session();
-    QTC_ASSERT(session, return);
-
     m_updateEditorSelectionsTimer = new QTimer(this);
     m_updateEditorSelectionsTimer->setInterval(500);
     m_updateEditorSelectionsTimer->setSingleShot(true);
@@ -682,10 +713,10 @@ CppModelManager::CppModelManager(QObject *parent)
     connect(session, SIGNAL(projectAdded(ProjectExplorer::Project*)),
             this, SLOT(onProjectAdded(ProjectExplorer::Project*)));
 
-    connect(session, SIGNAL(aboutToRemoveProject(ProjectExplorer::Project *)),
-            this, SLOT(onAboutToRemoveProject(ProjectExplorer::Project *)));
+    connect(session, SIGNAL(aboutToRemoveProject(ProjectExplorer::Project*)),
+            this, SLOT(onAboutToRemoveProject(ProjectExplorer::Project*)));
 
-    connect(session, SIGNAL(aboutToUnloadSession()),
+    connect(session, SIGNAL(aboutToUnloadSession(QString)),
             this, SLOT(onAboutToUnloadSession()));
 
     qRegisterMetaType<CPlusPlus::Document::Ptr>("CPlusPlus::Document::Ptr");
@@ -693,17 +724,29 @@ CppModelManager::CppModelManager(QObject *parent)
     // thread connections
     connect(this, SIGNAL(documentUpdated(CPlusPlus::Document::Ptr)),
             this, SLOT(onDocumentUpdated(CPlusPlus::Document::Ptr)));
+    connect(this, SIGNAL(extraDiagnosticsUpdated(QString)),
+            this, SLOT(onExtraDiagnosticsUpdated(QString)));
 
     // Listen for editor closed and opened events so that we can keep track of changing files
-    connect(m_core->editorManager(), SIGNAL(editorOpened(Core::IEditor *)),
-        this, SLOT(editorOpened(Core::IEditor *)));
+    connect(Core::ICore::editorManager(), SIGNAL(editorOpened(Core::IEditor*)),
+        this, SLOT(editorOpened(Core::IEditor*)));
 
-    connect(m_core->editorManager(), SIGNAL(editorAboutToClose(Core::IEditor *)),
-        this, SLOT(editorAboutToClose(Core::IEditor *)));
+    connect(Core::ICore::editorManager(), SIGNAL(editorAboutToClose(Core::IEditor*)),
+        this, SLOT(editorAboutToClose(Core::IEditor*)));
+
+    m_completionFallback = new InternalCompletionAssistProvider;
+    m_completionAssistProvider = m_completionFallback;
+    ExtensionSystem::PluginManager::instance()->addObject(m_completionAssistProvider);
+    m_highlightingFallback = new CppHighlightingSupportInternalFactory;
+    m_highlightingFactory = m_highlightingFallback;
 }
 
 CppModelManager::~CppModelManager()
-{ }
+{
+    ExtensionSystem::PluginManager::instance()->removeObject(m_completionAssistProvider);
+    delete m_completionFallback;
+    delete m_highlightingFallback;
+}
 
 Snapshot CppModelManager::snapshot() const
 {
@@ -731,7 +774,8 @@ QStringList CppModelManager::internalProjectFiles() const
     while (it.hasNext()) {
         it.next();
         ProjectInfo pinfo = it.value();
-        files += pinfo.sourceFiles;
+        foreach (const ProjectPart::Ptr &part, pinfo.projectParts())
+            files += part->sourceFiles;
     }
     files.removeDuplicates();
     return files;
@@ -744,7 +788,8 @@ QStringList CppModelManager::internalIncludePaths() const
     while (it.hasNext()) {
         it.next();
         ProjectInfo pinfo = it.value();
-        includePaths += pinfo.includePaths;
+        foreach (const ProjectPart::Ptr &part, pinfo.projectParts())
+            includePaths += part->includePaths;
     }
     includePaths.removeDuplicates();
     return includePaths;
@@ -757,7 +802,8 @@ QStringList CppModelManager::internalFrameworkPaths() const
     while (it.hasNext()) {
         it.next();
         ProjectInfo pinfo = it.value();
-        frameworkPaths += pinfo.frameworkPaths;
+        foreach (const ProjectPart::Ptr &part, pinfo.projectParts())
+            frameworkPaths += part->frameworkPaths;
     }
     frameworkPaths.removeDuplicates();
     return frameworkPaths;
@@ -766,25 +812,25 @@ QStringList CppModelManager::internalFrameworkPaths() const
 QByteArray CppModelManager::internalDefinedMacros() const
 {
     QByteArray macros;
+    QSet<QByteArray> alreadyIn;
     QMapIterator<ProjectExplorer::Project *, ProjectInfo> it(m_projects);
     while (it.hasNext()) {
         it.next();
         ProjectInfo pinfo = it.value();
-        macros += pinfo.defines;
+        foreach (const ProjectPart::Ptr &part, pinfo.projectParts()) {
+            const QList<QByteArray> defs = part->defines.split('\n');
+            foreach (const QByteArray &def, defs) {
+                if (!alreadyIn.contains(def)) {
+                    macros += def;
+                    macros.append('\n');
+                    alreadyIn.insert(def);
+                }
+            }
+        }
     }
     return macros;
 }
 
-void CppModelManager::setIncludesInPaths(const QMap<QString, QStringList> &includesInPaths)
-{
-    QMutexLocker locker(&mutex);
-    QMapIterator<QString, QStringList> i(includesInPaths);
-    while (i.hasNext()) {
-        i.next();
-        m_includesInPaths.insert(i.key(), i.value());
-    }
-}
-
 void CppModelManager::addEditorSupport(AbstractEditorSupport *editorSupport)
 {
     m_addtionalEditorSupport.insert(editorSupport);
@@ -826,7 +872,7 @@ CppModelManager::WorkingCopy CppModelManager::buildWorkingCopyList()
         it.next();
         TextEditor::ITextEditor *textEditor = it.key();
         CppEditorSupport *editorSupport = it.value();
-        QString fileName = textEditor->file()->fileName();
+        QString fileName = textEditor->document()->fileName();
         workingCopy.insert(fileName, editorSupport->contents(), editorSupport->editorRevision());
     }
 
@@ -868,32 +914,65 @@ CppModelManager::ProjectInfo CppModelManager::projectInfo(ProjectExplorer::Proje
 
 void CppModelManager::updateProjectInfo(const ProjectInfo &pinfo)
 {
+#if 0
+    // Tons of debug output...
+    qDebug()<<"========= CppModelManager::updateProjectInfo ======";
+    qDebug()<<" for project:"<< pinfo.project.data()->file()->fileName();
+    foreach (const ProjectPart::Ptr &part, pinfo.projectParts) {
+        qDebug() << "=== part ===";
+        qDebug() << "language:" << (part->language == CXX ? "C++" : "ObjC++");
+        qDebug() << "compilerflags:" << part->flags;
+        qDebug() << "precompiled header:" << part->precompiledHeaders;
+        qDebug() << "defines:" << part->defines;
+        qDebug() << "includes:" << part->includePaths;
+        qDebug() << "frameworkPaths:" << part->frameworkPaths;
+        qDebug() << "sources:" << part->sourceFiles;
+        qDebug() << "";
+    }
+
+    qDebug() << "";
+#endif
     QMutexLocker locker(&mutex);
 
     if (! pinfo.isValid())
         return;
 
-    m_projects.insert(pinfo.project, pinfo);
+    ProjectExplorer::Project *project = pinfo.project().data();
+    m_projects.insert(project, pinfo);
     m_dirty = true;
 
-    if (m_indexerEnabled) {
-        QFuture<void> result = QtConcurrent::run(&CppModelManager::updateIncludesInPaths,
-                                                 this,
-                                                 pinfo.includePaths,
-                                                 pinfo.frameworkPaths,
-                                                 m_headerSuffixes);
+    m_srcToProjectPart.clear();
 
-        if (pinfo.includePaths.size() > 1) {
-            m_core->progressManager()->addTask(result, tr("Scanning"),
-                                               CppTools::Constants::TASK_INDEX);
-        }
-    }
+    foreach (const ProjectInfo &projectInfo, m_projects.values())
+        foreach (const ProjectPart::Ptr &projectPart, projectInfo.projectParts())
+            foreach (const QString &sourceFile, projectPart->sourceFiles)
+                m_srcToProjectPart[sourceFile].append(projectPart);
 }
 
-QStringList CppModelManager::includesInPath(const QString &path) const
+QList<CppModelManager::ProjectPart::Ptr> CppModelManager::projectPart(const QString &fileName) const
 {
-    QMutexLocker locker(&mutex);
-    return m_includesInPaths.value(path);
+    QList<CppModelManager::ProjectPart::Ptr> parts = m_srcToProjectPart.value(fileName);
+    if (!parts.isEmpty())
+        return parts;
+
+    //### FIXME: This is a DIRTY hack!
+    if (fileName.endsWith(".h")) {
+        QString cppFile = fileName.mid(0, fileName.length() - 2) + QLatin1String(".cpp");
+        parts = m_srcToProjectPart.value(cppFile);
+        if (!parts.isEmpty())
+            return parts;
+    }
+
+    DependencyTable table;
+    table.build(snapshot());
+    QStringList deps = table.filesDependingOn(fileName);
+    foreach (const QString &dep, deps) {
+        parts = m_srcToProjectPart.value(dep);
+        if (!parts.isEmpty())
+            return parts;
+    }
+
+    return parts;
 }
 
 QFuture<void> CppModelManager::refreshSourceFiles(const QStringList &sourceFiles)
@@ -925,8 +1004,8 @@ QFuture<void> CppModelManager::refreshSourceFiles(const QStringList &sourceFiles
         m_synchronizer.addFuture(result);
 
         if (sourceFiles.count() > 1) {
-            m_core->progressManager()->addTask(result, tr("Parsing"),
-                            CppTools::Constants::TASK_INDEX);
+            Core::ICore::progressManager()->addTask(result, tr("Parsing"),
+                                                    CppTools::Constants::TASK_INDEX);
         }
 
         return result;
@@ -996,41 +1075,41 @@ void CppModelManager::onDocumentUpdated(Document::Ptr doc)
     if (outdated)
         return;
 
-    QList<Core::IEditor *> openedEditors = m_core->editorManager()->openedEditors();
+    updateEditor(doc);
+}
+
+void CppModelManager::onExtraDiagnosticsUpdated(const QString &fileName)
+{
+    protectSnapshot.lock();
+    Document::Ptr doc = m_snapshot.document(fileName);
+    protectSnapshot.unlock();
+    if (doc)
+        updateEditor(doc);
+}
+
+void CppModelManager::updateEditor(Document::Ptr doc)
+{
+    const QString fileName = doc->fileName();
+
+    QList<Core::IEditor *> openedEditors = Core::ICore::editorManager()->openedEditors();
     foreach (Core::IEditor *editor, openedEditors) {
-        if (editor->file()->fileName() == fileName) {
+        if (editor->document()->fileName() == fileName) {
             TextEditor::ITextEditor *textEditor = qobject_cast<TextEditor::ITextEditor *>(editor);
             if (! textEditor)
                 continue;
 
-            TextEditor::BaseTextEditor *ed = qobject_cast<TextEditor::BaseTextEditor *>(textEditor->widget());
+            TextEditor::BaseTextEditorWidget *ed = qobject_cast<TextEditor::BaseTextEditorWidget *>(textEditor->widget());
             if (! ed)
                 continue;
 
-            QList<TextEditor::BaseTextEditor::BlockRange> blockRanges;
+            QList<TextEditor::BaseTextEditorWidget::BlockRange> blockRanges;
 
             foreach (const Document::Block &block, doc->skippedBlocks()) {
-                blockRanges.append(TextEditor::BaseTextEditor::BlockRange(block.begin(), block.end()));
+                blockRanges.append(TextEditor::BaseTextEditorWidget::BlockRange(block.begin(), block.end()));
             }
 
             QList<QTextEdit::ExtraSelection> selections;
 
-#ifdef QTCREATOR_WITH_MACRO_HIGHLIGHTING
-            // set up the format for the macros
-            QTextCharFormat macroFormat;
-            macroFormat.setUnderlineStyle(QTextCharFormat::SingleUnderline);
-
-            QTextCursor c = ed->textCursor();
-            foreach (const Document::MacroUse &block, doc->macroUses()) {
-                QTextEdit::ExtraSelection sel;
-                sel.cursor = c;
-                sel.cursor.setPosition(block.begin());
-                sel.cursor.setPosition(block.end(), QTextCursor::KeepAnchor);
-                sel.format = macroFormat;
-                selections.append(sel);
-            }
-#endif // QTCREATOR_WITH_MACRO_HIGHLIGHTING
-
             // set up the format for the errors
             QTextCharFormat errorFormat;
             errorFormat.setUnderlineStyle(QTextCharFormat::WaveUnderline);
@@ -1041,54 +1120,10 @@ void CppModelManager::onDocumentUpdated(Document::Ptr doc)
             warningFormat.setUnderlineStyle(QTextCharFormat::WaveUnderline);
             warningFormat.setUnderlineColor(Qt::darkYellow);
 
-#ifdef QTCREATOR_WITH_ADVANCED_HIGHLIGHTER
-            QSet<QPair<unsigned, unsigned> > lines;
-            foreach (const Document::DiagnosticMessage &m, doc->diagnosticMessages()) {
-                if (m.fileName() != fileName)
-                    continue;
-
-                const QPair<unsigned, unsigned> coordinates = qMakePair(m.line(), m.column());
-
-                if (lines.contains(coordinates))
-                    continue;
-
-                lines.insert(coordinates);
-
-                QTextEdit::ExtraSelection sel;
-                if (m.isWarning())
-                    sel.format = warningFormat;
-                else
-                    sel.format = errorFormat;
-
-                QTextCursor c(ed->document()->findBlockByNumber(m.line() - 1));
-
-                // ### check for generated tokens.
-
-                int column = m.column();
-
-                if (column > c.block().length()) {
-                    column = 0;
-
-                    const QString text = c.block().text();
-                    for (int i = 0; i < text.size(); ++i) {
-                        if (! text.at(i).isSpace()) {
-                            ++column;
-                            break;
-                        }
-                    }
-                }
-
-                if (column != 0)
-                    --column;
-
-                c.setPosition(c.position() + column);
-                c.movePosition(QTextCursor::EndOfWord, QTextCursor::KeepAnchor);
-                sel.cursor = c;
-                selections.append(sel);
-            }
-#else
             QSet<int> lines;
-            foreach (const Document::DiagnosticMessage &m, doc->diagnosticMessages()) {
+            QList<Document::DiagnosticMessage> messages = doc->diagnosticMessages();
+            messages += extraDiagnostics(doc->fileName());
+            foreach (const Document::DiagnosticMessage &m, messages) {
                 if (m.fileName() != fileName)
                     continue;
                 else if (lines.contains(m.line()))
@@ -1112,9 +1147,10 @@ void CppModelManager::onDocumentUpdated(Document::Ptr doc)
                 }
                 c.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
                 sel.cursor = c;
+                sel.format.setToolTip(m.text());
                 selections.append(sel);
             }
-#endif
+
             QList<Editor> todo;
             foreach (const Editor &e, todo) {
                 if (e.textEditor != textEditor)
@@ -1146,14 +1182,14 @@ void CppModelManager::updateEditorSelections()
             continue;
 
         TextEditor::ITextEditor *textEditor = ed.textEditor;
-        TextEditor::BaseTextEditor *editor = qobject_cast<TextEditor::BaseTextEditor *>(textEditor->widget());
+        TextEditor::BaseTextEditorWidget *editor = qobject_cast<TextEditor::BaseTextEditorWidget *>(textEditor->widget());
 
         if (! editor)
             continue;
         else if (editor->document()->revision() != ed.revision)
             continue; // outdated
 
-        editor->setExtraSelections(TextEditor::BaseTextEditor::CodeWarningsSelection,
+        editor->setExtraSelections(TextEditor::BaseTextEditorWidget::CodeWarningsSelection,
                                    ed.selections);
 
         editor->setIfdefedOutBlocks(ed.ifdefedOutBlocks);
@@ -1182,8 +1218,8 @@ void CppModelManager::onAboutToRemoveProject(ProjectExplorer::Project *project)
 
 void CppModelManager::onAboutToUnloadSession()
 {
-    if (m_core->progressManager()) {
-        m_core->progressManager()->cancelTasks(CppTools::Constants::TASK_INDEX);
+    if (Core::ProgressManager *pm = Core::ICore::progressManager()) {
+        pm->cancelTasks(CppTools::Constants::TASK_INDEX);
     }
     do {
         QMutexLocker locker(&mutex);
@@ -1194,114 +1230,6 @@ void CppModelManager::onAboutToUnloadSession()
     GC();
 }
 
-void CppModelManager::updateIncludesInPaths(QFutureInterface<void> &future,
-                                            CppModelManager *manager,
-                                            QStringList paths,
-                                            QStringList frameworkPaths,
-                                            QStringList suffixes)
-{
-    QMap<QString, QStringList> entriesInPaths;
-    typedef QPair<QString, QString> SymLink;
-    typedef QList<SymLink> SymLinks;
-    SymLinks symlinks;
-    int processed = 0;
-
-    future.setProgressRange(0, paths.size());
-
-    // Add framework header directories to path list
-    QStringList frameworkFilter;
-    frameworkFilter << QLatin1String("*.framework");
-    QStringListIterator fwPathIt(frameworkPaths);
-    while (fwPathIt.hasNext()) {
-        const QString &fwPath = fwPathIt.next();
-        QStringList entriesInFrameworkPath;
-        const QStringList &frameworks = QDir(fwPath).entryList(frameworkFilter, QDir::Dirs | QDir::NoDotAndDotDot);
-        QStringListIterator fwIt(frameworks);
-        while (fwIt.hasNext()) {
-            QString framework = fwIt.next();
-            paths.append(fwPath + QLatin1Char('/') + framework + QLatin1String("/Headers"));
-            framework.chop(10); // remove the ".framework"
-            entriesInFrameworkPath.append(framework + QLatin1Char('/'));
-        }
-        entriesInPaths.insert(fwPath, entriesInFrameworkPath);
-    }
-
-    while (!paths.isEmpty()) {
-        if (future.isPaused())
-            future.waitForResume();
-
-        if (future.isCanceled())
-            return;
-
-        const QString path = paths.takeFirst();
-
-        if (path == QLatin1String("/"))
-            continue;
-
-        // Skip non-existing paths
-        if (!QFile::exists(path))
-            continue;
-
-        // Skip already scanned paths
-        if (entriesInPaths.contains(path))
-            continue;
-
-        QStringList entries;
-
-        QDirIterator i(path, QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot);
-        while (i.hasNext()) {
-            const QString fileName = i.next();
-            const QFileInfo fileInfo = i.fileInfo();
-            QString text = fileInfo.fileName();
-            if (fileInfo.isDir()) {
-                text += QLatin1Char('/');
-
-                // Also scan subdirectory, but avoid endless recursion with symbolic links
-                if (fileInfo.isSymLink()) {
-                    QString target = fileInfo.symLinkTarget();
-
-                    // Don't add broken symlinks
-                    if (!QFileInfo(target).exists())
-                        continue;
-
-                    QMap<QString, QStringList>::const_iterator result = entriesInPaths.find(target);
-                    if (result != entriesInPaths.constEnd()) {
-                        entriesInPaths.insert(fileName, result.value());
-                    } else {
-                        paths.append(target);
-                        symlinks.append(SymLink(fileName, target));
-                    }
-                } else {
-                    paths.append(fileName);
-                }
-                entries.append(text);
-            } else {
-                const QString suffix = fileInfo.suffix();
-                if (suffix.isEmpty() || suffixes.contains(suffix))
-                    entries.append(text);
-            }
-        }
-
-        entriesInPaths.insert(path, entries);
-
-        ++processed;
-        future.setProgressRange(0, processed + paths.size());
-        future.setProgressValue(processed);
-    }
-    // link symlinks
-    QListIterator<SymLink> it(symlinks);
-    it.toBack();
-    while (it.hasPrevious()) {
-        SymLink v = it.previous();
-        QMap<QString, QStringList>::const_iterator result = entriesInPaths.find(v.second);
-        entriesInPaths.insert(v.first, result.value());
-    }
-
-    manager->setIncludesInPaths(entriesInPaths);
-
-    future.reportFinished();
-}
-
 void CppModelManager::parse(QFutureInterface<void> &future,
                             CppPreprocessor *preproc,
                             QStringList files)
@@ -1309,7 +1237,7 @@ void CppModelManager::parse(QFutureInterface<void> &future,
     if (files.isEmpty())
         return;
 
-    const Core::MimeDatabase *mimeDb = Core::ICore::instance()->mimeDatabase();
+    const Core::MimeDatabase *mimeDb = Core::ICore::mimeDatabase();
     Core::MimeType cSourceTy = mimeDb->findByType(QLatin1String("text/x-csrc"));
     Core::MimeType cppSourceTy = mimeDb->findByType(QLatin1String("text/x-c++src"));
     Core::MimeType mSourceTy = mimeDb->findByType(QLatin1String("text/x-objcsrc"));
@@ -1372,6 +1300,7 @@ void CppModelManager::parse(QFutureInterface<void> &future,
     }
 
     future.setProgressValue(files.size());
+    preproc->modelManager()->finishedRefreshingSourceFiles(files);
 
     delete preproc;
 }
@@ -1417,5 +1346,69 @@ void CppModelManager::GC()
     m_snapshot = newSnapshot;
     protectSnapshot.unlock();
 }
+
+void CppModelManager::finishedRefreshingSourceFiles(const QStringList &files)
+{
+    emit sourceFilesRefreshed(files);
+}
+
+CppCompletionSupport *CppModelManager::completionSupport(Core::IEditor *editor) const
+{
+    if (TextEditor::ITextEditor *textEditor = qobject_cast<TextEditor::ITextEditor *>(editor))
+        return m_completionAssistProvider->completionSupport(textEditor);
+    else
+        return 0;
+}
+
+void CppModelManager::setCppCompletionAssistProvider(CppCompletionAssistProvider *completionAssistProvider)
+{
+    ExtensionSystem::PluginManager::instance()->removeObject(m_completionAssistProvider);
+    if (completionAssistProvider)
+        m_completionAssistProvider = completionAssistProvider;
+    else
+        m_completionAssistProvider = m_completionFallback;
+    ExtensionSystem::PluginManager::instance()->addObject(m_completionAssistProvider);
+}
+
+CppHighlightingSupport *CppModelManager::highlightingSupport(Core::IEditor *editor) const
+{
+    if (TextEditor::ITextEditor *textEditor = qobject_cast<TextEditor::ITextEditor *>(editor))
+        return m_highlightingFactory->highlightingSupport(textEditor);
+    else
+        return 0;
+}
+
+void CppModelManager::setHighlightingSupportFactory(CppHighlightingSupportFactory *highlightingFactory)
+{
+    if (highlightingFactory)
+        m_highlightingFactory = highlightingFactory;
+    else
+        m_highlightingFactory = m_highlightingFallback;
+}
+
+void CppModelManager::setExtraDiagnostics(const QString &fileName, int kind,
+                                          const QList<Document::DiagnosticMessage> &diagnostics)
+{
+    {
+        QMutexLocker locker(&protectExtraDiagnostics);
+        if (m_extraDiagnostics[fileName][kind] == diagnostics)
+            return;
+        m_extraDiagnostics[fileName].insert(kind, diagnostics);
+    }
+    emit extraDiagnosticsUpdated(fileName);
+}
+
+QList<Document::DiagnosticMessage> CppModelManager::extraDiagnostics(const QString &fileName, int kind) const
+{
+    QMutexLocker locker(&protectExtraDiagnostics);
+    if (kind == -1) {
+        QList<Document::DiagnosticMessage> messages;
+        foreach (const QList<Document::DiagnosticMessage> &list, m_extraDiagnostics.value(fileName))
+            messages += list;
+        return messages;
+    }
+    return m_extraDiagnostics.value(fileName).value(kind);
+}
+
 #endif
 
