@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -38,12 +38,13 @@
 #include <find/ifindfilter.h>
 #include <utils/filesearch.h>
 
-#include <QtGui/QTextDocument>
-#include <QtGui/QKeySequence>
-#include <QtCore/QSharedPointer>
-#include <QtCore/QFutureInterface>
-#include <QtCore/QPointer>
-#include <QtCore/QFutureWatcher>
+#include <QTextDocument>
+#include <QKeySequence>
+#include <QSharedPointer>
+#include <QFutureInterface>
+#include <QPointer>
+#include <QFutureWatcher>
+#include <QHash>
 
 QT_BEGIN_NAMESPACE
 class QFileInfo;
@@ -76,12 +77,28 @@ public:
 private slots:
     void switchHeaderSource();
 
+#ifdef WITH_TESTS
+    // codegen tests
+    void test_codegen_public_in_empty_class();
+    void test_codegen_public_in_nonempty_class();
+    void test_codegen_public_before_protected();
+    void test_codegen_private_after_protected();
+    void test_codegen_protected_in_nonempty_class();
+    void test_codegen_protected_between_public_and_private();
+    void test_codegen_qtdesigner_integration();
+    void test_codegen_definition_empty_class();
+    void test_codegen_definition_first_member();
+    void test_codegen_definition_last_member();
+    void test_codegen_definition_middle_member();
+#endif
+
 private:
     QString correspondingHeaderOrSourceI(const QString &fileName) const;
 
     CppModelManager *m_modelManager;
     QSharedPointer<CppFileSettings> m_fileSettings;
     CppToolsSettings *m_settings;
+    mutable QHash<QString, QString> m_headerSourceMapping;
 };
 
 } // namespace Internal
