@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -33,14 +33,25 @@
 #ifndef DEBUGGER_DIALOGS_H
 #define DEBUGGER_DIALOGS_H
 
-#include <QtGui/QDialog>
+#include <QHash>
+#include <QStringList>
+#include <QDialog>
+#include <QVBoxLayout>
 
 QT_BEGIN_NAMESPACE
-
 class QModelIndex;
 class QPushButton;
 class QLineEdit;
 class QDialogButtonBox;
+class QSettings;
+QT_END_NAMESPACE
+
+namespace ProjectExplorer { class Abi; }
+
+namespace Debugger {
+class DebuggerStartParameters;
+
+namespace Internal {
 
 namespace Ui {
 class AttachCoreDialog;
@@ -51,24 +62,9 @@ class AttachToQmlPortDialog;
 class StartRemoteEngineDialog;
 } // namespace Ui
 
-QT_END_NAMESPACE
-
-namespace ProjectExplorer {
-class Abi;
-}
-
-namespace Debugger {
-namespace Internal {
-
 class ProcessListFilterModel;
-
-struct ProcData
-{
-    QString ppid;
-    QString name;
-    QString image;
-    QString state;
-};
+class StartExternalParameters;
+class StartRemoteParameters;
 
 class AttachCoreDialog : public QDialog
 {
@@ -146,31 +142,25 @@ public:
     explicit StartExternalDialog(QWidget *parent);
     ~StartExternalDialog();
 
-    QString executableFile() const;
-    void setExecutableFile(const QString &executable);
-
-    QString executableArguments() const;
-    void setExecutableArguments(const QString &args);
-
-    QString workingDirectory() const;
-    void setWorkingDirectory(const QString &str);
-
-    int abiIndex() const;
-    void setAbiIndex(int);
-    ProjectExplorer::Abi abi() const;
-    QString debuggerCommand();
-
-    bool breakAtMain() const;
-
-    bool runInTerminal() const;
-    void setRunInTerminal(bool v);
-
-    bool isValid() const;
+    static bool run(QWidget *parent, QSettings *settings, DebuggerStartParameters *sp);
 
 private slots:
     void changed();
+    void historyIndexChanged(int);
 
 private:
+    StartExternalParameters parameters() const;
+    void setParameters(const StartExternalParameters &p);
+    void setHistory(const QList<StartExternalParameters> l);
+
+    QString executableFile() const;
+    void setExecutableFile(const QString &executable);
+
+    ProjectExplorer::Abi abi() const;
+    QString debuggerCommand();
+
+    bool isValid() const;
+
     Ui::StartExternalDialog *m_ui;
 };
 
@@ -182,41 +172,23 @@ public:
     explicit StartRemoteDialog(QWidget *parent, bool enableStartScript);
     ~StartRemoteDialog();
 
-    QString localExecutable() const;
-    void setLocalExecutable(const QString &executable);
-
-    QString remoteChannel() const;
-    void setRemoteChannel(const QString &host);
-
-    QString remoteArchitecture() const;
-    void setRemoteArchitecture(const QString &arch);
-    void setRemoteArchitectures(const QStringList &arches);
-
-    QString gnuTarget() const;
-    void setGnuTarget(const QString &gnuTarget);
-    void setGnuTargets(const QStringList &gnuTargets);
-
-    QString overrideStartScript() const;
-    void setOverrideStartScript(const QString &scriptName);
-
-    bool useServerStartScript() const;
-    void setUseServerStartScript(bool on);
-    QString serverStartScript() const;
-    void setServerStartScript(const QString &scriptName);
-
-    QString sysroot() const;
-    void setSysroot(const QString &sysroot);
-
-    QString debugger() const;
-    void setDebugger(const QString &debugger);
-
-    void setDebugInfoLocation(const QString &location);
-    QString debugInfoLocation() const;
+    static bool run(QWidget *parent, QSettings *settings,
+                    bool useScript, DebuggerStartParameters *sp);
 
 private slots:
     void updateState();
+    void historyIndexChanged(int);
 
 private:
+    StartRemoteParameters parameters() const;
+    void setParameters(const StartRemoteParameters &);
+    void setHistory(const QList<StartRemoteParameters> &);
+
+    void setRemoteArchitectures(const QStringList &list);
+
+    ProjectExplorer::Abi abi() const;
+    QString debuggerCommand() const;
+
     Ui::StartRemoteDialog *m_ui;
 };
 
@@ -234,6 +206,9 @@ public:
     int port() const;
     void setPort(const int port);
 
+    QString sysroot() const;
+    void setSysroot(const QString &sysroot);
+
 private:
     Ui::AttachToQmlPortDialog *m_ui;
 };
@@ -283,6 +258,8 @@ private:
      QDialogButtonBox *m_box;
 };
 
+typedef QHash<QString, QStringList> TypeFormats;
+
 class StartRemoteEngineDialog : public QDialog
 {
     Q_OBJECT
@@ -300,6 +277,24 @@ private:
     Ui::StartRemoteEngineDialog *m_ui;
 };
 
+class TypeFormatsDialogUi;
+
+class TypeFormatsDialog : public QDialog
+{
+    Q_OBJECT
+
+public:
+    explicit TypeFormatsDialog(QWidget *parent);
+    ~TypeFormatsDialog();
+
+    void addTypeFormats(const QString &type, const QStringList &formats,
+        int currentFormat);
+    TypeFormats typeFormats() const;
+
+private:
+    TypeFormatsDialogUi *m_ui;
+};
+
 } // namespace Debugger
 } // namespace Internal
 
