@@ -2,48 +2,40 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** No Commercial Usage
-**
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
 **
 ** GNU Lesser General Public License Usage
 **
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this file.
+** Please review the following information to ensure the GNU Lesser General
+** Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
+** Other Usage
+**
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at qt-info@nokia.com.
 **
 **************************************************************************/
 
 #include "moduleshandler.h"
-#include "debuggerengine.h"
 
 #include <utils/qtcassert.h>
 
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QTextStream>
-
-#include <QtGui/QAction>
-#include <QtGui/QMainWindow>
-#include <QtGui/QStandardItemModel>
-#include <QtGui/QSortFilterProxyModel>
+#include <QDebug>
+#include <QSortFilterProxyModel>
 
 
 //////////////////////////////////////////////////////////////////
@@ -55,41 +47,8 @@
 namespace Debugger {
 namespace Internal {
 
-class ModulesModel : public QAbstractItemModel
-{   // Needs tr - context.
-    Q_OBJECT
-public:
-    explicit ModulesModel(ModulesHandler *parent, DebuggerEngine *engine);
-
-    // QAbstractItemModel
-    int columnCount(const QModelIndex &parent) const
-        { return parent.isValid() ? 0 : 5; }
-    int rowCount(const QModelIndex &parent) const
-        { return parent.isValid() ? 0 : m_modules.size(); }
-    QModelIndex parent(const QModelIndex &) const { return QModelIndex(); }
-    QModelIndex index(int row, int column, const QModelIndex &) const
-        { return createIndex(row, column); }
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-    QVariant data(const QModelIndex &index, int role) const;
-    bool setData(const QModelIndex &index, const QVariant &value, int role);
-
-    void clearModel();
-    void addModule(const Module &module);
-    void removeModule(const QString &moduleName);
-    void setModules(const Modules &modules);
-    void updateModule(const QString &moduleName, const Module &module);
-
-    const Modules &modules() const { return m_modules; }
-
-private:
-    int indexOfModule(const QString &name) const;
-
-    DebuggerEngine *m_engine;
-    Modules m_modules;
-};
-
-ModulesModel::ModulesModel(ModulesHandler *parent, DebuggerEngine *engine)
-  : QAbstractItemModel(parent), m_engine(engine)
+ModulesModel::ModulesModel(ModulesHandler *parent)
+  : QAbstractItemModel(parent)
 {}
 
 QVariant ModulesModel::headerData(int section,
@@ -97,12 +56,12 @@ QVariant ModulesModel::headerData(int section,
 {
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         static QString headers[] = {
-            tr("Module name") + "        ",
-            tr("Module path") + "        ",
-            tr("Symbols read") + "        ",
-            tr("Symbols type") + "        ",
-            tr("Start address") + "        ",
-            tr("End address") + "        "
+            tr("Module name") + QLatin1String("        "),
+            tr("Module path") + QLatin1String("        "),
+            tr("Symbols read") + QLatin1String("        "),
+            tr("Symbols type") + QLatin1String("        "),
+            tr("Start address") + QLatin1String("        "),
+            tr("End address") + QLatin1String("        ")
         };
         return headers[section];
     }
@@ -111,12 +70,6 @@ QVariant ModulesModel::headerData(int section,
 
 QVariant ModulesModel::data(const QModelIndex &index, int role) const
 {
-    if (role == EngineCapabilitiesRole)
-        return m_engine->debuggerCapabilities();
-
-    if (role == EngineActionsEnabledRole)
-        return m_engine->debuggerActionsEnabled();
-
     int row = index.row();
     if (row < 0 || row >= m_modules.size())
         return QVariant();
@@ -153,44 +106,22 @@ QVariant ModulesModel::data(const QModelIndex &index, int role) const
             break;
         case 4:
             if (role == Qt::DisplayRole)
-                return module.startAddress;
+                return QString(QLatin1String("0x")
+                            + QString::number(module.startAddress, 16));
             break;
         case 5:
-            if (role == Qt::DisplayRole)
-                return module.endAddress;
+            if (role == Qt::DisplayRole) {
+                if (module.endAddress)
+                    return QString(QLatin1String("0x")
+                                + QString::number(module.endAddress, 16));
+                //: End address of loaded module
+                return tr("<unknown>", "address");
+            }
             break;
     }
     return QVariant();
 }
 
-bool ModulesModel::setData(const QModelIndex &index, const QVariant &value, int role)
-{
-    Q_UNUSED(index);
-
-    switch (role) {
-        case RequestReloadModulesRole:
-            m_engine->reloadModules();
-            return true;
-
-        case RequestExamineModulesRole:
-            m_engine->examineModules();
-            return true;
-
-        case RequestModuleSymbolsRole:
-            m_engine->loadSymbols(value.toString());
-            return true;
-
-        case RequestAllSymbolsRole:
-            m_engine->loadAllSymbols();
-            return true;
-
-        case RequestOpenFileRole:
-            m_engine->openFile(value.toString());
-            return true;
-    }
-    return false;
-}
-
 void ModulesModel::addModule(const Module &m)
 {
     beginInsertRows(QModelIndex(), m_modules.size(), m_modules.size());
@@ -226,7 +157,7 @@ void ModulesModel::removeModule(const QString &moduleName)
     const int index = indexOfModule(moduleName);
     QTC_ASSERT(index != -1, return);
     beginRemoveRows(QModelIndex(), index, index);
-    m_modules.removeAt(index);
+    m_modules.remove(index);
     endRemoveRows();
 }
 
@@ -244,9 +175,9 @@ void ModulesModel::updateModule(const QString &moduleName, const Module &module)
 //
 //////////////////////////////////////////////////////////////////
 
-ModulesHandler::ModulesHandler(DebuggerEngine *engine)
+ModulesHandler::ModulesHandler()
 {
-    m_model = new ModulesModel(this, engine);
+    m_model = new ModulesModel(this);
     m_proxyModel = new QSortFilterProxyModel(this);
     m_proxyModel->setSourceModel(m_model);
 }
@@ -289,4 +220,3 @@ Modules ModulesHandler::modules() const
 } // namespace Internal
 } // namespace Debugger
 
-#include "moduleshandler.moc"
