@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -62,12 +62,12 @@
 #include <cpptools/cpptoolsconstants.h>
 #include <utils/qtcassert.h>
 
-#include <QtDesigner/QDesignerFormEditorPluginInterface>
-#include <QtDesigner/QDesignerFormEditorInterface>
-#include <QtDesigner/QDesignerComponents>
+#include <QDesignerFormEditorPluginInterface>
+#include <QDesignerFormEditorInterface>
+#include <QDesignerComponents>
 
 #if QT_VERSION >= 0x050000
-#    include <QtDesigner/QDesignerFormWindowManagerInterface>
+#    include <QDesignerFormWindowManagerInterface>
 #else
 #    include "qt_private/pluginmanager_p.h"
 #    include "qt_private/iconloader_p.h"  // createIconSet
@@ -75,35 +75,35 @@
 #    include "qt_private/formwindowbase_p.h"
 #endif
 
-#include <QtDesigner/QDesignerWidgetBoxInterface>
-#include <QtDesigner/abstractobjectinspector.h>
-#include <QtDesigner/QDesignerPropertyEditorInterface>
-#include <QtDesigner/QDesignerActionEditorInterface>
-#include <QtDesigner/QDesignerFormEditorInterface>
+#include <QDesignerWidgetBoxInterface>
+#include <abstractobjectinspector.h>
+#include <QDesignerPropertyEditorInterface>
+#include <QDesignerActionEditorInterface>
+#include <QDesignerFormEditorInterface>
 
-#include <QtGui/QAction>
-#include <QtGui/QActionGroup>
-#include <QtGui/QApplication>
-#include <QtGui/QCursor>
-#include <QtGui/QDockWidget>
-#include <QtGui/QMenu>
-#include <QtGui/QMainWindow>
-#include <QtGui/QMessageBox>
-#include <QtGui/QKeySequence>
-#include <QtGui/QPrintDialog>
-#include <QtGui/QPrinter>
-#include <QtGui/QPainter>
-#include <QtGui/QStyle>
-#include <QtGui/QToolBar>
-#include <QtGui/QVBoxLayout>
+#include <QAction>
+#include <QActionGroup>
+#include <QApplication>
+#include <QCursor>
+#include <QDockWidget>
+#include <QMenu>
+#include <QMainWindow>
+#include <QMessageBox>
+#include <QKeySequence>
+#include <QPrintDialog>
+#include <QPrinter>
+#include <QPainter>
+#include <QStyle>
+#include <QToolBar>
+#include <QVBoxLayout>
 
-#include <QtCore/QDebug>
-#include <QtCore/QSettings>
-#include <QtCore/QSignalMapper>
-#include <QtCore/QPluginLoader>
-#include <QtCore/QTime>
+#include <QDebug>
+#include <QSettings>
+#include <QSignalMapper>
+#include <QPluginLoader>
+#include <QTime>
 
-static const char settingsGroup[] = "Designer";
+static const char settingsGroupC[] = "Designer";
 
 #ifdef Q_OS_MAC
     enum { osMac = 1 };
@@ -132,16 +132,16 @@ static inline QIcon designerIcon(const QString &iconName)
 }
 
 // Create a menu separator
-static inline QAction *createSeparator(QObject *parent,
+static QAction *createSeparator(QObject *parent,
                                  Core::ActionManager *am,
                                  const Core::Context &context,
                                  Core::ActionContainer *container,
-                                 const QString &name = QString(),
-                                 const QString &group = QString())
+                                 const Core::Id &id,
+                                 const Core::Id &group = Core::Id())
 {
     QAction *actSeparator = new QAction(parent);
     actSeparator->setSeparator(true);
-    Core::Command *command = am->registerAction(actSeparator, name, context);
+    Core::Command *command = am->registerAction(actSeparator, id, context);
     container->addAction(command, group);
     return actSeparator;
 }
@@ -159,7 +159,6 @@ FormEditorW::FormEditorW() :
     m_formeditor(QDesignerComponents::createFormEditor(0)),
     m_integration(0),
     m_fwm(0),
-    m_core(Core::ICore::instance()),
     m_initStage(RegisterPlugins),
     m_actionGroupEditMode(0),
     m_actionPrint(0),
@@ -180,12 +179,11 @@ FormEditorW::FormEditorW() :
         qDebug() << Q_FUNC_INFO;
     QTC_ASSERT(!m_self, return);
     m_self = this;
-    QTC_ASSERT(m_core, return);
 
     qFill(m_designerSubWindows, m_designerSubWindows + Designer::Constants::DesignerSubWindowCount,
           static_cast<QWidget *>(0));
 
-    m_formeditor->setTopLevel(qobject_cast<QWidget *>(m_core->editorManager()));
+    m_formeditor->setTopLevel(Core::ICore::editorManager());
     m_formeditor->setSettingsManager(new SettingsManager());
 
 #if QT_VERSION >= 0x050000
@@ -204,19 +202,19 @@ FormEditorW::FormEditorW() :
         m_settingsPages.append(settingsPage);
     }
 
-    connect(m_core->editorManager(), SIGNAL(currentEditorChanged(Core::IEditor *)),
-            this, SLOT(currentEditorChanged(Core::IEditor *)));
-    connect(m_shortcutMapper, SIGNAL(mapped(QObject *)),
-            this, SLOT(updateShortcut(QObject *)));
+    connect(Core::ICore::editorManager(), SIGNAL(currentEditorChanged(Core::IEditor*)),
+            this, SLOT(currentEditorChanged(Core::IEditor*)));
+    connect(m_shortcutMapper, SIGNAL(mapped(QObject*)),
+            this, SLOT(updateShortcut(QObject*)));
 }
 
 FormEditorW::~FormEditorW()
 {
     if (m_context)
-        m_core->removeContextObject(m_context);
+        Core::ICore::removeContextObject(m_context);
     if (m_initStage == FullyInitialized) {
-        if (QSettings *s = m_core->settings()) {
-            m_core->settings()->beginGroup(settingsGroup);
+        if (QSettings *s = Core::ICore::settings()) {
+            s->beginGroup(QLatin1String(settingsGroupC));
             m_editorWidget->saveSettings(s);
             s->endGroup();
         }
@@ -238,7 +236,7 @@ FormEditorW::~FormEditorW()
 void FormEditorW::addDockViewAction(Core::ActionManager *am,
                                     Core::ActionContainer *viewMenu,
                                     int index, const Core::Context &context,
-                                    const QString &title, const QString &id)
+                                    const QString &title, const Core::Id &id)
 {
     if (const QDockWidget *dw = m_editorWidget->designerDockWidgets()[index]) {
         QAction *action = dw->toggleViewAction();
@@ -251,35 +249,35 @@ void FormEditorW::addDockViewAction(Core::ActionManager *am,
 void FormEditorW::setupViewActions()
 {
     // Populate "View" menu of form editor menu
-    Core::ActionManager *am = m_core->actionManager();
+    Core::ActionManager *am = Core::ICore::actionManager();
     Core::ActionContainer *viewMenu = am->actionContainer(Core::Id(Core::Constants::M_WINDOW_VIEWS));
     QTC_ASSERT(viewMenu, return)
 
     addDockViewAction(am, viewMenu, WidgetBoxSubWindow, m_contexts,
-                      tr("Widget box"), QLatin1String("FormEditor.WidgetBox"));
+                      tr("Widget box"), Core::Id("FormEditor.WidgetBox"));
 
     addDockViewAction(am, viewMenu, ObjectInspectorSubWindow, m_contexts,
-                      tr("Object Inspector"), QLatin1String("FormEditor.ObjectInspector"));
+                      tr("Object Inspector"), Core::Id("FormEditor.ObjectInspector"));
 
     addDockViewAction(am, viewMenu, PropertyEditorSubWindow, m_contexts,
-                      tr("Property Editor"), QLatin1String("FormEditor.PropertyEditor"));
+                      tr("Property Editor"), Core::Id("FormEditor.PropertyEditor"));
 
     addDockViewAction(am, viewMenu, SignalSlotEditorSubWindow, m_contexts,
-                      tr("Signals && Slots Editor"), QLatin1String("FormEditor.SignalsAndSlotsEditor"));
+                      tr("Signals && Slots Editor"), Core::Id("FormEditor.SignalsAndSlotsEditor"));
 
     addDockViewAction(am, viewMenu, ActionEditorSubWindow, m_contexts,
-                      tr("Action Editor"), QLatin1String("FormEditor.ActionEditor"));
+                      tr("Action Editor"), Core::Id("FormEditor.ActionEditor"));
     // Lock/Reset
-    Core::Command *cmd = addToolAction(m_editorWidget->menuSeparator1(), am, m_contexts, QLatin1String("FormEditor.SeparatorLock"), viewMenu, QString());
+    Core::Command *cmd = addToolAction(m_editorWidget->menuSeparator1(), am, m_contexts, Core::Id("FormEditor.SeparatorLock"), viewMenu, QString());
     cmd->setAttribute(Core::Command::CA_Hide);
 
-    cmd = addToolAction(m_editorWidget->toggleLockedAction(), am, m_contexts, QLatin1String("FormEditor.Locked"), viewMenu, QString());
+    cmd = addToolAction(m_editorWidget->toggleLockedAction(), am, m_contexts, Core::Id("FormEditor.Locked"), viewMenu, QString());
     cmd->setAttribute(Core::Command::CA_Hide);
 
-    cmd = addToolAction(m_editorWidget->menuSeparator2(), am, m_contexts, QLatin1String("FormEditor.SeparatorReset"), viewMenu, QString());
+    cmd = addToolAction(m_editorWidget->menuSeparator2(), am, m_contexts, Core::Id("FormEditor.SeparatorReset"), viewMenu, QString());
     cmd->setAttribute(Core::Command::CA_Hide);
 
-    cmd = addToolAction(m_editorWidget->resetLayoutAction(), am, m_contexts, QLatin1String("FormEditor.ResetToDefaultLayout"), viewMenu, QString());
+    cmd = addToolAction(m_editorWidget->resetLayoutAction(), am, m_contexts, Core::Id("FormEditor.ResetToDefaultLayout"), viewMenu, QString());
     connect(m_editorWidget, SIGNAL(resetLayout()), m_editorWidget, SLOT(resetToDefaultLayout()));
     cmd->setAttribute(Core::Command::CA_Hide);
 }
@@ -327,12 +325,12 @@ void FormEditorW::fullInit()
         delete initTime;
     }
 
-    connect(m_core->editorManager()->instance(), SIGNAL(editorsClosed(QList<Core::IEditor*>)),
+    connect(Core::ICore::editorManager(), SIGNAL(editorsClosed(QList<Core::IEditor*>)),
             SLOT(closeFormEditorsForXmlEditors(QList<Core::IEditor*>)));
     // Nest toolbar and editor widget
     m_editorWidget = new EditorWidget(this);
-    QSettings *settings = m_core->settings();
-    settings->beginGroup(settingsGroup);
+    QSettings *settings = Core::ICore::settings();
+    settings->beginGroup(QLatin1String(settingsGroupC));
     m_editorWidget->restoreSettings(settings);
     settings->endGroup();
 
@@ -342,7 +340,7 @@ void FormEditorW::fullInit()
     m_toolBar->setNavigationVisible(false);
     m_toolBar->addCenterToolBar(m_editorToolBar);
 
-    m_designMode = ExtensionSystem::PluginManager::instance()->getObject<Core::DesignMode>();
+    m_designMode = Core::DesignMode::instance();
     m_modeWidget = new QWidget;
     m_modeWidget->setObjectName(QLatin1String("DesignerModeWidget"));
     QVBoxLayout *layout = new QVBoxLayout;
@@ -362,7 +360,7 @@ void FormEditorW::fullInit()
     Core::Context designerContexts = m_contexts;
     designerContexts.add(Core::Constants::C_EDITORMANAGER);
     m_context = new DesignerContext(designerContexts, m_modeWidget, this);
-    m_core->addContextObject(m_context);
+    Core::ICore::addContextObject(m_context);
 
     m_designMode->registerDesignWidget(m_modeWidget, QStringList(QLatin1String(FORM_MIMETYPE)), m_contexts);
 
@@ -436,7 +434,7 @@ void FormEditorW::deleteInstance()
 
 void FormEditorW::setupActions()
 {
-    Core::ActionManager *am = m_core->actionManager();
+    Core::ActionManager *am = Core::ICore::actionManager();
     Core::Command *command;
 
     //menus
@@ -479,77 +477,77 @@ void FormEditorW::setupActions()
     command = am->registerAction(m_modeActionSeparator, Core::Id("FormEditor.Sep.ModeActions"), m_contexts);
     medit->addAction(command, Core::Constants::G_EDIT_OTHER);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.WidgetEditor"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.WidgetEditor"));
     createEditModeAction(m_actionGroupEditMode, m_contexts, am, medit,
                          tr("Edit Widgets"), m_toolActionIds.back(),
                          EditModeWidgetEditor, QLatin1String("widgettool.png"), tr("F3"));
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.SignalsSlotsEditor"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.SignalsSlotsEditor"));
     createEditModeAction(m_actionGroupEditMode, m_contexts, am, medit,
                          tr("Edit Signals/Slots"), m_toolActionIds.back(),
                          EditModeSignalsSlotEditor, QLatin1String("signalslottool.png"), tr("F4"));
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.BuddyEditor"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.BuddyEditor"));
     createEditModeAction(m_actionGroupEditMode, m_contexts, am, medit,
                          tr("Edit Buddies"), m_toolActionIds.back(),
                          EditModeBuddyEditor, QLatin1String("buddytool.png"));
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.TabOrderEditor"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.TabOrderEditor"));
     createEditModeAction(m_actionGroupEditMode, m_contexts, am, medit,
                          tr("Edit Tab Order"),  m_toolActionIds.back(),
                          EditModeTabOrderEditor, QLatin1String("tabordertool.png"));
 
     //tool actions
-    m_toolActionIds.push_back(QLatin1String("FormEditor.LayoutHorizontally"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.LayoutHorizontally"));
     const QString horizLayoutShortcut = osMac ? tr("Meta+H") : tr("Ctrl+H");
     addToolAction(m_fwm->actionHorizontalLayout(), am, m_contexts,
                   m_toolActionIds.back(), mformtools, horizLayoutShortcut);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.LayoutVertically"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.LayoutVertically"));
     const QString vertLayoutShortcut = osMac ? tr("Meta+L") : tr("Ctrl+L");
     addToolAction(m_fwm->actionVerticalLayout(), am, m_contexts,
                   m_toolActionIds.back(),  mformtools, vertLayoutShortcut);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.SplitHorizontal"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.SplitHorizontal"));
     addToolAction(m_fwm->actionSplitHorizontal(), am, m_contexts,
                   m_toolActionIds.back(), mformtools);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.SplitVertical"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.SplitVertical"));
     addToolAction(m_fwm->actionSplitVertical(), am, m_contexts,
                   m_toolActionIds.back(), mformtools);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.LayoutForm"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.LayoutForm"));
     addToolAction(m_fwm->actionFormLayout(), am, m_contexts,
                   m_toolActionIds.back(),  mformtools);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.LayoutGrid"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.LayoutGrid"));
     const QString gridShortcut = osMac ? tr("Meta+G") : tr("Ctrl+G");
     addToolAction(m_fwm->actionGridLayout(), am, m_contexts,
                   m_toolActionIds.back(),  mformtools, gridShortcut);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.LayoutBreak"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.LayoutBreak"));
     addToolAction(m_fwm->actionBreakLayout(), am, m_contexts,
                   m_toolActionIds.back(), mformtools);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.LayoutAdjustSize"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.LayoutAdjustSize"));
     const QString adjustShortcut = osMac ? tr("Meta+J") : tr("Ctrl+J");
     addToolAction(m_fwm->actionAdjustSize(), am, m_contexts,
                   m_toolActionIds.back(),  mformtools, adjustShortcut);
 
-    m_toolActionIds.push_back(QLatin1String("FormEditor.SimplifyLayout"));
+    m_toolActionIds.push_back(Core::Id("FormEditor.SimplifyLayout"));
     addToolAction(m_fwm->actionSimplifyLayout(), am, m_contexts,
                   m_toolActionIds.back(),  mformtools);
 
-    createSeparator(this, am, m_contexts, mformtools, QLatin1String("FormEditor.Menu.Tools.Separator1"));
+    createSeparator(this, am, m_contexts, mformtools, Core::Id("FormEditor.Menu.Tools.Separator1"));
 
     addToolAction(m_fwm->actionLower(), am, m_contexts,
-                  QLatin1String("FormEditor.Lower"), mformtools);
+                  Core::Id("FormEditor.Lower"), mformtools);
 
     addToolAction(m_fwm->actionRaise(), am, m_contexts,
-                  QLatin1String("FormEditor.Raise"), mformtools);
+                  Core::Id("FormEditor.Raise"), mformtools);
 
     // Commands that do not go into the editor toolbar
-    createSeparator(this, am, m_contexts, mformtools, QLatin1String("FormEditor.Menu.Tools.Separator2"));
+    createSeparator(this, am, m_contexts, mformtools, Core::Id("FormEditor.Menu.Tools.Separator2"));
 
 #if QT_VERSION >= 0x050000
     m_actionPreview = m_fwm->action(QDesignerFormWindowManagerInterface::DefaultPreviewAction);
@@ -558,7 +556,7 @@ void FormEditorW::setupActions()
 #endif
     QTC_ASSERT(m_actionPreview, return);
     addToolAction(m_actionPreview,  am,  m_contexts,
-                   QLatin1String("FormEditor.Preview"), mformtools, tr("Alt+Shift+R"));
+                   Core::Id("FormEditor.Preview"), mformtools, tr("Alt+Shift+R"));
 
     // Preview in style...
 #if QT_VERSION >= 0x050000
@@ -573,9 +571,9 @@ void FormEditorW::setupActions()
     setPreviewMenuEnabled(false);
 
     // Form settings
-    createSeparator(this, am, m_contexts,  medit, QLatin1String("FormEditor.Edit.Separator2"), Core::Constants::G_EDIT_OTHER);
+    createSeparator(this, am, m_contexts,  medit, Core::Id("FormEditor.Edit.Separator2"), Core::Constants::G_EDIT_OTHER);
 
-    createSeparator(this, am, m_contexts, mformtools, QLatin1String("FormEditor.Menu.Tools.Separator3"));
+    createSeparator(this, am, m_contexts, mformtools, Core::Id("FormEditor.Menu.Tools.Separator3"));
 
     m_actionSwitchSource = new QAction(tr("Switch Source/Form"), this);
     connect(m_actionSwitchSource, SIGNAL(triggered()), this, SLOT(switchSourceForm()));
@@ -583,21 +581,21 @@ void FormEditorW::setupActions()
     // Switch form/source in editor/design contexts.
     Core::Context switchContexts = m_contexts;
     switchContexts.add(Core::Constants::C_EDITORMANAGER);
-    addToolAction(m_actionSwitchSource, am, switchContexts, QLatin1String("FormEditor.FormSwitchSource"), mformtools,
+    addToolAction(m_actionSwitchSource, am, switchContexts, Core::Id("FormEditor.FormSwitchSource"), mformtools,
                   tr("Shift+F4"));
 
-    createSeparator(this, am, m_contexts, mformtools, QLatin1String("FormEditor.Menu.Tools.Separator4"));
+    createSeparator(this, am, m_contexts, mformtools, Core::Id("FormEditor.Menu.Tools.Separator4"));
 #if QT_VERSION >= 0x050000
     QAction *actionFormSettings = m_fwm->action(QDesignerFormWindowManagerInterface::FormWindowSettingsDialogAction);
 #else
     QAction *actionFormSettings = m_fwm->actionShowFormWindowSettingsDialog();
 #endif
-    addToolAction(actionFormSettings, am, m_contexts, QLatin1String("FormEditor.FormSettings"), mformtools);
+    addToolAction(actionFormSettings, am, m_contexts, Core::Id("FormEditor.FormSettings"), mformtools);
 
-    createSeparator(this, am, m_contexts, mformtools, QLatin1String("FormEditor.Menu.Tools.Separator5"));
+    createSeparator(this, am, m_contexts, mformtools, Core::Id("FormEditor.Menu.Tools.Separator5"));
     m_actionAboutPlugins = new QAction(tr("About Qt Designer plugins...."), this);
     addToolAction(m_actionAboutPlugins,  am,  m_contexts,
-                   QLatin1String("FormEditor.AboutPlugins"), mformtools);
+                   Core::Id("FormEditor.AboutPlugins"), mformtools);
     connect(m_actionAboutPlugins,  SIGNAL(triggered()), m_fwm,
 #if QT_VERSION >= 0x050000
             SLOT(showPluginDialog())
@@ -608,15 +606,15 @@ void FormEditorW::setupActions()
     m_actionAboutPlugins->setEnabled(false);
 
     // FWM
-    connect(m_fwm, SIGNAL(activeFormWindowChanged(QDesignerFormWindowInterface *)), this, SLOT(activeFormWindowChanged(QDesignerFormWindowInterface *)));
+    connect(m_fwm, SIGNAL(activeFormWindowChanged(QDesignerFormWindowInterface*)), this, SLOT(activeFormWindowChanged(QDesignerFormWindowInterface*)));
 }
 
 QToolBar *FormEditorW::createEditorToolBar() const
 {
     QToolBar *editorToolBar = new QToolBar;
-    Core::ActionManager *am = m_core->actionManager();
-    const QStringList::const_iterator cend = m_toolActionIds.constEnd();
-    for (QStringList::const_iterator it = m_toolActionIds.constBegin(); it != cend; ++it) {
+    Core::ActionManager *am = Core::ICore::actionManager();
+    const QList<Core::Id>::const_iterator cend = m_toolActionIds.constEnd();
+    for (QList<Core::Id>::const_iterator it = m_toolActionIds.constBegin(); it != cend; ++it) {
         Core::Command *cmd = am->command(*it);
         QTC_ASSERT(cmd, continue);
         QAction *action = cmd->action();
@@ -633,7 +631,7 @@ Core::ActionContainer *FormEditorW::createPreviewStyleMenu(Core::ActionManager *
                                                             QActionGroup *actionGroup)
 {
     const QString menuId = QLatin1String(M_FORMEDITOR_PREVIEW);
-    Core::ActionContainer *menuPreviewStyle = am->createMenu(menuId);
+    Core::ActionContainer *menuPreviewStyle = am->createMenu(M_FORMEDITOR_PREVIEW);
     menuPreviewStyle->menu()->setTitle(tr("Preview in"));
 
     // The preview menu is a list of invisible actions for the embedded design
@@ -655,7 +653,7 @@ Core::ActionContainer *FormEditorW::createPreviewStyleMenu(Core::ActionManager *
             name += dot;
         }
         name += data.toString();
-        Core::Command *command = am->registerAction(a, name, m_contexts);
+        Core::Command *command = am->registerAction(a, Core::Id(name), m_contexts);
         bindShortcut(command, a);
         if (isDeviceProfile) {
             command->setAttribute(Core::Command::CA_UpdateText);
@@ -674,14 +672,14 @@ void FormEditorW::setPreviewMenuEnabled(bool e)
 
 void FormEditorW::saveSettings(QSettings *s)
 {
-    s->beginGroup(settingsGroup);
+    s->beginGroup(QLatin1String(settingsGroupC));
     m_editorWidget->saveSettings(s);
     s->endGroup();
 }
 
 void FormEditorW::critical(const QString &errorMessage)
 {
-    QMessageBox::critical(m_core->mainWindow(), tr("Designer"),  errorMessage);
+    QMessageBox::critical(Core::ICore::mainWindow(), tr("Designer"),  errorMessage);
 }
 
 // Apply the command shortcut to the action and connects to the command's keySequenceChanged signal
@@ -700,7 +698,7 @@ QAction *FormEditorW::createEditModeAction(QActionGroup *ag,
                                      Core::ActionManager *am,
                                      Core::ActionContainer *medit,
                                      const QString &actionName,
-                                     const QString &name,
+                                     const Core::Id &id,
                                      int toolNumber,
                                      const QString &iconName,
                                      const QString &keySequence)
@@ -709,7 +707,7 @@ QAction *FormEditorW::createEditModeAction(QActionGroup *ag,
     rc->setCheckable(true);
     if (!iconName.isEmpty())
          rc->setIcon(designerIcon(iconName));
-    Core::Command *command = am->registerAction(rc, name, context);
+    Core::Command *command = am->registerAction(rc, id, context);
     command->setAttribute(Core::Command::CA_Hide);
     if (!keySequence.isEmpty())
         command->setDefaultKeySequence(QKeySequence(keySequence));
@@ -722,10 +720,10 @@ QAction *FormEditorW::createEditModeAction(QActionGroup *ag,
 
 // Create a tool action
 Core::Command *FormEditorW::addToolAction(QAction *a, Core::ActionManager *am,
-                                          const Core::Context &context, const QString &name,
+                                          const Core::Context &context, const Core::Id &id,
                                           Core::ActionContainer *c1, const QString &keySequence)
 {
-    Core::Command *command = am->registerAction(a, name, context);
+    Core::Command *command = am->registerAction(a, id, context);
     if (!keySequence.isEmpty())
         command->setDefaultKeySequence(QKeySequence(keySequence));
     if (!a->isSeparator())
@@ -759,7 +757,7 @@ EditorData FormEditorW::createEditor(QWidget *parent)
     data.formWindowEditor = xmlEditor->designerEditor();
     connect(data.widgetHost, SIGNAL(formWindowSizeChanged(int,int)),
             xmlEditor, SIGNAL(changed()));
-    connect(data.formWindowEditor->file(), SIGNAL(changed()),
+    connect(data.formWindowEditor->document(), SIGNAL(changed()),
             resourceHandler, SLOT(updateResources()));
     m_editorWidget->add(data);
 
@@ -784,7 +782,7 @@ void FormEditorW::currentEditorChanged(Core::IEditor *editor)
     if (Designer::Constants::Internal::debug)
         qDebug() << Q_FUNC_INFO << editor << " of " << m_fwm->formWindowCount();
 
-    if (editor && editor->id() == QLatin1String(Constants::K_DESIGNER_XML_EDITOR_ID)) {
+    if (editor && editor->id() == Core::Id(Constants::K_DESIGNER_XML_EDITOR_ID)) {
         FormWindowEditor *xmlEditor = qobject_cast<FormWindowEditor *>(editor);
         QTC_ASSERT(xmlEditor, return);
         ensureInitStage(FullyInitialized);
@@ -852,9 +850,10 @@ void FormEditorW::print()
     if (!fw)
         return;
 
-    const bool oldFullPage =  m_core->printer()->fullPage();
-    const QPrinter::Orientation oldOrientation =  m_core->printer()->orientation ();
-    m_core->printer()->setFullPage(false);
+    QPrinter *printer = Core::ICore::printer();
+    const bool oldFullPage =  printer->fullPage();
+    const QPrinter::Orientation oldOrientation =  printer->orientation ();
+    printer->setFullPage(false);
     do {
         // Grab the image to be able to a suggest suitable orientation
         QString errorMessage;
@@ -869,19 +868,20 @@ void FormEditorW::print()
         }
 
         const QSizeF pixmapSize = pixmap.size();
-        m_core->printer()->setOrientation( pixmapSize.width() > pixmapSize.height() ?  QPrinter::Landscape :  QPrinter::Portrait);
+        printer->setOrientation( pixmapSize.width() > pixmapSize.height() ?  QPrinter::Landscape :  QPrinter::Portrait);
 
         // Printer parameters
-        QPrintDialog dialog(m_core->printer(), fw);
+        QPrintDialog dialog(printer, fw);
         if (!dialog.exec())
            break;
 
-        const QCursor oldCursor = m_core->mainWindow()->cursor();
-        m_core->mainWindow()->setCursor(Qt::WaitCursor);
+        QWidget *mainWindow = Core::ICore::mainWindow();
+        const QCursor oldCursor = mainWindow->cursor();
+        mainWindow->setCursor(Qt::WaitCursor);
         // Estimate of required scaling to make form look the same on screen and printer.
-        const double suggestedScaling = static_cast<double>(m_core->printer()->physicalDpiX()) /  static_cast<double>(fw->physicalDpiX());
+        const double suggestedScaling = static_cast<double>(printer->physicalDpiX()) /  static_cast<double>(fw->physicalDpiX());
 
-        QPainter painter(m_core->printer());
+        QPainter painter(printer);
         painter.setRenderHint(QPainter::SmoothPixmapTransform);
 
         // Clamp to page
@@ -896,19 +896,19 @@ void FormEditorW::print()
         painter.translate(xOffset, yOffset);
         painter.scale(scaling, scaling);
         painter.drawPixmap(0, 0, pixmap);
-        m_core->mainWindow()->setCursor(oldCursor);
+        mainWindow->setCursor(oldCursor);
 
     } while (false);
-    m_core->printer()->setFullPage(oldFullPage);
-    m_core->printer()->setOrientation(oldOrientation);
+    printer->setFullPage(oldFullPage);
+    printer->setOrientation(oldOrientation);
 }
 
 // Find out current existing editor file
-static QString currentFile(const Core::EditorManager *em)
+static QString currentFile()
 {
-    if (Core::IEditor *editor = em->currentEditor())
-        if (const Core::IFile *file = editor->file()) {
-            const QString fileName = file->fileName();
+    if (Core::IEditor *editor = Core::EditorManager::instance()->currentEditor())
+        if (const Core::IDocument *document= editor->document()) {
+            const QString fileName = document->fileName();
             if (!fileName.isEmpty() && QFileInfo(fileName).isFile())
                 return fileName;
         }
@@ -917,13 +917,13 @@ static QString currentFile(const Core::EditorManager *em)
 
 // Switch between form ('ui') and source file ('cpp'):
 // Find corresponding 'other' file, simply assuming it is in the same directory.
-static QString otherFile(const Core::EditorManager *em)
+static QString otherFile()
 {
     // Determine mime type of current file.
-    const QString current = currentFile(em);
+    const QString current = currentFile();
     if (current.isEmpty())
         return QString();
-    const Core::MimeDatabase *mdb = Core::ICore::instance()->mimeDatabase();
+    const Core::MimeDatabase *mdb = Core::ICore::mimeDatabase();
     const Core::MimeType currentMimeType = mdb->findByFile(current);
     if (!currentMimeType)
         return QString();
@@ -952,10 +952,9 @@ static QString otherFile(const Core::EditorManager *em)
 
 void FormEditorW::switchSourceForm()
 {
-    Core::EditorManager *em = Core::EditorManager::instance();
-    const QString fileToOpen = otherFile(em);
+    const QString fileToOpen = otherFile();
     if (!fileToOpen.isEmpty())
-        em->openEditor(fileToOpen, QString(), Core::EditorManager::ModeSwitch);
+        Core::ICore::editorManager()->openEditor(fileToOpen, Core::Id(), Core::EditorManager::ModeSwitch);
 }
 
 } // namespace Internal
