@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -35,10 +35,10 @@
 
 #include "searchresultwindow.h"
 
-#include <QtCore/QAbstractItemModel>
-#include <QtCore/QRegExp>
-#include <QtGui/QFont>
-#include <QtGui/QTextDocument>
+#include <QAbstractItemModel>
+#include <QRegExp>
+#include <QFont>
+#include <QTextDocument>
 
 namespace Find {
 namespace Internal {
@@ -70,11 +70,6 @@ public:
 
     QList<QModelIndex> addResults(const QList<SearchResultItem> &items, SearchResult::AddMode mode);
 
-    QModelIndex find(const QRegExp &expr, const QModelIndex &index,
-                     QTextDocument::FindFlags flags, bool startWithCurrentIndex, bool *wrapped = 0);
-    QModelIndex find(const QString &term, const QModelIndex &index,
-                     QTextDocument::FindFlags flags, bool startWithCurrentIndex, bool *wrapped = 0);
-
 signals:
     void jumpToSearchResult(const QString &fileName, int lineNumber,
                             int searchTermStart, int searchTermLength);
@@ -90,8 +85,6 @@ private:
     bool setCheckState(const QModelIndex &idx, Qt::CheckState checkState, bool firstCall = true);
     QModelIndex nextIndex(const QModelIndex &idx, bool *wrapped = 0) const;
     QModelIndex prevIndex(const QModelIndex &idx, bool *wrapped = 0) const;
-    QModelIndex followingIndex(const QModelIndex &idx, bool backward, bool includeGenerated = false,
-                               bool *wrapped = 0);
     SearchResultTreeItem *treeItemAtIndex(const QModelIndex &idx) const;
 
     SearchResultTreeItem *m_rootItem;
