@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -33,8 +33,8 @@
 #ifndef SETTINGSPAGE_H
 #define SETTINGSPAGE_H
 
-#include <QtGui/QWidget>
-#include <QtCore/QPointer>
+#include <QWidget>
+#include <QPointer>
 
 #include <vcsbase/vcsbaseoptionspage.h>
 
@@ -59,14 +59,11 @@ public:
 
     QString searchKeywords() const;
 
-private slots:
-    void setSystemPath();
-
 private:
     Ui::SettingsPage m_ui;
 };
 
-class SettingsPage : public VCSBase::VCSBaseOptionsPage
+class SettingsPage : public VcsBase::VcsBaseOptionsPage
 {
     Q_OBJECT
 
