@@ -2,30 +2,29 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** No Commercial Usage
-**
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
 **
 ** GNU Lesser General Public License Usage
 **
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this file.
+** Please review the following information to ensure the GNU Lesser General
+** Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
+** Other Usage
+**
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at qt-info@nokia.com.
 **
@@ -33,23 +32,23 @@
 
 #include "centralwidget.h"
 
-#include "helpmanager.h"
 #include "helpviewer.h"
+#include "localhelpmanager.h"
 #include "topicchooser.h"
 
-#include <QtCore/QEvent>
-#include <QtCore/QTimer>
+#include <QEvent>
+#include <QTimer>
 
-#include <QtGui/QKeyEvent>
-#include <QtGui/QLayout>
-#include <QtGui/QPageSetupDialog>
-#include <QtGui/QPrinter>
-#include <QtGui/QPrintDialog>
-#include <QtGui/QPrintPreviewDialog>
-#include <QtGui/QStackedWidget>
+#include <QKeyEvent>
+#include <QLayout>
+#include <QPageSetupDialog>
+#include <QPrinter>
+#include <QPrintDialog>
+#include <QPrintPreviewDialog>
+#include <QStackedWidget>
 
-#include <QtHelp/QHelpEngine>
-#include <QtHelp/QHelpSearchEngine>
+#include <QHelpEngine>
+#include <QHelpSearchEngine>
 
 using namespace Help::Internal;
 
@@ -167,9 +166,9 @@ void CentralWidget::setCurrentPage(HelpViewer *page)
 }
 
 bool CentralWidget::find(const QString &txt, Find::FindFlags flags,
-    bool incremental)
+    bool incremental, bool *wrapped)
 {
-    return currentHelpViewer()->findText(txt, flags, incremental, false);
+    return currentHelpViewer()->findText(txt, flags, incremental, false, wrapped);
 }
 
 // -- public slots
@@ -328,7 +327,7 @@ void CentralWidget::highlightSearchTerms()
                 case QHelpSearchQuery::DEFAULT:
                 case QHelpSearchQuery::ATLEAST:
                     foreach (QString term, query.wordList)
-                        terms.append(term.remove(QLatin1String("\"")));
+                        terms.append(term.remove(QLatin1Char('"')));
                 }
             }
         }
