@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -35,8 +35,8 @@
 #include <coreplugin/editormanager/editormanager.h>
 #include <coreplugin/editormanager/ieditor.h>
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QDir>
+#include <QFileInfo>
+#include <QDir>
 
 using namespace Core;
 using namespace Locator;
@@ -88,7 +88,7 @@ void OpenDocumentsFilter::refreshInternally()
         OpenEditorsModel::Entry entry;
         // don't work on IEditor directly, since that will be useless with split windows
         entry.m_displayName = editor->displayName();
-        entry.m_fileName = editor->file()->fileName();
+        entry.m_fileName = editor->document()->fileName();
         m_editors.append(entry);
     }
     m_editors += m_editorManager->openedEditorsModel()->restoredEditors();
@@ -102,5 +102,5 @@ void OpenDocumentsFilter::refresh(QFutureInterface<void> &future)
 
 void OpenDocumentsFilter::accept(FilterEntry selection) const
 {
-    m_editorManager->openEditor(selection.internalData.toString(), QString(), Core::EditorManager::ModeSwitch);
+    m_editorManager->openEditor(selection.internalData.toString(), Core::Id(), Core::EditorManager::ModeSwitch);
 }
