@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -41,12 +41,12 @@
 #include <texteditor/itexteditor.h>
 #include <coreplugin/editormanager/editormanager.h>
 
-#include <QtCore/QSettings>
-#include <QtCore/QRegExp>
+#include <QSettings>
+#include <QRegExp>
 
-#include <QtGui/QGridLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QHBoxLayout>
+#include <QGridLayout>
+#include <QLabel>
+#include <QHBoxLayout>
 
 using namespace Find;
 using namespace ProjectExplorer;
@@ -57,7 +57,7 @@ AllProjectsFind::AllProjectsFind(ProjectExplorerPlugin *plugin)
     : m_plugin(plugin),
       m_configWidget(0)
 {
-    connect(m_plugin, SIGNAL(fileListChanged()), this, SIGNAL(changed()));
+    connect(m_plugin, SIGNAL(fileListChanged()), this, SLOT(handleFileListChanged()));
 }
 
 QString AllProjectsFind::id() const
@@ -73,26 +73,26 @@ QString AllProjectsFind::displayName() const
 bool AllProjectsFind::isEnabled() const
 {
     return BaseFileFind::isEnabled()
-            && m_plugin->session() != 0
             && m_plugin->session()->projects().count() > 0;
 }
 
-QList<Project *> AllProjectsFind::projects() const
+Utils::FileIterator *AllProjectsFind::files(const QStringList &nameFilters,
+                                            const QVariant &additionalParameters) const
 {
-    Q_ASSERT(m_plugin->session());
-    return m_plugin->session()->projects();
+    Q_UNUSED(additionalParameters)
+    return filesForProjects(nameFilters, m_plugin->session()->projects());
 }
 
-Utils::FileIterator *AllProjectsFind::files() const
+Utils::FileIterator *AllProjectsFind::filesForProjects(const QStringList &nameFilters,
+                                            const QList<Project *> &projects) const
 {
     QList<QRegExp> filterRegs;
-    QStringList nameFilters = fileNameFilters();
     foreach (const QString &filter, nameFilters) {
         filterRegs << QRegExp(filter, Qt::CaseInsensitive, QRegExp::Wildcard);
     }
     QMap<QString, QTextCodec *> openEditorEncodings = TextEditor::ITextEditor::openedTextEditorsEncodings();
     QMap<QString, QTextCodec *> encodings;
-    foreach (const Project *project, projects()) {
+    foreach (const Project *project, projects) {
         QStringList projectFiles = project->files(Project::AllFiles);
         QStringList filteredFiles;
         if (!filterRegs.isEmpty()) {
@@ -117,6 +117,11 @@ Utils::FileIterator *AllProjectsFind::files() const
     return new Utils::FileIterator(encodings.keys(), encodings.values());
 }
 
+QVariant AllProjectsFind::additionalParameters() const
+{
+    return QVariant();
+}
+
 QString AllProjectsFind::label() const
 {
     return tr("All Projects:");
@@ -128,6 +133,11 @@ QString AllProjectsFind::toolTip() const
     return tr("Filter: %1\n%2").arg(fileNameFilters().join(QLatin1String(",")));
 }
 
+void AllProjectsFind::handleFileListChanged()
+{
+    emit enabledChanged(isEnabled());
+}
+
 QWidget *AllProjectsFind::createConfigWidget()
 {
     if (!m_configWidget) {
