@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -61,7 +61,7 @@ class VarManMacroExpander : public Utils::AbstractQtcMacroExpander {
 public:
     virtual bool resolveMacro(const QString &name, QString *ret)
     {
-        *ret = Core::VariableManager::instance()->value(name);
+        *ret = Core::VariableManager::instance()->value(name.toUtf8());
         return !ret->isEmpty();
     }
 };
