@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -36,7 +36,7 @@
 #include <QDeclarativeContext>
 #include <QDeclarativeEngine>
 #include <QDeclarativeComponent>
-#include <QtCore/QDebug>
+#include <QDebug>
 #include <QFile>
 #include <QPixmap>
 #include <QTimeLine>
@@ -831,7 +831,7 @@ public:
      QComboBoxDeclarativeUI(QObject *parent = 0) : QObject(parent), m_itemsSet(false)
      {
          cb = qobject_cast<QComboBox*>(parent);
-         connect(cb, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(setCurrentText(const QString &)));
+         connect(cb, SIGNAL(currentIndexChanged(QString)), this, SLOT(setCurrentText(QString)));
      }
 
      QString currentText() const
