@@ -2,30 +2,29 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** No Commercial Usage
-**
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
 **
 ** GNU Lesser General Public License Usage
 **
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this file.
+** Please review the following information to ensure the GNU Lesser General
+** Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
+** Other Usage
+**
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at qt-info@nokia.com.
 **
@@ -39,8 +38,13 @@
 #include <model.h>
 #include <rewriterview.h>
 #include <formeditorwidget.h>
+#include <stateseditorwidget.h>
+#include <itemlibrarywidget.h>
+#include <componentaction.h>
+#include <toolbox.h>
 
 #include <coreplugin/coreconstants.h>
+#include <coreplugin/designmode.h>
 #include <coreplugin/modemanager.h>
 #include <coreplugin/outputpane.h>
 #include <coreplugin/icore.h>
@@ -54,21 +58,23 @@
 #include <extensionsystem/pluginmanager.h>
 
 #include <utils/parameteraction.h>
+#include <utils/fileutils.h>
 #include <utils/qtcassert.h>
+#include <utils/crumblepath.h>
 
-#include <QtCore/QSettings>
-#include <QtCore/QEvent>
-#include <QtCore/QDir>
-#include <QtGui/QApplication>
-#include <QtGui/QPlainTextEdit>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QScrollArea>
-#include <QtGui/QTabWidget>
-#include <QtGui/QToolButton>
-#include <QtGui/QMenu>
-#include <QtGui/QClipboard>
-#include <QtGui/QLabel>
-#include <QtGui/QProgressDialog>
+#include <QSettings>
+#include <QEvent>
+#include <QDir>
+#include <QApplication>
+#include <QPlainTextEdit>
+#include <QVBoxLayout>
+#include <QScrollArea>
+#include <QTabWidget>
+#include <QToolButton>
+#include <QMenu>
+#include <QClipboard>
+#include <QLabel>
+#include <QProgressDialog>
 
 using Core::MiniSplitter;
 using Core::IEditor;
@@ -76,30 +82,29 @@ using Core::EditorManager;
 
 using namespace QmlDesigner;
 
-Q_DECLARE_METATYPE(Core::IEditor*)
-
 enum {
     debug = false
 };
 
-const char * const SB_NAVIGATOR = "Navigator";
-const char * const SB_LIBRARY = "Library";
-const char * const SB_PROPERTIES = "Properties";
-const char * const SB_PROJECTS = "Projects";
-const char * const SB_FILESYSTEM = "FileSystem";
-const char * const SB_OPENDOCUMENTS = "OpenDocuments";
+const char SB_NAVIGATOR[] = "Navigator";
+const char SB_LIBRARY[] = "Library";
+const char SB_PROPERTIES[] = "Properties";
+const char SB_PROJECTS[] = "Projects";
+const char SB_FILESYSTEM[] = "FileSystem";
+const char SB_OPENDOCUMENTS[] = "OpenDocuments";
 
 namespace QmlDesigner {
 namespace Internal {
 
+DesignModeWidget *DesignModeWidget::s_instance = 0;
+
 DocumentWarningWidget::DocumentWarningWidget(DesignModeWidget *parent) :
-        QFrame(parent),
+        Utils::FakeToolTip(parent),
         m_errorMessage(new QLabel("Placeholder", this)),
         m_goToError(new QLabel(this)),
         m_designModeWidget(parent)
 {
-    setFrameStyle(QFrame::Panel | QFrame::Raised);
-    setLineWidth(1);
+    setWindowFlags(Qt::Widget); //We only want the visual style from a ToolTip
     setForegroundRole(QPalette::ToolTipText);
     setBackgroundRole(QPalette::ToolTipBase);
     setAutoFillBackground(true);
@@ -132,10 +137,52 @@ void DocumentWarningWidget::setError(const RewriterView::Error &error)
     resize(layout()->totalSizeHint());
 }
 
+class ItemLibrarySideBarItem : public Core::SideBarItem
+{
+public:
+    explicit ItemLibrarySideBarItem(ItemLibraryWidget *widget, const QString &id);
+    virtual ~ItemLibrarySideBarItem();
+
+    virtual QList<QToolButton *> createToolBarWidgets();
+};
+
+ItemLibrarySideBarItem::ItemLibrarySideBarItem(ItemLibraryWidget *widget, const QString &id) : Core::SideBarItem(widget, id) {}
+
+ItemLibrarySideBarItem::~ItemLibrarySideBarItem()
+{
+
+}
+
+QList<QToolButton *> ItemLibrarySideBarItem::createToolBarWidgets()
+{
+    return qobject_cast<ItemLibraryWidget*>(widget())->createToolBarWidgets();
+}
+
+class NavigatorSideBarItem : public Core::SideBarItem
+{
+public:
+    explicit NavigatorSideBarItem(NavigatorWidget *widget, const QString &id);
+    virtual ~NavigatorSideBarItem();
+
+    virtual QList<QToolButton *> createToolBarWidgets();
+};
+
+NavigatorSideBarItem::NavigatorSideBarItem(NavigatorWidget *widget, const QString &id) : Core::SideBarItem(widget, id) {}
+
+NavigatorSideBarItem::~NavigatorSideBarItem()
+{
+
+}
+
+QList<QToolButton *> NavigatorSideBarItem::createToolBarWidgets()
+{
+    return qobject_cast<NavigatorWidget*>(widget())->createToolBarWidgets();
+}
+
 void DocumentWarningWidget::goToError()
 {
-    m_designModeWidget->textEditor()->gotoLine(m_error.line(), m_error.column());
-    Core::ModeManager::instance()->activateMode(Core::Constants::MODE_EDIT);
+    m_designModeWidget->textEditor()->gotoLine(m_error.line(), m_error.column() - 1);
+    Core::ModeManager::activateMode(Core::Constants::MODE_EDIT);
 }
 
 // ---------- DesignModeWidget
@@ -148,8 +195,11 @@ DesignModeWidget::DesignModeWidget(QWidget *parent) :
     m_isDisabled(false),
     m_showSidebars(true),
     m_initStatus(NotInitialized),
-    m_warningWidget(0)
+    m_warningWidget(0),
+    m_navigatorHistoryCounter(-1),
+    m_keepNavigatorHistory(false)
 {
+    s_instance = this;
     m_undoAction = new QAction(tr("&Undo"), this);
     connect(m_undoAction, SIGNAL(triggered()), this, SLOT(undo()));
     m_redoAction = new QAction(tr("&Redo"), this);
@@ -167,25 +217,26 @@ DesignModeWidget::DesignModeWidget(QWidget *parent) :
     m_hideSidebarsAction = new QAction(tr("Toggle Full Screen"), this);
     connect(m_hideSidebarsAction, SIGNAL(triggered()), this, SLOT(toggleSidebars()));
     m_restoreDefaultViewAction = new QAction(tr("&Restore Default View"), this);
+    m_goIntoComponentAction  = new QAction(tr("&Go into Component"), this);
     connect(m_restoreDefaultViewAction, SIGNAL(triggered()), SLOT(restoreDefaultView()));
+    connect(m_goIntoComponentAction, SIGNAL(triggered()), SLOT(goIntoComponent()));
     m_toggleLeftSidebarAction = new QAction(tr("Toggle &Left Sidebar"), this);
     connect(m_toggleLeftSidebarAction, SIGNAL(triggered()), SLOT(toggleLeftSidebar()));
     m_toggleRightSidebarAction = new QAction(tr("Toggle &Right Sidebar"), this);
     connect(m_toggleRightSidebarAction, SIGNAL(triggered()), SLOT(toggleRightSidebar()));
 
-    Core::ModeManager *modeManager = Core::ModeManager::instance();
-    Core::IMode *designmode = modeManager->mode(Core::Constants::MODE_DESIGN);
     m_outputPlaceholderSplitter = new Core::MiniSplitter;
-    m_outputPanePlaceholder = new StyledOutputpanePlaceHolder(designmode, m_outputPlaceholderSplitter);
+    m_outputPanePlaceholder = new StyledOutputpanePlaceHolder(Core::DesignMode::instance(), m_outputPlaceholderSplitter);
 }
 
 DesignModeWidget::~DesignModeWidget()
 {
+    s_instance = 0;
 }
 
 void DesignModeWidget::restoreDefaultView()
 {
-    QSettings *settings = Core::ICore::instance()->settings();
+    QSettings *settings = Core::ICore::settings();
     m_leftSideBar->closeAllWidgets();
     m_rightSideBar->closeAllWidgets();
     m_leftSideBar->readSettings(settings,  "none.LeftSideBar");
@@ -217,13 +268,20 @@ void DesignModeWidget::toggleSidebars()
         m_leftSideBar->setVisible(m_showSidebars);
     if (m_rightSideBar)
         m_rightSideBar->setVisible(m_showSidebars);
-    if (!m_statesEditorWidget.isNull())
-        m_statesEditorWidget->setVisible(m_showSidebars);
+    if (!m_statesEditorView.isNull())
+        m_statesEditorView->widget()->setVisible(m_showSidebars);
 
 }
 
 void DesignModeWidget::showEditor(Core::IEditor *editor)
 {
+    if (m_textEditor && editor)
+        if (m_textEditor->document()->fileName() != editor->document()->fileName()) {
+            if (!m_keepNavigatorHistory)
+                addNavigatorHistoryEntry(editor->document()->fileName());
+            setupNavigatorHistory();
+        }
+
     //
     // Prevent recursive calls to function by explicitly managing initialization status
     // (QApplication::processEvents is called explicitly at a number of places)
@@ -241,7 +299,7 @@ void DesignModeWidget::showEditor(Core::IEditor *editor)
     TextEditor::ITextEditor *textEditor = 0;
 
     if (editor) {
-        fileName = editor->file()->fileName();
+        fileName = editor->document()->fileName();
         textEdit = qobject_cast<QPlainTextEdit*>(editor->widget());
         textEditor = qobject_cast<TextEditor::ITextEditor*>(editor);
         if (textEditor)
@@ -265,16 +323,17 @@ void DesignModeWidget::showEditor(Core::IEditor *editor)
             DesignDocumentController *newDocument = new DesignDocumentController(this);
 
             newDocument->setNodeInstanceView(m_nodeInstanceView.data());
-            newDocument->setAllPropertiesBox(m_allPropertiesBox.data());
-            newDocument->setNavigator(m_navigator.data());
-            newDocument->setStatesEditorWidget(m_statesEditorWidget.data());
-            newDocument->setItemLibrary(m_itemLibrary.data());
+            newDocument->setPropertyEditorView(m_propertyEditorView.data());
+            newDocument->setNavigator(m_navigatorView.data());
+            newDocument->setStatesEditorView(m_statesEditorView.data());
+            newDocument->setItemLibraryView(m_itemLibraryView.data());
             newDocument->setFormEditorView(m_formEditorView.data());
+            newDocument->setComponentView(m_componentView.data());
 
 
             newDocument->setFileName(fileName);
 
-            document = newDocument;          
+            document = newDocument;
 
             m_documentHash.insert(textEdit, document);
         }
@@ -293,7 +352,7 @@ void DesignModeWidget::closeEditors(QList<Core::IEditor*> editors)
             }
             if (m_documentHash.contains(textEdit)) {
                 if (debug)
-                    qDebug() << Q_FUNC_INFO << editor->file()->fileName();
+                    qDebug() << Q_FUNC_INFO << editor->document()->fileName();
                 DesignDocumentController *document = m_documentHash.take(textEdit).data();
                 delete document;
             }
@@ -357,9 +416,14 @@ QAction *DesignModeWidget::restoreDefaultViewAction() const
     return m_restoreDefaultViewAction;
 }
 
+QAction *DesignModeWidget::goIntoComponentAction() const
+{
+    return m_goIntoComponentAction;
+}
+
 void DesignModeWidget::readSettings()
 {
-    QSettings *settings = Core::ICore::instance()->settings();
+    QSettings *settings = Core::ICore::settings();
 
     settings->beginGroup("Bauhaus");
     m_leftSideBar->readSettings(settings, QLatin1String("LeftSideBar"));
@@ -374,7 +438,7 @@ void DesignModeWidget::readSettings()
 
 void DesignModeWidget::saveSettings()
 {
-    QSettings *settings = Core::ICore::instance()->settings();
+    QSettings *settings = Core::ICore::settings();
 
     settings->beginGroup("Bauhaus");
     m_leftSideBar->saveSettings(settings, QLatin1String("LeftSideBar"));
@@ -447,6 +511,11 @@ void DesignModeWidget::redoAvailable(bool isAvailable)
     }
 }
 
+void DesignModeWidget::goIntoComponent()
+{
+    if (m_currentDesignDocumentController)
+        m_currentDesignDocumentController->goIntoComponent();
+}
 
 void DesignModeWidget::enable()
 {
@@ -454,7 +523,7 @@ void DesignModeWidget::enable()
         qDebug() << Q_FUNC_INFO;
     m_warningWidget->setVisible(false);
     m_formEditorView->widget()->setEnabled(true);
-    m_statesEditorWidget->setEnabled(true);
+    m_statesEditorView->widget()->setEnabled(true);
     m_leftSideBar->setEnabled(true);
     m_rightSideBar->setEnabled(true);
     m_isDisabled = false;
@@ -469,7 +538,7 @@ void DesignModeWidget::disable(const QList<RewriterView::Error> &errors)
     m_warningWidget->setVisible(true);
     m_warningWidget->move(width() / 2, height() / 2);
     m_formEditorView->widget()->setEnabled(false);
-    m_statesEditorWidget->setEnabled(false);
+    m_statesEditorView->widget()->setEnabled(false);
     m_leftSideBar->setEnabled(false);
     m_rightSideBar->setEnabled(false);
     m_isDisabled = true;
@@ -492,23 +561,27 @@ void DesignModeWidget::setAutoSynchronization(bool sync)
     if (debug)
         qDebug() << Q_FUNC_INFO << sync;
 
+    RewriterView *rewriter = m_currentDesignDocumentController->rewriterView();
+
     m_currentDesignDocumentController->blockModelSync(!sync);
 
     if (sync) {
+        if (rewriter && m_currentDesignDocumentController->model())
+            rewriter->setSelectedModelNodes(QList<ModelNode>());
         // text editor -> visual editor
         if (!m_currentDesignDocumentController->model()) {
             m_currentDesignDocumentController->loadMaster(m_currentTextEdit.data());
         } else {
             m_currentDesignDocumentController->loadCurrentModel();
+            m_componentView->resetView();
         }
 
         QList<RewriterView::Error> errors = m_currentDesignDocumentController->qmlErrors();
         if (errors.isEmpty()) {
             // set selection to text cursor
-            RewriterView *rewriter = m_currentDesignDocumentController->rewriterView();
             const int cursorPos = m_currentTextEdit->textCursor().position();
             ModelNode node = nodeForPosition(cursorPos);
-            if (node.isValid()) {
+            if (rewriter && node.isValid()) {
                 rewriter->setSelectedModelNodes(QList<ModelNode>() << node);
             }
             enable();
@@ -595,48 +668,45 @@ void DesignModeWidget::setup()
     QWidget *fileSystemExplorer = 0;
 
 
-    foreach(Core::INavigationWidgetFactory *factory, factories)
-    {
+    foreach (Core::INavigationWidgetFactory *factory, factories) {
         Core::NavigationView navigationView;
         navigationView.widget = 0;
-        if (factory->id() == QLatin1String("Projects")) {
+        if (factory->id() == Core::Id("Projects")) {
             navigationView = factory->createWidget();
             projectsExplorer = navigationView.widget;
             projectsExplorer->setWindowTitle(tr("Projects"));
-        } else if (factory->id() == QLatin1String("File System")) {
+        } else if (factory->id() == Core::Id("File System")) {
             navigationView = factory->createWidget();
             fileSystemExplorer = navigationView.widget;
             fileSystemExplorer->setWindowTitle(tr("File System"));
-        } else if (factory->id() == QLatin1String("Open Documents")) {
+        } else if (factory->id() == Core::Id("Open Documents")) {
             navigationView = factory->createWidget();
             openDocumentsWidget = navigationView.widget;
             openDocumentsWidget->setWindowTitle(tr("Open Documents"));
         }
 
-        if (navigationView.widget)
-        {
-            QFile file(":/qmldesigner/stylesheet.css");
-            file.open(QFile::ReadOnly);
-            QFile file2(":/qmldesigner/scrollbar.css");
-            file2.open(QFile::ReadOnly);
-
-            QString labelStyle = QLatin1String("QLabel { background-color: #4f4f4f; }");
-
-            QString styleSheet = file.readAll() + file2.readAll() + labelStyle;
-            navigationView.widget->setStyleSheet(styleSheet);
+        if (navigationView.widget) {
+            QByteArray sheet = Utils::FileReader::fetchQrc(":/qmldesigner/stylesheet.css");
+            sheet += Utils::FileReader::fetchQrc(":/qmldesigner/scrollbar.css");
+            sheet += "QLabel { background-color: #4f4f4f; }";
+            navigationView.widget->setStyleSheet(QString::fromLatin1(sheet));
         }
     }
 
     m_nodeInstanceView = new NodeInstanceView(this);
+    connect(m_nodeInstanceView.data(), SIGNAL(qmlPuppetCrashed()), this, SLOT(qmlPuppetCrashed()));
      // Sidebar takes ownership
-    m_navigator = new NavigatorView;
-    m_allPropertiesBox = new AllPropertiesBox;
-    m_itemLibrary = new ItemLibrary;
+    m_navigatorView = new NavigatorView;
+    m_propertyEditorView = new PropertyEditor(this);
+    m_itemLibraryView = new ItemLibraryView(this);
+
+    m_statesEditorView = new StatesEditorView(this);
 
-    m_statesEditorWidget = new StatesEditorWidget(this);
-    
     m_formEditorView = new FormEditorView(this);
+    connect(m_formEditorView->crumblePath(), SIGNAL(elementClicked(QVariant)), this, SLOT(onCrumblePathElementClicked(QVariant)));
 
+    m_componentView = new ComponentView(this);
+    m_formEditorView->widget()->toolBox()->addLeftSideAction(m_componentView->action());
     m_fakeToolBar = Core::EditorManager::createToolBar(this);
 
     m_mainSplitter = new MiniSplitter(this);
@@ -646,9 +716,9 @@ void DesignModeWidget::setup()
     m_warningWidget = new DocumentWarningWidget(this);
     m_warningWidget->setVisible(false);
 
-    Core::SideBarItem *navigatorItem = new Core::SideBarItem(m_navigator->widget(), QLatin1String(SB_NAVIGATOR));
-    Core::SideBarItem *libraryItem = new Core::SideBarItem(m_itemLibrary.data(), QLatin1String(SB_LIBRARY));
-    Core::SideBarItem *propertiesItem = new Core::SideBarItem(m_allPropertiesBox.data(), QLatin1String(SB_PROPERTIES));
+    Core::SideBarItem *navigatorItem = new NavigatorSideBarItem(m_navigatorView->widget(), QLatin1String(SB_NAVIGATOR));
+    Core::SideBarItem *libraryItem = new ItemLibrarySideBarItem(m_itemLibraryView->widget(), QLatin1String(SB_LIBRARY));
+    Core::SideBarItem *propertiesItem = new Core::SideBarItem(m_propertyEditorView->widget(), QLatin1String(SB_PROPERTIES));
 
     // default items
     m_sideBarItems << navigatorItem << libraryItem << propertiesItem;
@@ -674,11 +744,17 @@ void DesignModeWidget::setup()
     connect(m_leftSideBar, SIGNAL(availableItemsChanged()), SLOT(updateAvailableSidebarItemsRight()));
     connect(m_rightSideBar, SIGNAL(availableItemsChanged()), SLOT(updateAvailableSidebarItemsLeft()));
 
+    connect(Core::ICore::instance(), SIGNAL(coreAboutToClose()),
+            this, SLOT(deleteSidebarWidgets()));
+
     m_fakeToolBar->setToolbarCreationFlags(Core::EditorToolBar::FlagsStandalone);
     //m_fakeToolBar->addEditor(textEditor()); ### what does this mean?
-    m_fakeToolBar->setNavigationVisible(false);
+    m_fakeToolBar->setNavigationVisible(true);
 
     connect(m_fakeToolBar, SIGNAL(closeClicked()), this, SLOT(closeCurrentEditor()));
+    connect(m_fakeToolBar, SIGNAL(goForwardClicked()), this, SLOT(onGoForwardClicked()));
+    connect(m_fakeToolBar, SIGNAL(goBackClicked()), this, SLOT(onGoBackClicked()));
+    setupNavigatorHistory();
 
     // right area:
     QWidget *centerWidget = new QWidget;
@@ -688,10 +764,13 @@ void DesignModeWidget::setup()
         rightLayout->setSpacing(0);
         rightLayout->addWidget(m_fakeToolBar);
         //### we now own these here
-        rightLayout->addWidget(m_statesEditorWidget.data());
+        rightLayout->addWidget(m_statesEditorView->widget());
 
-        FormEditorContext *context = new FormEditorContext(m_formEditorView->widget());
-        Core::ICore::instance()->addContextObject(context);
+        FormEditorContext *formEditorContext = new FormEditorContext(m_formEditorView->widget());
+        Core::ICore::addContextObject(formEditorContext);
+
+        NavigatorContext *navigatorContext = new NavigatorContext(m_navigatorView->widget());
+        Core::ICore::addContextObject(navigatorContext);
 
         // editor and output panes
         m_outputPlaceholderSplitter->addWidget(m_formEditorView->widget());
@@ -718,7 +797,7 @@ void DesignModeWidget::setup()
     mainLayout->addWidget(m_mainSplitter);
 
     m_warningWidget->setVisible(false);
-    m_statesEditorWidget->setEnabled(true);
+    m_statesEditorView->widget()->setEnabled(true);
     m_leftSideBar->setEnabled(true);
     m_rightSideBar->setEnabled(true);
     m_leftSideBar->setCloseWhenEmpty(true);
@@ -742,6 +821,57 @@ void DesignModeWidget::updateAvailableSidebarItemsLeft()
     m_leftSideBar->setUnavailableItemIds(m_rightSideBar->unavailableItemIds());
 }
 
+void DesignModeWidget::deleteSidebarWidgets()
+{
+    delete m_leftSideBar;
+    delete m_rightSideBar;
+    m_leftSideBar = 0;
+    m_rightSideBar = 0;
+}
+
+void DesignModeWidget::qmlPuppetCrashed()
+{
+    QList<RewriterView::Error> errorList;
+    RewriterView::Error error(tr("Qt Quick emulation layer crashed"));
+    errorList << error;
+    disable(errorList);
+}
+
+void DesignModeWidget::onGoBackClicked()
+{
+    if (m_navigatorHistoryCounter > 0) {
+        --m_navigatorHistoryCounter;
+        m_keepNavigatorHistory = true;
+
+        Core::EditorManager::instance()->openEditor(m_navigatorHistory.at(m_navigatorHistoryCounter));
+
+        m_keepNavigatorHistory = false;
+    }
+}
+
+void DesignModeWidget::onGoForwardClicked()
+{
+    if (m_navigatorHistoryCounter < (m_navigatorHistory.size() - 1)) {
+        ++m_navigatorHistoryCounter;
+        m_keepNavigatorHistory = true;
+
+        Core::EditorManager::instance()->openEditor(m_navigatorHistory.at(m_navigatorHistoryCounter));
+
+        m_keepNavigatorHistory = false;
+    }
+}
+
+void DesignModeWidget::onCrumblePathElementClicked(const QVariant &data)
+{
+    currentDesignDocumentController()->setCrumbleBarInfo(data.value<CrumbleBarInfo>());
+}
+
+DesignModeWidget *DesignModeWidget::instance()
+{
+    return s_instance;
+}
+
+
 void DesignModeWidget::resizeEvent(QResizeEvent *event)
 {
     if (m_warningWidget)
@@ -776,6 +906,24 @@ ModelNode DesignModeWidget::nodeForPosition(int cursorPos) const
     return bestNode;
 }
 
+void DesignModeWidget::setupNavigatorHistory()
+{
+    const bool canGoBack = m_navigatorHistoryCounter > 0;
+    const bool canGoForward = m_navigatorHistoryCounter < (m_navigatorHistory.size() - 1);
+    m_fakeToolBar->setCanGoBack(canGoBack);
+    m_fakeToolBar->setCanGoForward(canGoForward);
+}
+
+void DesignModeWidget::addNavigatorHistoryEntry(const QString &fileName)
+{
+    if (m_navigatorHistoryCounter > 0)
+        m_navigatorHistory.insert(m_navigatorHistoryCounter + 1, fileName);
+    else
+        m_navigatorHistory.append(fileName);
+
+    ++m_navigatorHistoryCounter;
+}
+
 
 QString DesignModeWidget::contextHelpId() const
 {
