@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -32,7 +32,7 @@
 
 #include "qtquickplugin.h"
 #include <widgetplugin_helper.h>
-#include <QtCore/QtPlugin>
+#include <QtPlugin>
 #include <private/qdeclarativerectangle_p.h>
 #include <private/qdeclarativescalegrid_p_p.h>
 
