@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -33,10 +33,10 @@
 #ifndef PLUGINGENERATOR_H
 #define PLUGINGENERATOR_H
 
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QList>
-#include <QtCore/QMap>
+#include <QObject>
+#include <QString>
+#include <QList>
+#include <QMap>
 
 QT_BEGIN_NAMESPACE
 class QWidget;
