@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -35,14 +35,15 @@
 
 #include "qt4projectmanager_global.h"
 
-#include <coreplugin/ifile.h>
+#include <utils/fileutils.h>
+#include <coreplugin/idocument.h>
 #include <projectexplorer/projectnodes.h>
 
-#include <QtCore/QHash>
-#include <QtCore/QStringList>
-#include <QtCore/QDateTime>
-#include <QtCore/QMap>
-#include <QtCore/QFutureWatcher>
+#include <QHash>
+#include <QStringList>
+#include <QDateTime>
+#include <QMap>
+#include <QFutureWatcher>
 
 // defined in proitems.h
 QT_BEGIN_NAMESPACE
@@ -81,6 +82,10 @@ enum Qt4ProjectType {
 enum Qt4Variable {
     DefinesVar = 1,
     IncludePathVar,
+    CppFlagsVar,
+    CppHeaderVar,
+    CppSourceVar,
+    ObjCSourceVar,
     UiDirVar,
     MocDirVar,
     PkgConfigVar,
@@ -113,7 +118,6 @@ using ProjectExplorer::FileType;
 
 namespace Internal {
 class Qt4UiCodeModelSupport;
-class ProFileReader;
 class Qt4PriFile;
 struct InternalNode;
 }
@@ -125,6 +129,7 @@ class QT4PROJECTMANAGER_EXPORT Qt4PriFileNode : public ProjectExplorer::ProjectN
 
 public:
     Qt4PriFileNode(Qt4Project *project, Qt4ProFileNode* qt4ProFileNode, const QString &filePath);
+    ~Qt4PriFileNode();
 
     void update(ProFile *includeFileExact, QtSupport::ProFileReader *readerExact, ProFile *includeFileCumlative, QtSupport::ProFileReader *readerCumalative);
 
@@ -163,8 +168,8 @@ protected:
     void clear();
     static QStringList varNames(FileType type);
     static QStringList dynamicVarNames(QtSupport::ProFileReader *readerExact, QtSupport::ProFileReader *readerCumulative);
-    static QSet<QString> filterFilesProVariables(ProjectExplorer::FileType fileType, const QSet<QString> &files);
-    static QSet<QString> filterFilesRecursiveEnumerata(ProjectExplorer::FileType fileType, const QSet<QString> &files);
+    static QSet<Utils::FileName> filterFilesProVariables(ProjectExplorer::FileType fileType, const QSet<Utils::FileName> &files);
+    static QSet<Utils::FileName> filterFilesRecursiveEnumerata(ProjectExplorer::FileType fileType, const QSet<Utils::FileName> &files);
 
     enum ChangeType {
         AddToProFile,
@@ -202,8 +207,8 @@ private:
 
     // Memory is cheap...
     // TODO (really that cheap?)
-    QMap<ProjectExplorer::FileType, QSet<QString> > m_files;
-    QSet<QString> m_recursiveEnumerateFiles;
+    QMap<ProjectExplorer::FileType, QSet<Utils::FileName> > m_files;
+    QSet<Utils::FileName> m_recursiveEnumerateFiles;
     QSet<QString> m_watchedFolders;
     bool m_includedInExactParse;
 
@@ -215,7 +220,7 @@ private:
 };
 
 namespace Internal {
-class Qt4PriFile : public Core::IFile
+class Qt4PriFile : public Core::IDocument
 {
     Q_OBJECT
 public:
@@ -229,7 +234,6 @@ public:
     virtual QString mimeType() const;
 
     virtual bool isModified() const;
-    virtual bool isReadOnly() const;
     virtual bool isSaveAsAllowed() const;
 
     ReloadBehavior reloadBehavior(ChangeTrigger state, ChangeType type) const;
@@ -277,8 +281,8 @@ struct QT4PROJECTMANAGER_EXPORT TargetInformation
         return workingDir == other.workingDir
                 && target == other.target
                 && executable == other.executable
-                && valid == valid
-                && buildDir == buildDir;
+                && valid == other.valid
+                && buildDir == other.buildDir;
     }
     bool operator!=(const TargetInformation &other) const
     {
@@ -354,6 +358,7 @@ public:
 
     QString makefile() const;
     QStringList symbianCapabilities() const;
+    QByteArray cxxDefines() const;
     bool isDeployable() const;
     QString resolvedMkspecPath() const;
 
@@ -388,6 +393,8 @@ private:
     void createUiCodeModelSupport();
     QStringList updateUiFiles();
 
+    QStringList fileListForVar(QtSupport::ProFileReader *readerExact, QtSupport::ProFileReader *readerCumulative,
+                               const QString &varName, const QString &projectDir) const;
     QString uiDirPath(QtSupport::ProFileReader *reader) const;
     QString mocDirPath(QtSupport::ProFileReader *reader) const;
     QStringList includePaths(QtSupport::ProFileReader *reader) const;
