@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -51,7 +51,7 @@
 
 #include <coreplugin/icore.h>
 #include <coreplugin/coreconstants.h>
-#include <coreplugin/filemanager.h>
+#include <coreplugin/documentmanager.h>
 #include <coreplugin/messagemanager.h>
 #include <coreplugin/mimedatabase.h>
 #include <coreplugin/actionmanager/actionmanager.h>
@@ -64,77 +64,77 @@
 
 #include <utils/qtcassert.h>
 
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtCore/QTemporaryFile>
-#include <QtCore/QTextCodec>
-#include <QtCore/QtPlugin>
-#include <QtCore/QProcessEnvironment>
-#include <QtCore/QUrl>
-#include <QtGui/QAction>
-#include <QtGui/QFileDialog>
-#include <QtGui/QMainWindow>
-#include <QtGui/QMenu>
-#include <QtGui/QMessageBox>
-#include <QtGui/QInputDialog>
-#include <QtXml/QXmlStreamReader>
+#include <QDebug>
+#include <QDir>
+#include <QFileInfo>
+#include <QTemporaryFile>
+#include <QTextCodec>
+#include <QtPlugin>
+#include <QProcessEnvironment>
+#include <QUrl>
+#include <QXmlStreamReader>
+#include <QAction>
+#include <QFileDialog>
+#include <QMainWindow>
+#include <QMenu>
+#include <QMessageBox>
+#include <QInputDialog>
 #include <limits.h>
 
 namespace Subversion {
 namespace Internal {
 
-static const char * const CMD_ID_SUBVERSION_MENU    = "Subversion.Menu";
-static const char * const CMD_ID_ADD                = "Subversion.Add";
-static const char * const CMD_ID_DELETE_FILE        = "Subversion.Delete";
-static const char * const CMD_ID_REVERT             = "Subversion.Revert";
-static const char * const CMD_ID_SEPARATOR0         = "Subversion.Separator0";
-static const char * const CMD_ID_DIFF_PROJECT       = "Subversion.DiffAll";
-static const char * const CMD_ID_DIFF_CURRENT       = "Subversion.DiffCurrent";
-static const char * const CMD_ID_SEPARATOR1         = "Subversion.Separator1";
-static const char * const CMD_ID_COMMIT_ALL         = "Subversion.CommitAll";
-static const char * const CMD_ID_REVERT_ALL         = "Subversion.RevertAll";
-static const char * const CMD_ID_COMMIT_CURRENT     = "Subversion.CommitCurrent";
-static const char * const CMD_ID_SEPARATOR2         = "Subversion.Separator2";
-static const char * const CMD_ID_FILELOG_CURRENT    = "Subversion.FilelogCurrent";
-static const char * const CMD_ID_ANNOTATE_CURRENT   = "Subversion.AnnotateCurrent";
-static const char * const CMD_ID_SEPARATOR3         = "Subversion.Separator3";
-static const char * const CMD_ID_SEPARATOR4         = "Subversion.Separator4";
-static const char * const CMD_ID_STATUS             = "Subversion.Status";
-static const char * const CMD_ID_PROJECTLOG         = "Subversion.ProjectLog";
-static const char * const CMD_ID_REPOSITORYLOG      = "Subversion.RepositoryLog";
-static const char * const CMD_ID_REPOSITORYUPDATE   = "Subversion.RepositoryUpdate";
-static const char * const CMD_ID_REPOSITORYDIFF     = "Subversion.RepositoryDiff";
-static const char * const CMD_ID_REPOSITORYSTATUS   = "Subversion.RepositoryStatus";
-static const char * const CMD_ID_UPDATE             = "Subversion.Update";
-static const char * const CMD_ID_COMMIT_PROJECT     = "Subversion.CommitProject";
-static const char * const CMD_ID_DESCRIBE           = "Subversion.Describe";
+static const char CMD_ID_SUBVERSION_MENU[]    = "Subversion.Menu";
+static const char CMD_ID_ADD[]                = "Subversion.Add";
+static const char CMD_ID_DELETE_FILE[]        = "Subversion.Delete";
+static const char CMD_ID_REVERT[]             = "Subversion.Revert";
+static const char CMD_ID_SEPARATOR0[]         = "Subversion.Separator0";
+static const char CMD_ID_DIFF_PROJECT[]       = "Subversion.DiffAll";
+static const char CMD_ID_DIFF_CURRENT[]       = "Subversion.DiffCurrent";
+static const char CMD_ID_SEPARATOR1[]         = "Subversion.Separator1";
+static const char CMD_ID_COMMIT_ALL[]         = "Subversion.CommitAll";
+static const char CMD_ID_REVERT_ALL[]         = "Subversion.RevertAll";
+static const char CMD_ID_COMMIT_CURRENT[]     = "Subversion.CommitCurrent";
+static const char CMD_ID_SEPARATOR2[]         = "Subversion.Separator2";
+static const char CMD_ID_FILELOG_CURRENT[]    = "Subversion.FilelogCurrent";
+static const char CMD_ID_ANNOTATE_CURRENT[]   = "Subversion.AnnotateCurrent";
+static const char CMD_ID_SEPARATOR3[]         = "Subversion.Separator3";
+static const char CMD_ID_SEPARATOR4[]         = "Subversion.Separator4";
+static const char CMD_ID_STATUS[]             = "Subversion.Status";
+static const char CMD_ID_PROJECTLOG[]         = "Subversion.ProjectLog";
+static const char CMD_ID_REPOSITORYLOG[]      = "Subversion.RepositoryLog";
+static const char CMD_ID_REPOSITORYUPDATE[]   = "Subversion.RepositoryUpdate";
+static const char CMD_ID_REPOSITORYDIFF[]     = "Subversion.RepositoryDiff";
+static const char CMD_ID_REPOSITORYSTATUS[]   = "Subversion.RepositoryStatus";
+static const char CMD_ID_UPDATE[]             = "Subversion.Update";
+static const char CMD_ID_COMMIT_PROJECT[]     = "Subversion.CommitProject";
+static const char CMD_ID_DESCRIBE[]           = "Subversion.Describe";
 
-static const char *nonInteractiveOptionC = "--non-interactive";
+static const char nonInteractiveOptionC[] = "--non-interactive";
 
 
 
-static const VCSBase::VCSBaseEditorParameters editorParameters[] = {
+static const VcsBase::VcsBaseEditorParameters editorParameters[] = {
 {
-    VCSBase::RegularCommandOutput,
+    VcsBase::RegularCommandOutput,
     "Subversion Command Log Editor", // id
     QT_TRANSLATE_NOOP("VCS", "Subversion Command Log Editor"), // display name
     "Subversion Command Log Editor", // context
     "application/vnd.nokia.text.scs_svn_commandlog",
     "scslog"},
-{   VCSBase::LogOutput,
+{   VcsBase::LogOutput,
     "Subversion File Log Editor",   // id
     QT_TRANSLATE_NOOP("VCS", "Subversion File Log Editor"),   // display_name
     "Subversion File Log Editor",   // context
     "application/vnd.nokia.text.scs_svn_filelog",
     "scsfilelog"},
-{    VCSBase::AnnotateOutput,
+{    VcsBase::AnnotateOutput,
     "Subversion Annotation Editor",  // id
     QT_TRANSLATE_NOOP("VCS", "Subversion Annotation Editor"),   // display_name
     "Subversion Annotation Editor",  // context
     "application/vnd.nokia.text.scs_svn_annotation",
     "scsannotate"},
-{   VCSBase::DiffOutput,
+{   VcsBase::DiffOutput,
     "Subversion Diff Editor",  // id
     QT_TRANSLATE_NOOP("VCS", "Subversion Diff Editor"),   // display_name
     "Subversion Diff Editor",  // context
@@ -142,10 +142,10 @@ static const VCSBase::VCSBaseEditorParameters editorParameters[] = {
 };
 
 // Utility to find a parameter set by type
-static inline const VCSBase::VCSBaseEditorParameters *findType(int ie)
+static inline const VcsBase::VcsBaseEditorParameters *findType(int ie)
 {
-    const VCSBase::EditorContentType et = static_cast<VCSBase::EditorContentType>(ie);
-    return  VCSBase::VCSBaseEditorWidget::findType(editorParameters, sizeof(editorParameters)/sizeof(VCSBase::VCSBaseEditorParameters), et);
+    const VcsBase::EditorContentType et = static_cast<VcsBase::EditorContentType>(ie);
+    return  VcsBase::VcsBaseEditorWidget::findType(editorParameters, sizeof(editorParameters)/sizeof(VcsBase::VcsBaseEditorParameters), et);
 }
 
 static inline QString debugCodec(const QTextCodec *c)
@@ -191,7 +191,7 @@ static inline QStringList svnDirectories()
 SubversionPlugin *SubversionPlugin::m_subversionPluginInstance = 0;
 
 SubversionPlugin::SubversionPlugin() :
-    VCSBase::VCSBasePlugin(QLatin1String(Subversion::Constants::SUBVERSIONCOMMITEDITOR_ID)),
+    VcsBase::VcsBasePlugin(QLatin1String(Subversion::Constants::SUBVERSIONCOMMITEDITOR_ID)),
     m_svnDirectories(svnDirectories()),
     m_commandLocator(0),
     m_addAction(0),
@@ -241,7 +241,7 @@ bool SubversionPlugin::isCommitEditorOpen() const
     return !m_commitMessageFileName.isEmpty();
 }
 
-static const VCSBase::VCSBaseSubmitEditorParameters submitParameters = {
+static const VcsBase::VcsBaseSubmitEditorParameters submitParameters = {
     Subversion::Constants::SUBVERSION_SUBMIT_MIMETYPE,
     Subversion::Constants::SUBVERSIONCOMMITEDITOR_ID,
     Subversion::Constants::SUBVERSIONCOMMITEDITOR_DISPLAY_NAME,
@@ -260,8 +260,8 @@ static inline Core::Command *createSeparator(QObject *parent,
 
 bool SubversionPlugin::initialize(const QStringList & /*arguments */, QString *errorMessage)
 {
-    typedef VCSBase::VCSSubmitEditorFactory<SubversionSubmitEditor> SubversionSubmitEditorFactory;
-    typedef VCSBase::VCSEditorFactory<SubversionEditor> SubversionEditorFactory;
+    typedef VcsBase::VcsSubmitEditorFactory<SubversionSubmitEditor> SubversionSubmitEditorFactory;
+    typedef VcsBase::VcsEditorFactory<SubversionEditor> SubversionEditorFactory;
     using namespace Constants;
 
     using namespace Core::Constants;
@@ -270,12 +270,11 @@ bool SubversionPlugin::initialize(const QStringList & /*arguments */, QString *e
     initializeVcs(new SubversionControl(this));
 
     m_subversionPluginInstance = this;
-    Core::ICore *core = Core::ICore::instance();
 
-    if (!core->mimeDatabase()->addMimeTypes(QLatin1String(":/trolltech.subversion/Subversion.mimetypes.xml"), errorMessage))
+    if (!Core::ICore::mimeDatabase()->addMimeTypes(QLatin1String(":/trolltech.subversion/Subversion.mimetypes.xml"), errorMessage))
         return false;
 
-    if (QSettings *settings = core->settings())
+    if (QSettings *settings = Core::ICore::settings())
         m_settings.fromSettings(settings);
 
     addAutoReleasedObject(new SettingsPage);
@@ -283,7 +282,7 @@ bool SubversionPlugin::initialize(const QStringList & /*arguments */, QString *e
     addAutoReleasedObject(new SubversionSubmitEditorFactory(&submitParameters));
 
     static const char *describeSlot = SLOT(describe(QString,QString));
-    const int editorCount = sizeof(editorParameters)/sizeof(VCSBase::VCSBaseEditorParameters);
+    const int editorCount = sizeof(editorParameters)/sizeof(VcsBase::VcsBaseEditorParameters);
     for (int i = 0; i < editorCount; i++)
         addAutoReleasedObject(new SubversionEditorFactory(editorParameters + i, this, describeSlot));
 
@@ -295,7 +294,7 @@ bool SubversionPlugin::initialize(const QStringList & /*arguments */, QString *e
     addAutoReleasedObject(m_commandLocator);
 
     //register actions
-    Core::ActionManager *ami = core->actionManager();
+    Core::ActionManager *ami = Core::ICore::actionManager();
     Core::ActionContainer *toolsContainer = ami->actionContainer(M_TOOLS);
 
     Core::ActionContainer *subversionMenu =
@@ -456,12 +455,12 @@ bool SubversionPlugin::initialize(const QStringList & /*arguments */, QString *e
     // Actions of the submit editor
     Core::Context svncommitcontext(Constants::SUBVERSIONCOMMITEDITOR);
 
-    m_submitCurrentLogAction = new QAction(VCSBase::VCSBaseSubmitEditor::submitIcon(), tr("Commit"), this);
+    m_submitCurrentLogAction = new QAction(VcsBase::VcsBaseSubmitEditor::submitIcon(), tr("Commit"), this);
     command = ami->registerAction(m_submitCurrentLogAction, Constants::SUBMIT_CURRENT, svncommitcontext);
     command->setAttribute(Core::Command::CA_UpdateText);
     connect(m_submitCurrentLogAction, SIGNAL(triggered()), this, SLOT(submitCurrentLog()));
 
-    m_submitDiffAction = new QAction(VCSBase::VCSBaseSubmitEditor::diffIcon(), tr("Diff &Selected Files"), this);
+    m_submitDiffAction = new QAction(VcsBase::VcsBaseSubmitEditor::diffIcon(), tr("Diff &Selected Files"), this);
     command = ami->registerAction(m_submitDiffAction , Constants::DIFF_SELECTED, svncommitcontext);
 
     m_submitUndoAction = new QAction(tr("&Undo"), this);
@@ -473,19 +472,19 @@ bool SubversionPlugin::initialize(const QStringList & /*arguments */, QString *e
     return true;
 }
 
-bool SubversionPlugin::submitEditorAboutToClose(VCSBase::VCSBaseSubmitEditor *submitEditor)
+bool SubversionPlugin::submitEditorAboutToClose(VcsBase::VcsBaseSubmitEditor *submitEditor)
 {
     if (!isCommitEditorOpen())
         return true;
 
-    Core::IFile *fileIFace = submitEditor->file();
+    Core::IDocument *editorDocument = submitEditor->document();
     const SubversionSubmitEditor *editor = qobject_cast<SubversionSubmitEditor *>(submitEditor);
-    if (!fileIFace || !editor)
+    if (!editorDocument || !editor)
         return true;
 
     // Submit editor closing. Make it write out the commit message
     // and retrieve files
-    const QFileInfo editorFile(fileIFace->fileName());
+    const QFileInfo editorFile(editorDocument->fileName());
     const QFileInfo changeFile(m_commitMessageFileName);
     if (editorFile.absoluteFilePath() != changeFile.absoluteFilePath())
         return true; // Oops?!
@@ -493,16 +492,16 @@ bool SubversionPlugin::submitEditorAboutToClose(VCSBase::VCSBaseSubmitEditor *su
     // Prompt user. Force a prompt unless submit was actually invoked (that
     // is, the editor was closed or shutdown).
     SubversionSettings newSettings = m_settings;
-    const VCSBase::VCSBaseSubmitEditor::PromptSubmitResult answer =
+    const VcsBase::VcsBaseSubmitEditor::PromptSubmitResult answer =
             editor->promptSubmit(tr("Closing Subversion Editor"),
                                  tr("Do you want to commit the change?"),
                                  tr("The commit message check failed. Do you want to commit the change?"),
                                  &newSettings.promptToSubmit, !m_submitActionTriggered);
     m_submitActionTriggered = false;
     switch (answer) {
-    case VCSBase::VCSBaseSubmitEditor::SubmitCanceled:
+    case VcsBase::VcsBaseSubmitEditor::SubmitCanceled:
         return false; // Keep editing and change file
-    case VCSBase::VCSBaseSubmitEditor::SubmitDiscarded:
+    case VcsBase::VcsBaseSubmitEditor::SubmitDiscarded:
         cleanCommitMessageFile();
         return true; // Cancel all
     default:
@@ -513,7 +512,7 @@ bool SubversionPlugin::submitEditorAboutToClose(VCSBase::VCSBaseSubmitEditor *su
     bool closeEditor = true;
     if (!fileList.empty()) {
         // get message & commit
-        closeEditor = Core::ICore::instance()->fileManager()->saveFile(fileIFace);
+        closeEditor = Core::DocumentManager::saveDocument(editorDocument);
         if (closeEditor)
             closeEditor = commit(m_commitMessageFileName, fileList);
     }
@@ -538,7 +537,7 @@ struct SubversionDiffParameters
 };
 
 // Parameter widget controlling whitespace diff mode, associated with a parameter
-class SubversionDiffParameterWidget : public VCSBase::VCSBaseEditorParameterWidget
+class SubversionDiffParameterWidget : public VcsBase::VcsBaseEditorParameterWidget
 {
     Q_OBJECT
 public:
@@ -555,7 +554,7 @@ private:
 };
 
 SubversionDiffParameterWidget::SubversionDiffParameterWidget(const SubversionDiffParameters &p, QWidget *parent) :
-    VCSBase::VCSBaseEditorParameterWidget(parent), m_parameters(p)
+    VcsBase::VcsBaseEditorParameterWidget(parent), m_parameters(p)
 {
     setBaseArguments(p.arguments);
     addToggleButton(QLatin1String("w"), tr("Ignore whitespace"));
@@ -574,7 +573,7 @@ void SubversionDiffParameterWidget::triggerReRun()
 
 static inline void setDiffBaseDirectory(Core::IEditor *editor, const QString &db)
 {
-    if (VCSBase::VCSBaseEditorWidget *ve = qobject_cast<VCSBase::VCSBaseEditorWidget*>(editor->widget()))
+    if (VcsBase::VcsBaseEditorWidget *ve = qobject_cast<VcsBase::VcsBaseEditorWidget*>(editor->widget()))
         ve->setDiffBaseDirectory(db);
 }
 
@@ -591,8 +590,8 @@ void SubversionPlugin::svnDiff(const Subversion::Internal::SubversionDiffParamet
 {
     if (Subversion::Constants::debug)
         qDebug() << Q_FUNC_INFO << p.files << p.diffName;
-    const QString source = VCSBase::VCSBaseEditorWidget::getSource(p.workingDir, p.files);
-    QTextCodec *codec = source.isEmpty() ? static_cast<QTextCodec *>(0) : VCSBase::VCSBaseEditorWidget::getCodec(source);
+    const QString source = VcsBase::VcsBaseEditorWidget::getSource(p.workingDir, p.files);
+    QTextCodec *codec = source.isEmpty() ? static_cast<QTextCodec *>(0) : VcsBase::VcsBaseEditorWidget::getCodec(source);
 
     const QString diffName = p.files.count() == 1 && p.diffName.isEmpty() ?
                              QFileInfo(p.files.front()).fileName() : p.diffName;
@@ -608,18 +607,18 @@ void SubversionPlugin::svnDiff(const Subversion::Internal::SubversionDiffParamet
 
     // diff of a single file? re-use an existing view if possible to support
     // the common usage pattern of continuously changing and diffing a file
-    const QString tag = VCSBase::VCSBaseEditorWidget::editorTag(VCSBase::DiffOutput, p.workingDir, p.files);
+    const QString tag = VcsBase::VcsBaseEditorWidget::editorTag(VcsBase::DiffOutput, p.workingDir, p.files);
     // Show in the same editor if diff has been executed before
-    if (Core::IEditor *existingEditor = VCSBase::VCSBaseEditorWidget::locateEditorByTag(tag)) {
+    if (Core::IEditor *existingEditor = VcsBase::VcsBaseEditorWidget::locateEditorByTag(tag)) {
         existingEditor->createNew(response.stdOut);
         Core::EditorManager::instance()->activateEditor(existingEditor, Core::EditorManager::ModeSwitch);
         setDiffBaseDirectory(existingEditor, p.workingDir);
         return;
     }
     const QString title = QString::fromLatin1("svn diff %1").arg(diffName);
-    Core::IEditor *editor = showOutputInEditor(title, response.stdOut, VCSBase::DiffOutput, source, codec);
+    Core::IEditor *editor = showOutputInEditor(title, response.stdOut, VcsBase::DiffOutput, source, codec);
     setDiffBaseDirectory(editor, p.workingDir);
-    VCSBase::VCSBaseEditorWidget::tagEditor(editor, tag);
+    VcsBase::VcsBaseEditorWidget::tagEditor(editor, tag);
     SubversionEditor *diffEditorWidget = qobject_cast<SubversionEditor *>(editor->widget());
     QTC_ASSERT(diffEditorWidget, return ; )
 
@@ -629,7 +628,7 @@ void SubversionPlugin::svnDiff(const Subversion::Internal::SubversionDiffParamet
     SubversionDiffParameterWidget *pw = new SubversionDiffParameterWidget(p);
     connect(pw, SIGNAL(reRunDiff(Subversion::Internal::SubversionDiffParameters)),
             this, SLOT(svnDiff(Subversion::Internal::SubversionDiffParameters)));
-    connect(diffEditorWidget, SIGNAL(diffChunkReverted(VCSBase::DiffChunk)),
+    connect(diffEditorWidget, SIGNAL(diffChunkReverted(VcsBase::DiffChunk)),
             pw, SLOT(triggerReRun()));
     diffEditorWidget->setConfigurationWidget(pw);
 }
@@ -647,7 +646,7 @@ SubversionSubmitEditor *SubversionPlugin::openSubversionSubmitEditor(const QStri
     return submitEditor;
 }
 
-void SubversionPlugin::updateActions(VCSBase::VCSBasePlugin::ActionState as)
+void SubversionPlugin::updateActions(VcsBase::VcsBasePlugin::ActionState as)
 {
     if (!enableMenuAction(as, m_menuAction)) {
         m_commandLocator->setEnabled(false);
@@ -685,14 +684,14 @@ void SubversionPlugin::updateActions(VCSBase::VCSBasePlugin::ActionState as)
 
 void SubversionPlugin::addCurrentFile()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasFile(), return)
     vcsAdd(state.currentFileTopLevel(), state.relativeCurrentFile());
 }
 
 void SubversionPlugin::revertAll()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasTopLevel(), return)
     const QString title = tr("Revert repository");
     if (QMessageBox::warning(0, title, tr("Revert all pending changes to the repository?"),
@@ -713,7 +712,7 @@ void SubversionPlugin::revertAll()
 
 void SubversionPlugin::revertCurrentFile()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasFile(), return)
 
     QStringList args(QLatin1String("diff"));
@@ -748,35 +747,35 @@ void SubversionPlugin::revertCurrentFile()
 
 void SubversionPlugin::diffProject()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasProject(), return)
     svnDiff(state.currentProjectTopLevel(), state.relativeCurrentProject(), state.currentProjectName());
 }
 
 void SubversionPlugin::diffCurrentFile()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasFile(), return)
     svnDiff(state.currentFileTopLevel(), QStringList(state.relativeCurrentFile()));
 }
 
 void SubversionPlugin::startCommitCurrentFile()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasFile(), return)
     startCommit(state.currentFileTopLevel(), QStringList(state.relativeCurrentFile()));
 }
 
 void SubversionPlugin::startCommitAll()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasTopLevel(), return);
     startCommit(state.topLevel());
 }
 
 void SubversionPlugin::startCommitProject()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasProject(), return);
     startCommit(state.currentProjectPath());
 }
@@ -786,10 +785,10 @@ void SubversionPlugin::startCommitProject()
  * commit will start. */
 void SubversionPlugin::startCommit(const QString &workingDir, const QStringList &files)
 {
-    if (VCSBase::VCSBaseSubmitEditor::raiseSubmitEditor())
+    if (VcsBase::VcsBaseSubmitEditor::raiseSubmitEditor())
         return;
     if (isCommitEditorOpen()) {
-        VCSBase::VCSBaseOutputWindow::instance()->appendWarning(tr("Another commit is currently being executed."));
+        VcsBase::VcsBaseOutputWindow::instance()->appendWarning(tr("Another commit is currently being executed."));
         return;
     }
 
@@ -804,7 +803,7 @@ void SubversionPlugin::startCommit(const QString &workingDir, const QStringList
     // Get list of added/modified/deleted files
     const StatusList statusOutput = parseStatusOutput(response.stdOut);
     if (statusOutput.empty()) {
-        VCSBase::VCSBaseOutputWindow::instance()->appendWarning(tr("There are no modified files."));
+        VcsBase::VcsBaseOutputWindow::instance()->appendWarning(tr("There are no modified files."));
         return;
     }
     m_commitRepository = workingDir;
@@ -816,7 +815,7 @@ void SubversionPlugin::startCommit(const QString &workingDir, const QStringList
     // Create a submit
     saver.write(submitTemplate.toUtf8());
     if (!saver.finalize()) {
-        VCSBase::VCSBaseOutputWindow::instance()->appendError(saver.errorString());
+        VcsBase::VcsBaseOutputWindow::instance()->appendError(saver.errorString());
         return;
     }
     m_commitMessageFileName = saver.fileName();
@@ -844,54 +843,54 @@ bool SubversionPlugin::commit(const QString &messageFile,
 
 void SubversionPlugin::filelogCurrentFile()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasFile(), return)
    filelog(state.currentFileTopLevel(), QStringList(state.relativeCurrentFile()), true);
 }
 
 void SubversionPlugin::logProject()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasProject(), return)
     filelog(state.currentProjectTopLevel(), state.relativeCurrentProject());
 }
 
 void SubversionPlugin::logRepository()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasTopLevel(), return)
     filelog(state.topLevel());
 }
 
 void SubversionPlugin::diffRepository()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasTopLevel(), return)
     svnDiff(state.topLevel(), QStringList());
 }
 
 void SubversionPlugin::statusRepository()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasTopLevel(), return)
     svnStatus(state.topLevel());
 }
 
 void SubversionPlugin::updateRepository()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasTopLevel(), return)
     svnUpdate(state.topLevel());
 }
 
 void SubversionPlugin::svnStatus(const QString &workingDir, const QStringList &relativePaths)
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasTopLevel(), return)
     QStringList args(QLatin1String("status"));
     if (!relativePaths.isEmpty())
         args.append(relativePaths);
-    VCSBase::VCSBaseOutputWindow *outwin = VCSBase::VCSBaseOutputWindow::instance();
+    VcsBase::VcsBaseOutputWindow *outwin = VcsBase::VcsBaseOutputWindow::instance();
     outwin->setRepository(workingDir);
     runSvn(workingDir, args, m_settings.timeOutMS(),
            ShowStdOutInLogWindow|ShowSuccessMessage);
@@ -920,24 +919,24 @@ void SubversionPlugin::filelog(const QString &workingDir,
     // Re-use an existing view if possible to support
     // the common usage pattern of continuously changing and diffing a file
 
-    const QString id = VCSBase::VCSBaseEditorWidget::getTitleId(workingDir, files);
-    const QString tag = VCSBase::VCSBaseEditorWidget::editorTag(VCSBase::LogOutput, workingDir, files);
-    if (Core::IEditor *editor = VCSBase::VCSBaseEditorWidget::locateEditorByTag(tag)) {
+    const QString id = VcsBase::VcsBaseEditorWidget::getTitleId(workingDir, files);
+    const QString tag = VcsBase::VcsBaseEditorWidget::editorTag(VcsBase::LogOutput, workingDir, files);
+    if (Core::IEditor *editor = VcsBase::VcsBaseEditorWidget::locateEditorByTag(tag)) {
         editor->createNew(response.stdOut);
         Core::EditorManager::instance()->activateEditor(editor, Core::EditorManager::ModeSwitch);
     } else {
         const QString title = QString::fromLatin1("svn log %1").arg(id);
-        const QString source = VCSBase::VCSBaseEditorWidget::getSource(workingDir, files);
-        Core::IEditor *newEditor = showOutputInEditor(title, response.stdOut, VCSBase::LogOutput, source, /*codec*/0);
-        VCSBase::VCSBaseEditorWidget::tagEditor(newEditor, tag);
+        const QString source = VcsBase::VcsBaseEditorWidget::getSource(workingDir, files);
+        Core::IEditor *newEditor = showOutputInEditor(title, response.stdOut, VcsBase::LogOutput, source, /*codec*/0);
+        VcsBase::VcsBaseEditorWidget::tagEditor(newEditor, tag);
         if (enableAnnotationContextMenu)
-            VCSBase::VCSBaseEditorWidget::getVcsBaseEditor(newEditor)->setFileLogAnnotateEnabled(true);
+            VcsBase::VcsBaseEditorWidget::getVcsBaseEditor(newEditor)->setFileLogAnnotateEnabled(true);
     }
 }
 
 void SubversionPlugin::updateProject()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasProject(), return);
     svnUpdate(state.currentProjectTopLevel(), state.relativeCurrentProject());
 }
@@ -957,7 +956,7 @@ void SubversionPlugin::svnUpdate(const QString &workingDir, const QStringList &r
 
 void SubversionPlugin::annotateCurrentFile()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasFile(), return);
     vcsAnnotate(state.currentFileTopLevel(), state.relativeCurrentFile());
 }
@@ -974,8 +973,8 @@ void SubversionPlugin::vcsAnnotate(const QString &workingDir, const QString &fil
                                 const QString &revision /* = QString() */,
                                 int lineNumber /* = -1 */)
 {
-    const QString source = VCSBase::VCSBaseEditorWidget::getSource(workingDir, file);
-    QTextCodec *codec = VCSBase::VCSBaseEditorWidget::getCodec(source);
+    const QString source = VcsBase::VcsBaseEditorWidget::getSource(workingDir, file);
+    QTextCodec *codec = VcsBase::VcsBaseEditorWidget::getCodec(source);
 
     QStringList args(QLatin1String("annotate"));
     if (m_settings.spaceIgnorantAnnotation)
@@ -994,26 +993,26 @@ void SubversionPlugin::vcsAnnotate(const QString &workingDir, const QString &fil
     // Re-use an existing view if possible to support
     // the common usage pattern of continuously changing and diffing a file
     if (lineNumber <= 0)
-        lineNumber = VCSBase::VCSBaseEditorWidget::lineNumberOfCurrentEditor(source);
+        lineNumber = VcsBase::VcsBaseEditorWidget::lineNumberOfCurrentEditor(source);
     // Determine id
     const QStringList files = QStringList(file);
-    const QString id = VCSBase::VCSBaseEditorWidget::getTitleId(workingDir, files, revision);
-    const QString tag = VCSBase::VCSBaseEditorWidget::editorTag(VCSBase::AnnotateOutput, workingDir, files);
-    if (Core::IEditor *editor = VCSBase::VCSBaseEditorWidget::locateEditorByTag(tag)) {
+    const QString id = VcsBase::VcsBaseEditorWidget::getTitleId(workingDir, files, revision);
+    const QString tag = VcsBase::VcsBaseEditorWidget::editorTag(VcsBase::AnnotateOutput, workingDir, files);
+    if (Core::IEditor *editor = VcsBase::VcsBaseEditorWidget::locateEditorByTag(tag)) {
         editor->createNew(response.stdOut);
-        VCSBase::VCSBaseEditorWidget::gotoLineOfEditor(editor, lineNumber);
+        VcsBase::VcsBaseEditorWidget::gotoLineOfEditor(editor, lineNumber);
         Core::EditorManager::instance()->activateEditor(editor, Core::EditorManager::ModeSwitch);
     } else {
         const QString title = QString::fromLatin1("svn annotate %1").arg(id);
-        Core::IEditor *newEditor = showOutputInEditor(title, response.stdOut, VCSBase::AnnotateOutput, source, codec);
-        VCSBase::VCSBaseEditorWidget::tagEditor(newEditor, tag);
-        VCSBase::VCSBaseEditorWidget::gotoLineOfEditor(newEditor, lineNumber);
+        Core::IEditor *newEditor = showOutputInEditor(title, response.stdOut, VcsBase::AnnotateOutput, source, codec);
+        VcsBase::VcsBaseEditorWidget::tagEditor(newEditor, tag);
+        VcsBase::VcsBaseEditorWidget::gotoLineOfEditor(newEditor, lineNumber);
     }
 }
 
 void SubversionPlugin::projectStatus()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasProject(), return);
     svnStatus(state.currentFileTopLevel(), state.relativeCurrentProject());
 }
@@ -1053,7 +1052,7 @@ void SubversionPlugin::describe(const QString &source, const QString &changeNr)
     QTextStream(&diffArg) << (number - 1) << ':' << number;
     args.push_back(diffArg);
 
-    QTextCodec *codec = VCSBase::VCSBaseEditorWidget::getCodec(source);
+    QTextCodec *codec = VcsBase::VcsBaseEditorWidget::getCodec(source);
     const SubversionResponse response =
             runSvn(topLevel, args, m_settings.timeOutMS(),
                    SshPasswordPrompt, codec);
@@ -1064,23 +1063,23 @@ void SubversionPlugin::describe(const QString &source, const QString &changeNr)
     // Re-use an existing view if possible to support
     // the common usage pattern of continuously changing and diffing a file
     const QString id = diffArg + source;
-    const QString tag = VCSBase::VCSBaseEditorWidget::editorTag(VCSBase::DiffOutput, source, QStringList(), changeNr);
-    if (Core::IEditor *editor = VCSBase::VCSBaseEditorWidget::locateEditorByTag(tag)) {
+    const QString tag = VcsBase::VcsBaseEditorWidget::editorTag(VcsBase::DiffOutput, source, QStringList(), changeNr);
+    if (Core::IEditor *editor = VcsBase::VcsBaseEditorWidget::locateEditorByTag(tag)) {
         editor->createNew(description);
         Core::EditorManager::instance()->activateEditor(editor, Core::EditorManager::ModeSwitch);
     } else {
         const QString title = QString::fromLatin1("svn describe %1#%2").arg(fi.fileName(), changeNr);
-        Core::IEditor *newEditor = showOutputInEditor(title, description, VCSBase::DiffOutput, source, codec);
-        VCSBase::VCSBaseEditorWidget::tagEditor(newEditor, tag);
+        Core::IEditor *newEditor = showOutputInEditor(title, description, VcsBase::DiffOutput, source, codec);
+        VcsBase::VcsBaseEditorWidget::tagEditor(newEditor, tag);
     }
 }
 
 void SubversionPlugin::slotDescribe()
 {
-    const VCSBase::VCSBasePluginState state = currentState();
+    const VcsBase::VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasTopLevel(), return);
 
-    QInputDialog inputDialog(Core::ICore::instance()->mainWindow());
+    QInputDialog inputDialog(Core::ICore::mainWindow());
     inputDialog.setWindowFlags(inputDialog.windowFlags() & ~Qt::WindowContextHelpButtonHint);
     inputDialog.setInputMode(QInputDialog::IntInput);
     inputDialog.setIntRange(2, INT_MAX);
@@ -1151,7 +1150,7 @@ SubversionResponse SubversionPlugin::runSvn(const QString &workingDir,
 
     const QStringList completeArguments = SubversionPlugin::addAuthenticationOptions(arguments, userName, password);
     const Utils::SynchronousProcessResponse sp_resp =
-            VCSBase::VCSBasePlugin::runVCS(workingDir, executable,
+            VcsBase::VcsBasePlugin::runVcs(workingDir, executable,
                                            completeArguments, timeOut, flags, outputCodec);
 
     response.error = sp_resp.result != Utils::SynchronousProcessResponse::Finished;
@@ -1162,15 +1161,16 @@ SubversionResponse SubversionPlugin::runSvn(const QString &workingDir,
     return response;
 }
 
-Core::IEditor * SubversionPlugin::showOutputInEditor(const QString& title, const QString &output,
+Core::IEditor *SubversionPlugin::showOutputInEditor(const QString &title, const QString &output,
                                                      int editorType, const QString &source,
                                                      QTextCodec *codec)
 {
-    const VCSBase::VCSBaseEditorParameters *params = findType(editorType);
+    const VcsBase::VcsBaseEditorParameters *params = findType(editorType);
     QTC_ASSERT(params, return 0);
-    const QString id = params->id;
+    const Core::Id id = params->id;
     if (Subversion::Constants::debug)
-        qDebug() << "SubversionPlugin::showOutputInEditor" << title << id <<  "Size= " << output.size() <<  " Type=" << editorType << debugCodec(codec);
+        qDebug() << "SubversionPlugin::showOutputInEditor" << title << id.name()
+                 <<  "Size= " << output.size() <<  " Type=" << editorType << debugCodec(codec);
     QString s = title;
     Core::IEditor *editor = Core::EditorManager::instance()->openEditorWithContents(id, &s, output);
     connect(editor, SIGNAL(annotateRevisionRequested(QString,QString,int)),
@@ -1199,7 +1199,7 @@ void SubversionPlugin::setSettings(const SubversionSettings &s)
 {
     if (s != m_settings) {
         m_settings = s;
-        if (QSettings *settings = Core::ICore::instance()->settings())
+        if (QSettings *settings = Core::ICore::settings())
             m_settings.toSettings(settings);
         subVersionControl()->emitConfigurationChanged();
     }
@@ -1304,16 +1304,16 @@ bool SubversionPlugin::vcsCheckout(const QString &directory, const QByteArray &u
         // authentication will always fail (if the username and password data are not stored locally),
         // if for example we are logging into a new host for the first time using svn. There seems to
         // be a bug in subversion, so this might get fixed in the future.
-        tempUrl.setUserInfo("");
-        args << tempUrl.toEncoded() << directory;
+        tempUrl.setUserInfo(QString());
+        args << QLatin1String(tempUrl.toEncoded()) << directory;
         const SubversionResponse response = runSvn(directory, username, password, args,
                                                    m_settings.longTimeOutMS(),
-                                                   VCSBase::VCSBasePlugin::SshPasswordPrompt);
+                                                   VcsBase::VcsBasePlugin::SshPasswordPrompt);
         return !response.error;
     } else {
-        args << url << directory;
+        args << QLatin1String(url) << directory;
         const SubversionResponse response = runSvn(directory, args, m_settings.longTimeOutMS(),
-                                                   VCSBase::VCSBasePlugin::SshPasswordPrompt);
+                                                   VcsBase::VcsBasePlugin::SshPasswordPrompt);
         return !response.error;
     }
 }
