@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -33,10 +33,10 @@
 #ifndef CODECSELECTOR_H
 #define CODECSELECTOR_H
 
-#include <QtGui/QDialog>
-#include <QtGui/QLabel>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QListWidget>
+#include <QDialog>
+#include <QLabel>
+#include <QDialogButtonBox>
+#include <QListWidget>
 
 namespace TextEditor {
 
