@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -36,29 +36,23 @@
 #include <coreplugin/icore.h>
 #include <coreplugin/editormanager/editormanager.h>
 
-#include <QtCore/QtDebug>
-#include <QtCore/QSettings>
-#include <QtCore/QDirIterator>
-#include <QtGui/QPushButton>
-#include <QtGui/QFileDialog>
-#include <QtGui/QVBoxLayout>
+#include <QSettings>
 
 using namespace Find;
 using namespace TextEditor;
 using namespace TextEditor::Internal;
 
 FindInCurrentFile::FindInCurrentFile()
-  : m_configWidget(0),
-    m_currentFile(0)
+  : m_currentDocument(0)
 {
-    connect(Core::ICore::instance()->editorManager(), SIGNAL(currentEditorChanged(Core::IEditor*)),
+    connect(Core::ICore::editorManager(), SIGNAL(currentEditorChanged(Core::IEditor*)),
             this, SLOT(handleFileChange(Core::IEditor*)));
-    handleFileChange(Core::ICore::instance()->editorManager()->currentEditor());
+    handleFileChange(Core::ICore::editorManager()->currentEditor());
 }
 
 QString FindInCurrentFile::id() const
 {
-    return "Current File";
+    return QLatin1String("Current File");
 }
 
 QString FindInCurrentFile::displayName() const
@@ -66,10 +60,11 @@ QString FindInCurrentFile::displayName() const
     return tr("Current File");
 }
 
-Utils::FileIterator *FindInCurrentFile::files() const
+Utils::FileIterator *FindInCurrentFile::files(const QStringList &nameFilters,
+                                              const QVariant &additionalParameters) const
 {
-    Q_ASSERT(isEnabled());
-    QString fileName = m_currentFile->fileName();
+    Q_UNUSED(nameFilters)
+    QString fileName = additionalParameters.toString();
     QMap<QString, QTextCodec *> openEditorEncodings = ITextEditor::openedTextEditorsEncodings();
     QTextCodec *codec = openEditorEncodings.value(fileName);
     if (!codec)
@@ -77,65 +72,54 @@ Utils::FileIterator *FindInCurrentFile::files() const
     return new Utils::FileIterator(QStringList() << fileName, QList<QTextCodec *>() << codec);
 }
 
+QVariant FindInCurrentFile::additionalParameters() const
+{
+    return qVariantFromValue(m_currentDocument->fileName());
+}
+
 QString FindInCurrentFile::label() const
 {
-    return tr("File '%1':").arg(QFileInfo(m_currentFile->fileName()).fileName());
+    return tr("File '%1':").arg(QFileInfo(m_currentDocument->fileName()).fileName());
 }
 
 QString FindInCurrentFile::toolTip() const
 {
     // %2 is filled by BaseFileFind::runNewSearch
-    return tr("File path: %1\n%2").arg(QDir::toNativeSeparators(m_currentFile->fileName()));
+    return tr("File path: %1\n%2").arg(QDir::toNativeSeparators(m_currentDocument->fileName()));
 }
 
 bool FindInCurrentFile::isEnabled() const
 {
-    return m_currentFile && !m_currentFile->fileName().isEmpty();
+    return m_currentDocument && !m_currentDocument->fileName().isEmpty();
 }
 
 void FindInCurrentFile::handleFileChange(Core::IEditor *editor)
 {
     if (!editor) {
-        if (m_currentFile) {
-            m_currentFile = 0;
-            emit changed();
+        if (m_currentDocument) {
+            m_currentDocument = 0;
+            emit enabledChanged(isEnabled());
         }
     } else {
-        Core::IFile *file = editor->file();
-        if (file != m_currentFile) {
-            m_currentFile = file;
-            emit changed();
+        Core::IDocument *document = editor->document();
+        if (document != m_currentDocument) {
+            m_currentDocument = document;
+            emit enabledChanged(isEnabled());
         }
     }
 }
 
 
-QWidget *FindInCurrentFile::createConfigWidget()
-{
-    if (!m_configWidget) {
-        m_configWidget = new QWidget;
-        QGridLayout * const gridLayout = new QGridLayout(m_configWidget);
-        gridLayout->setMargin(0);
-        m_configWidget->setLayout(gridLayout);
-        // just for the layout HACK
-        QLabel * const filePatternLabel = new QLabel;
-        filePatternLabel->setMinimumWidth(80);
-        filePatternLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
-        gridLayout->addWidget(filePatternLabel, 0, 0);
-    }
-    return m_configWidget;
-}
-
 void FindInCurrentFile::writeSettings(QSettings *settings)
 {
-    settings->beginGroup("FindInCurrentFile");
+    settings->beginGroup(QLatin1String("FindInCurrentFile"));
     writeCommonSettings(settings);
     settings->endGroup();
 }
 
 void FindInCurrentFile::readSettings(QSettings *settings)
 {
-    settings->beginGroup("FindInCurrentFile");
-    readCommonSettings(settings, "*.cpp,*.h");
+    settings->beginGroup(QLatin1String("FindInCurrentFile"));
+    readCommonSettings(settings, QLatin1String("*"));
     settings->endGroup();
 }
