@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Author: Andreas Hartmetz, KDAB (andreas.hartmetz@kdab.com)
 **
@@ -50,20 +50,20 @@
 #include <texteditor/basetexteditor.h>
 #include <utils/qtcassert.h>
 
-#include <QtCore/QDir>
-#include <QtCore/QDebug>
+#include <QDir>
+#include <QDebug>
 
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
-#include <QtGui/QClipboard>
-#include <QtGui/QLabel>
-#include <QtGui/QListView>
-#include <QtGui/QMenu>
-#include <QtGui/QPainter>
-#include <QtGui/QScrollBar>
-#include <QtGui/QSortFilterProxyModel>
-#include <QtGui/QStyledItemDelegate>
-#include <QtGui/QVBoxLayout>
+#include <QAction>
+#include <QApplication>
+#include <QClipboard>
+#include <QLabel>
+#include <QListView>
+#include <QMenu>
+#include <QPainter>
+#include <QScrollBar>
+#include <QSortFilterProxyModel>
+#include <QStyledItemDelegate>
+#include <QVBoxLayout>
 
 using namespace Valgrind::XmlProtocol;
 
@@ -526,14 +526,7 @@ void MemcheckErrorView::contextMenuEvent(QContextMenuEvent *e)
 
 void MemcheckErrorView::suppressError()
 {
-    SuppressionDialog *dialog = new SuppressionDialog(this);
-    if (dialog->shouldShow()) {
-        dialog->setModal(true);
-        dialog->show();
-        dialog->setAttribute(Qt::WA_DeleteOnClose, true);
-    } else {
-        delete dialog;
-    }
+    SuppressionDialog::maybeShow(this);
 }
 
 void MemcheckErrorView::goNext()
