@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -35,12 +35,12 @@
 
 #include "ui_topicchooser.h"
 
-#include <QtCore/QUrl>
-#include <QtCore/QMap>
-#include <QtCore/QModelIndex>
-#include <QtCore/QString>
+#include <QUrl>
+#include <QMap>
+#include <QModelIndex>
+#include <QString>
 
-#include <QtGui/QDialog>
+#include <QDialog>
 
 QT_FORWARD_DECLARE_CLASS(QSortFilterProxyModel)
 
