@@ -5,9 +5,12 @@ project = "SquishProject"
 
 def main():
     startApplication("qtcreator" + SettingsPath)
-    createProject_Qt_GUI(projectsPath, project, defaultQtVersion, True)
-    runAndCloseApp()
-    sendEvent("QCloseEvent", waitForObject(":Qt Creator_Core::Internal::MainWindow"))
+    createProject_Qt_Console(projectsPath, project)
+    for config in iterateBuildConfigs(1, 0):
+        selectBuildConfig(1, 0, config)
+        test.log("Testing build configuration: " + config)
+        runAndCloseApp()
+    invokeMenuItem("File", "Exit")
     waitForCleanShutdown()
 
 def init():
