@@ -2,7 +2,7 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -35,14 +35,14 @@
 
 
 #include "codadevice.h"
-#include <QtNetwork/QTcpSocket>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
+#include <QTcpSocket>
+#include <QFile>
+#include <QFileInfo>
 
 #include <cstdio>
 
 static const char usageC[] =
-"\n%1 v0.1 built "__DATE__"\n\n"
+"\n%1 v0.1 built " __DATE__ "\n\n"
 "Test client for Symbian CODA\n\n"
 "Usage:\n"
 "%1 ping            connection   Note: For serial connections ONLY.\n"
